@@ -1,7 +1,6 @@
 /* Target-dependent code for GNU/Linux x86-64.
 
-   Copyright (C) 2001-2025 Free Software Foundation, Inc.
-   Copyright (C) 2013-2025 Intel Corporation
+   Copyright (C) 2001-2024 Free Software Foundation, Inc.
    Contributed by Jiri Smid, SuSE Labs.
 
    This file is part of GDB.
@@ -43,6 +42,7 @@
 #include "arch/amd64.h"
 #include "target-descriptions.h"
 #include "expop.h"
+#include "arch/amd64-linux-tdesc.h"
 #include "inferior.h"
 #include "x86-tdep.h"
 
@@ -52,7 +52,7 @@
 #include "record-full.h"
 #include "linux-record.h"
 
-#include <sstream>
+#include <string_view>
 
 /* Bit 63 is used to select between a kernel-space and user-space address.  */
 #define VA_RANGE_SELECT_BIT_MASK  0x8000000000000000UL
@@ -108,9 +108,10 @@ int amd64_linux_gregset_reg_offset[] =
   -1, -1, -1, -1, -1, -1, -1, -1,
   -1, -1, -1, -1, -1, -1, -1, -1,
   -1,				/* PKEYS register pkru  */
-  -1, 				/* CET user mode register PL3_SSP.  */
   -1,				/* TILECFG register (AMX).  */
-  -1,			 	/* TILEDATA registers tmm0 ... tmm7 (AMX).  */
+  -1,			 	/* TILEDATA register for the pseudo
+				   registers tmm0 ... tmm7 (AMX).  */
+  -1, 				/* CET user mode register PL3_SSP.  */
   -1, -1, -1, -1, -1, -1, -1, -1,     /* r16 ... r31.  */
   -1, -1, -1, -1, -1, -1, -1, -1,
 
@@ -333,8 +334,9 @@ amd64_linux_write_pc (struct regcache *regcache, CORE_ADDR pc)
     = gdbarch_tdep<i386_gdbarch_tdep> (regcache->arch ());
   if (tdep != nullptr && tdep->tilecfg_raw_regnum != -1)
     {
-      gdb_byte tilecfg_buf[register_size (regcache->arch (),
-					  tdep->tilecfg_raw_regnum)];
+       const int raw_size = register_size (regcache->arch (),
+					   tdep->tilecfg_raw_regnum);
+       gdb::byte_vector tilecfg_buf (raw_size);
 
       if (regcache->raw_read (tdep->tilecfg_raw_regnum, tilecfg_buf)
 	  != REG_VALID)
@@ -1617,45 +1619,6 @@ amd64_linux_record_signal (struct gdbarch *gdbarch,
   return 0;
 }
 
-const target_desc *
-amd64_linux_read_description (uint64_t xcr0_features_bit, bool is_x32,
-			      bool ssp_enabled)
-{
-  static target_desc *amd64_linux_tdescs \
-    [2/*AVX*/][2/*AVX512*/][2/*PKRU*/][2/*PL3_SSP*/]\
-    [2/*AMX*/][2/*APX*/] = {};
-  static target_desc *x32_linux_tdescs \
-    [2/*AVX*/][2/*AVX512*/][2/*PKRU*/][2/*PL3_SSP*/][2/*AMX*/]\
-    [2/*APX*/] = {};
-
-  target_desc **tdesc;
-
-  if (is_x32)
-    {
-      tdesc = &x32_linux_tdescs[(xcr0_features_bit & X86_XSTATE_AVX) ? 1 : 0 ]
-	[(xcr0_features_bit & X86_XSTATE_AVX512) ? 1 : 0]
-	[(xcr0_features_bit & X86_XSTATE_PKRU) ? 1 : 0]
-	[ssp_enabled ? 1 : 0]
-	[(xcr0_features_bit & X86_XSTATE_AMX) ? 1 : 0]
-	[(xcr0_features_bit & X86_XSTATE_APX_F) ? 1 : 0];
-    }
-  else
-    {
-      tdesc = &amd64_linux_tdescs[(xcr0_features_bit & X86_XSTATE_AVX) ? 1 : 0]
-	[(xcr0_features_bit & X86_XSTATE_AVX512) ? 1 : 0]
-	[(xcr0_features_bit & X86_XSTATE_PKRU) ? 1 : 0]
-	[ssp_enabled ? 1 : 0]
-	[(xcr0_features_bit & X86_XSTATE_AMX) ? 1 : 0]
-	[(xcr0_features_bit & X86_XSTATE_APX_F) ? 1 : 0];
-    }
-
-  if (*tdesc == NULL)
-    *tdesc = amd64_create_target_description (xcr0_features_bit, is_x32, true,
-					      true, ssp_enabled);
-
-  return *tdesc;
-}
-
 /* Get shadow stack pointer state from core dump.  */
 
 static bool
@@ -1673,15 +1636,15 @@ amd64_linux_core_read_description (struct gdbarch *gdbarch,
 {
   /* Linux/x86-64.  */
   x86_xsave_layout layout;
-  uint64_t xcr0 = i386_linux_core_read_xsave_info (abfd, layout);
-  if (xcr0 == 0)
-    xcr0 = X86_XSTATE_SSE_MASK;
+  uint64_t xstate_bv_mask = i386_linux_core_read_xsave_info (abfd, layout);
+  if (xstate_bv_mask == 0)
+    xstate_bv_mask = X86_XSTATE_SSE_MASK;
 
-  bool ssp_enabled = amd64_linux_core_read_ssp_state_p (abfd);
+  if (amd64_linux_core_read_ssp_state_p (abfd))
+    xstate_bv_mask |= X86_XSTATE_CET_U;
 
-  return amd64_linux_read_description (xcr0 & X86_XSTATE_ALL_MASK,
-				       gdbarch_ptr_bit (gdbarch) == 32,
-				       ssp_enabled);
+  return amd64_linux_read_description (xstate_bv_mask & X86_XSTATE_ALL_MASK,
+				       gdbarch_ptr_bit (gdbarch) == 32);
 }
 
 /* Similar to amd64_supply_fpregset, but use XSAVE extended state.  */
@@ -1711,17 +1674,23 @@ static const struct regset amd64_linux_xstateregset =
     amd64_linux_collect_xstateregset
   };
 
+/* Supply shadow stack pointer register from the buffer SSP to the
+   register cache REGCACHE.  */
+
 static void
-amd64_linux_supply_ssp (const struct regset *regset,
-			struct regcache *regcache, int regnum,
+amd64_linux_supply_ssp (const regset *regset,
+			regcache *regcache, int regnum,
 			const void *ssp, size_t len)
 {
   x86_supply_ssp (regcache, *static_cast<const uint64_t *> (ssp));
 }
 
+/* Collect the shadow stack pointer register from the register cache
+   REGCACHE and store it in SSP.  */
+
 static void
-amd64_linux_collect_ssp (const struct regset *regset,
-			 const struct regcache *regcache, int regnum,
+amd64_linux_collect_ssp (const regset *regset,
+			 const regcache *regcache, int regnum,
 			 void *ssp, size_t len)
 {
   x86_collect_ssp (regcache, *static_cast<uint64_t *> (ssp));
@@ -1734,7 +1703,6 @@ static const struct regset amd64_linux_ssp_register
     NULL, amd64_linux_supply_ssp, amd64_linux_collect_ssp
   };
 
-
 /* Iterate over core file register note sections.  */
 
 static void
@@ -1902,42 +1870,40 @@ amd64_linux_lam_untag_mask ()
   if (inf->fake_pid_p)
     return DEFAULT_TAG_MASK;
 
-  /* Construct status file name and read the file's content.  */
-  std::string filename = string_printf ("/proc/%d/status", inf->pid);
+  const std::string filename = string_printf ("/proc/%d/status", inf->pid);
   gdb::unique_xmalloc_ptr<char> status_file
     = target_fileio_read_stralloc (nullptr, filename.c_str ());
 
   if (status_file == nullptr)
     return DEFAULT_TAG_MASK;
 
-  /* Parse the status file line-by-line and look for the untag mask.  */
-  std::istringstream strm_status_file (status_file.get ());
-  std::string line;
-  const std::string untag_mask_str ("untag_mask:\t");
-  while (std::getline (strm_status_file, line))
+  std::string_view status_file_view (status_file.get ());
+  constexpr std::string_view untag_mask_str = "untag_mask:\t";
+  const size_t found = status_file_view.find (untag_mask_str);
+  if (found != std::string::npos)
     {
-      const size_t found = line.find (untag_mask_str);
-      if (found != std::string::npos)
-	{
-	  const size_t tag_length = untag_mask_str.length();
-	  return std::strtoul (&line[found + tag_length], nullptr, 0);
-	}
+      const char* start = status_file_view.data() + found
+			  + untag_mask_str.length ();
+      char* endptr;
+      errno = 0;
+      unsigned long long result = std::strtoul (start, &endptr, 0);
+      if (errno != 0 || endptr == start)
+	error (_("Failed to parse untag_mask from file %s."),
+	       std::string (filename).c_str ());
+
+      return result;
     }
 
    return DEFAULT_TAG_MASK;
 }
 
-/* Adjust watchpoint address based on the tagging mode which is currently
-   enabled.  For now, linear address masking (LAM) is the only feature
-   which allows to store metadata in pointer values for amd64.  Thus, we
-   adjust the watchpoint address based on the currently active LAM mode
-   using the untag mask provided by the linux kernel.  Check each time for
-   a new mask, as LAM is enabled at runtime.  Also, the LAM configuration
-   may change when entering an enclave.  No untagging will be applied if
-   this function is called while we don't have execution.  */
+/* Adjust watchpoint address based on the currently active linear address
+   masking (LAM) mode using the untag mask.  Check each time for a new
+   mask, as LAM is enabled at runtime.  */
 
 static CORE_ADDR
-amd64_linux_remove_non_addr_bits_wpt (gdbarch *gdbarch, CORE_ADDR addr)
+amd64_linux_remove_non_address_bits_watchpoint (gdbarch *gdbarch,
+						CORE_ADDR addr)
 {
   /* The topmost bit tells us if we have a kernel-space address or a user-space
      address.  */
@@ -1960,7 +1926,8 @@ amd64_linux_remove_non_addr_bits_wpt (gdbarch *gdbarch, CORE_ADDR addr)
    possible.  */
 
 static std::optional<CORE_ADDR>
-amd64_linux_get_shadow_stack_pointer (gdbarch *gdbarch)
+amd64_linux_get_shadow_stack_pointer (gdbarch *gdbarch, regcache *regcache,
+				      bool &shadow_stack_enabled)
 {
   const i386_gdbarch_tdep *tdep = gdbarch_tdep<i386_gdbarch_tdep> (gdbarch);
 
@@ -1968,7 +1935,6 @@ amd64_linux_get_shadow_stack_pointer (gdbarch *gdbarch)
     return {};
 
   CORE_ADDR ssp;
-  regcache *regcache = get_thread_regcache (inferior_thread ());
   if (regcache_raw_read_unsigned (regcache, tdep->ssp_regnum, &ssp)
       != REG_VALID)
     return {};
@@ -1980,6 +1946,9 @@ amd64_linux_get_shadow_stack_pointer (gdbarch *gdbarch)
   if (ssp == 0x0)
     return {};
 
+  /* In case there is a shadow stack pointer available which is non-null,
+     the shadow stack feature is enabled.  */
+  shadow_stack_enabled = true;
   return ssp;
 }
 
@@ -2075,8 +2044,9 @@ amd64_linux_init_abi_common(struct gdbarch_info info, struct gdbarch *gdbarch,
   set_gdbarch_process_record (gdbarch, i386_process_record);
   set_gdbarch_process_record_signal (gdbarch, amd64_linux_record_signal);
 
-  set_gdbarch_remove_non_addr_bits_wpt (gdbarch,
-					amd64_linux_remove_non_addr_bits_wpt);
+  set_gdbarch_remove_non_address_bits_watchpoint
+    (gdbarch, amd64_linux_remove_non_address_bits_watchpoint);
+
   set_gdbarch_get_shadow_stack_pointer (gdbarch,
 					amd64_linux_get_shadow_stack_pointer);
 
