@@ -561,7 +561,7 @@ int mm_write_mtx_crd(char fname[], int M, int N, int nz, int I[], int J[],
 */
 char *mm_strdup(const char *s)
 {
-    int len = strlen(s);
+    size_t len = strlen(s);
     char *s2 = (char *) malloc((len+1)*sizeof(char));
     MALLOC_CHECK_ERROR(s2, return NULL;);
     return strcpy(s2, s);
