@@ -476,16 +476,11 @@ static FileFormat GetImageType(File &file)
 
 Image::Image()
 {
-    m_bufferAlignment = 64;
-    m_stepAlignment = 64;
     Reset();
 }
 
 Image::Image(Size size, ColorFormat color, SampleFormat sampleFormat)
 {
-    m_bufferAlignment = 64;
-    m_stepAlignment = 64;
-
     Reset();
 
     m_size = size;
@@ -497,9 +492,6 @@ Image::Image(Size size, ColorFormat color, SampleFormat sampleFormat)
 
 Image::Image(Size size, unsigned int samples, SampleFormat sampleFormat)
 {
-    m_bufferAlignment = 64;
-    m_stepAlignment = 64;
-
     Reset();
 
     m_size = size;
@@ -510,9 +502,6 @@ Image::Image(Size size, unsigned int samples, SampleFormat sampleFormat)
 
 Image::Image(const char *pFileName, ColorFormat dstColor, SampleFormat dstFormat)
 {
-    m_bufferAlignment = 64;
-    m_stepAlignment = 64;
-
     Reset();
 
     if (STS_OK != Read(pFileName, dstColor, dstFormat))
