@@ -2,7 +2,7 @@
 # SPDX-License-Identifier: MIT
 from cli.args import parse_args
 from cli.console_output import CliConsoleOutput
-from tools.common.version import PythonVersion, UnsupportedPythonVersionError
+from tools.common.python_version import PythonVersion, UnsupportedPythonVersionError
 
 
 def main(dry_run=False):
@@ -17,6 +17,8 @@ def main(dry_run=False):
     try:
         if not dry_run:
             run(args)
+        else:
+            return args
     except Exception as e:
         CliConsoleOutput.show_error('Error running Metric post processor', exception=e)
 
