@@ -1,15 +1,18 @@
 # Copyright (C) 2023 Intel Corporation
 # SPDX-License-Identifier: MIT
 
+import logging
+import operator
 from dataclasses import dataclass, field
 from enum import Enum, auto, Flag
-from typing import List, Callable, Union, Dict, Type
+from typing import List, Callable, Union, Dict, Type, Any, Tuple
 from abc import abstractmethod, ABC
 
 import numpy as np
 import pandas as pd
 import re
 
+from mpp.core.threshold_metric_computer import ThresholdMetricComputer
 from mpp.core.metric_computer import MetricComputer, _SliceMetricComputer, CompiledMetric
 from mpp.core.normalizer import Normalizer
 from mpp.core.types import RawDataFrameColumns as rdc, RawDataFrame, SummaryViewDataFrameColumns as svdc, \
@@ -39,6 +42,7 @@ class ViewAggregationLevel(Enum):
     """
     SYSTEM = auto()
     SOCKET = auto()
+    DIE = auto()
     CORE = auto()
     THREAD = auto()
     UNCORE = auto()
@@ -59,6 +63,7 @@ class ViewAttributes:
     required_events: Union[EventInfoDataFrame, None]  # column names that must appear in the view data
     percentile: Union[int, None] = None  # percentile to calculate for system summary or None (no percentile in summary)
     tps: Union[float, None] = None  # tps value for tps views (transactions per second)
+    thresholds: Union[pd.DataFrame, None] = None  # thresholds for the view
 
     def clone(self, update: Dict = None):
         """
@@ -106,15 +111,45 @@ class ViewCollection:
         """
         self.__view_configurations.extend(views)
 
-    def remove_views(self, view_name_filter):
+    def remove_views(self, filters: List[Tuple], mode: str = 'exclude') -> None:
         """
         Remove a view from the view collection. Filters __view_configurations based on view_name.
 
-        @param view_name_filter: the name of the view you wish to remove
+        @param filters: list of tuples, each containing (attribute, value, operator)
+        @param mode: 'exclude' to remove views that match all criteria (default), 'include' to keep only views that match all criteria
         @return: None, updated __view_configurations
         """
-        self.__view_configurations = list(
-            filter(lambda view: view_name_filter not in view.view_name, self.__view_configurations))
+        self._validate_filter_preconditions(filters, mode)
+        self._handle_view_filtering(filters, mode)
+
+    def _handle_view_filtering(self, filters, mode):
+        # Apply all filters together with AND logic - all conditions must be true
+        def matches_all_filters(config):
+            return all(operator(getattr(config, attribute), value)
+                       for attribute, value, operator in filters)
+
+        if mode == 'exclude':
+            # Remove views that match all filter criteria
+            self.__view_configurations = list(
+                filter(lambda config: not matches_all_filters(config), self.__view_configurations)
+            )
+        else:  # mode == 'include'
+            # Keep only views that match all filter criteria
+            self.__view_configurations = list(
+                filter(matches_all_filters, self.__view_configurations)
+            )
+
+    @staticmethod
+    def _validate_filter_preconditions(filters, mode):
+        if mode not in ['exclude', 'include']:
+            raise ValueError("mode must be either 'exclude' or 'include'")
+        for filter_tuple in filters:
+            if len(filter_tuple) != 3:
+                raise ValueError('each filter must be a tuple of length 3: (attribute, value, operator)')
+            attribute, value, op = filter_tuple
+            # TODO: get this condtion to work
+            # if attribute not in ViewAttributes.__dataclass_fields__:
+            #     raise ValueError(f'attribute "{attribute}" is not a valid ViewAttributes attribute')
 
     def add_view(self,
                  view_name: str,
@@ -133,7 +168,7 @@ class ViewCollection:
         :param view_type: the view type to add, e.g. Summary, Details. You can specify multiple types
                           (e.g. Summary and Details) by combining types using bitwise OR.
         :param aggregation_level: the level at which to aggregate data, e.g. System, Socket, Core...
-        @param device: device to be filtered for this view
+        :param device: device to be filtered for this view
         :param show_modules: include module information if True
         :param metric_computer: the metric computer to use for the specified view
         :param normalizer: the normalizer to use for the specified view
@@ -171,6 +206,7 @@ class ViewInitializer:
     def __init__(self, devices, api_args: 'ApiArgs'):
         self.__devices = devices
         self.__show_modules: bool = api_args.system_information.has_modules
+        self.__show_die: bool = api_args.system_information.has_die
         self.__normalizer: Normalizer = Normalizer(api_args.system_information.ref_tsc)
         self.__event_info: EventInfoDataFrame = api_args.event_info
         self.__include_detail_views: bool = not api_args.no_detail_views
@@ -186,6 +222,9 @@ class ViewInitializer:
     def add_views(self) -> ViewCollection:
         for device in self.__devices:
             for agg_level in device.aggregation_levels:
+                # Skip die views when die data is not available
+                if agg_level == ViewAggregationLevel.DIE and not self.__show_die:
+                    continue
                 self.add_view(device, agg_level, ViewType.SUMMARY)
                 self._conditional_add_detail_view(device, agg_level)
         return self.__view_collection
@@ -217,6 +256,62 @@ class ViewInitializer:
         return False
 
 
+class ViewFilter:
+    """
+    Filter views in a ViewCollection based on no_detail_views and unit_filter API arguments
+    """
+
+    def __init__(self, view_collection: ViewCollection, api_args: 'ApiArgs'):
+        self.__view_collection = view_collection
+        self.__no_detail_views = api_args.no_detail_views
+        self.__unit_filters = api_args.unit_filters
+        self.__sys_info = api_args.system_information
+
+    def filter_views(self):
+        self.__conditional_filter_detail_views()
+        self.__filter_uncore_views_without_uncore()
+        self.__filter_views_by_unit_filter()
+        return self.__view_collection
+
+    def __conditional_filter_detail_views(self):
+        if self.__no_detail_views:
+            details_view_filter = [
+                ('view_type', ViewType.DETAILS, operator.eq),
+                ('aggregation_level', ViewAggregationLevel.SYSTEM, operator.ne)
+            ]
+            self.__view_collection.remove_views(details_view_filter, mode='exclude')
+
+    def __filter_uncore_views_without_uncore(self):
+        """
+        This method is used to remove 'uncore_view_summary' and 'uncore_view_details' that should not be generated
+        """
+
+        for core_type in self.__sys_info.unique_core_types:
+            uncore_view_filter = [
+                ('aggregation_level', ViewAggregationLevel.UNCORE, operator.eq),
+                ('device', Device(core_type), operator.eq)
+            ]
+            self.__view_collection.remove_views(uncore_view_filter, mode='exclude')
+
+    def __filter_views_by_unit_filter(self):
+        if not self.__unit_filters:
+            return
+        view_filters: List[List[Tuple]] = []
+        for agg_level in [ViewAggregationLevel.CORE, ViewAggregationLevel.THREAD]:
+            view_filters.append([('aggregation_level', agg_level, operator.eq)])
+        for unit in self.__unit_filters:
+            # Works only for core filters for now
+            if self.__unit_is_completely_filtered_out(unit):
+                device_filter = ('device', Device(unit), operator.eq)
+                for view_filter in view_filters:
+                    view_filter.append(device_filter)
+                    self.__view_collection.remove_views(view_filter, mode='exclude')
+                logging.warning(f'All metrics for core type "{unit}" are filtered out.')
+
+    def __unit_is_completely_filtered_out(self, unit):
+        return unit in self.__unit_filters and not self.__unit_filters[unit]
+
+
 class ViewGenerator:
     """
     Generate views with various levels of data aggregation (per system, socket, core, thread...)
@@ -272,13 +367,23 @@ class ViewGenerator:
         if df.empty:
             return [ViewData(view.attributes, df, pd.DataFrame()) for view in self.__views if ViewType.SUMMARY in
                     view.attributes.view_type]
-        return [view.compute_aggregate(df) for view in self.__views if ViewType.SUMMARY in view.attributes.view_type]
+
+        results = []
+        for view in self.__views:
+            if ViewType.SUMMARY in view.attributes.view_type:
+                view_data = view.compute_aggregate(df)
+                # Only include views that have actual data (filter out empty results for backwards compatibility)
+                if not view_data.data.empty:
+                    results.append(view_data)
+
+        return results
 
     def __initialize_view_definitions(self, view_collection: ViewCollection):
         def create_view_definition(config: ViewAttributes):
             return {
                 ViewAggregationLevel.SYSTEM: _SystemDataView,
                 ViewAggregationLevel.SOCKET: _SocketDataView,
+                ViewAggregationLevel.DIE: _DieView,
                 ViewAggregationLevel.CORE: _CoreDataView,
                 ViewAggregationLevel.THREAD: _ThreadDataView,
                 ViewAggregationLevel.UNCORE: _UncoreDataView,
@@ -803,7 +908,10 @@ class _DataView:
 
     def __merge_slice_metrics_detail_views(self, details_metrics_df, slice_metrics_df):
         if not slice_metrics_df.empty:
-            details_metrics_df = details_metrics_df.merge(slice_metrics_df, left_index=True, right_index=True)
+            if details_metrics_df.empty:
+                details_metrics_df = slice_metrics_df
+            else:
+                details_metrics_df = details_metrics_df.merge(slice_metrics_df, left_index=True, right_index=True)
             if not self.__metric_column_order:
                 self.__metric_column_order = self.__get_metric_column_order(details_metrics_df, slice_metrics_df)
             details_metrics_df = details_metrics_df[self.__metric_column_order]
@@ -865,10 +973,14 @@ class _DataView:
                                               metric_computer=None):
         # TODO: maybe make this an interface with separate implementation for metriccomputer, slicemetriccomputer
         details_events_df = self._aggregate_events(details_events_df, aggregation_list, details_group_by)
-        details_view_df = pd.pivot_table(details_events_df,
-                                         columns=[rdc.NAME],
-                                         index=details_index,
-                                         values=rdc.VALUE)
+        try:
+            details_view_df = pd.pivot_table(details_events_df,
+                                             columns=[rdc.NAME],
+                                             index=details_index,
+                                             values=rdc.VALUE)
+        except Exception as e:
+            self.__handle_exceptions(e)
+
         details_view_df = self.__adjust_details_view_dataframe_columns(details_view_df)
         details_metrics_df = self._compute_metrics(details_view_df, metric_computer, True)
         return details_metrics_df, details_view_df
@@ -921,6 +1033,18 @@ class _DataView:
             df = df.loc[~(df[df_column_type.DEVICE].str.contains('|'.join(self.__exclude_any_device_containing)))]
         return df
 
+    def __handle_exceptions(self, e: Exception):
+        error_type = type(e).__name__
+        default_exception_msg = f" ({error_type}, message: {str(e)})"
+        if isinstance(e, ValueError) and 'negative dimensions are not allowed' in str(e):
+            raise ArrayMetricCalculationError(original_exception=e) from e
+        elif isinstance (e, IndexError) and 'is out of bounds for axis' in str(e):
+            raise ArrayMetricCalculationError(original_exception=e) from e
+        elif isinstance(e, MemoryError) and 'Unable to allocate' in str(e):
+            raise ArrayMetricCalculationError(original_exception=e) from e
+        else:
+            raise Exception(default_exception_msg)
+
 
 class DataAccumulator:
     """
@@ -931,8 +1055,7 @@ class DataAccumulator:
 
     def __init__(self, view_generator: ViewGenerator):
         self.__views = {view.attributes.view_name: view for view in view_generator.views}
-        self.__event_views = {view.attributes.view_name: ViewData(view.attributes, pd.DataFrame())
-                              for view in view_generator.views}
+        self.__event_views = {}
         self.__stats_views = {view.attributes.view_name: ViewData(view.attributes, pd.DataFrame())
                               for view in view_generator.views}
 
@@ -947,12 +1070,14 @@ class DataAccumulator:
             if ViewType.SUMMARY not in new_view.attributes.view_type:
                 raise ValueError('warning: request for details in summary function')
             data_view = self.__views[new_view.attributes.view_name]
-            view = self.__event_views[new_view.attributes.view_name]
-            view.data = data_view.update_summary(new_view.data, view.data)
-            view.retire_latency_counts = \
-                data_view.update_counts_per_event(new_view.retire_latency_counts, view.retire_latency_counts)
-            view.static_msr_counts = \
-                data_view.update_counts_per_event(new_view.static_msr_counts, view.static_msr_counts)
+            if new_view.attributes.view_name not in self.__event_views:
+                self.__event_views[new_view.attributes.view_name] = ViewData(new_view.attributes, pd.DataFrame())
+            event_view = self.__event_views[new_view.attributes.view_name]
+            event_view.data = data_view.update_summary(new_view.data, event_view.data)
+            event_view.retire_latency_counts = \
+                data_view.update_counts_per_event(new_view.retire_latency_counts, event_view.retire_latency_counts)
+            event_view.static_msr_counts = \
+                data_view.update_counts_per_event(new_view.static_msr_counts, event_view.static_msr_counts)
 
     def update_statistics(self, detail_views: Dict[str, ViewData] = None, df: RawDataFrame = None) -> None:
         """
@@ -969,17 +1094,17 @@ class DataAccumulator:
                 raise ValueError('if no detail views are requested, then a dataframe must be passed into this method')
 
         validate_preconditions()
-        for view_id, view in self.__stats_views.items():
-            if detail_views and view.attributes.view_type != ViewType.DETAILS:
+        for view_id, stat_view in self.__stats_views.items():
+            if detail_views and stat_view.attributes.view_type != ViewType.DETAILS:
                 try:
                     df = detail_views[view_id.replace('summary', 'details')].data
                 except KeyError:
                     # Statistics don't need to be computed for any view other than system summary for now
                     continue
-            if view.attributes.view_type == ViewType.DETAILS:
+            if stat_view.attributes.view_type == ViewType.DETAILS:
                 continue
             data_view = self.__views[view_id]
-            view.data = data_view.update_statistics(df)
+            stat_view.data = data_view.update_statistics(df)
 
     def generate_summary_views(self) -> Dict[str, ViewData]:
         """
@@ -1023,6 +1148,11 @@ class _SystemDataView(_DataView):
                          device_filter_mode='exclude'
                          )
         self.__stats = _Statistics(config.percentile)
+        self._thresholds = pd.DataFrame()
+
+    @property
+    def thresholds(self) -> pd.DataFrame:
+        return self._thresholds
 
     def update_statistics(self, df: Union[RawDataFrame, pd.DataFrame]) -> StatisticsDataFrame:
         """
@@ -1046,8 +1176,22 @@ class _SystemDataView(_DataView):
         if not stats_df.empty:
             summary_data_df = pd.concat([summary_data_df, stats_df.dropna(axis=0, how='all').transpose()])
         metric_descriptions = self.__get_descriptions()
+        if self.attributes.metric_computer and self.attributes.metric_computer.metric_definitions:
+            self._set_threshold_df(summary_view.data)
         summary_view.data = self.__add_descriptions(summary_data_df, metric_descriptions)
-        return summary_view
+        return ViewData(self.attributes.clone(update={'thresholds': self._thresholds}), summary_view.data)
+
+    def _set_threshold_df(self, summary_view_df: pd.DataFrame) -> None:
+        threshold_definitions = self._get_threshold_definitions()
+        if threshold_definitions:
+            threshold_metric_computer = ThresholdMetricComputer(threshold_definitions)
+            self._thresholds = threshold_metric_computer.compute_metric(summary_view_df)
+
+    def _get_threshold_definitions(self):
+        metric_definitions = list(filter(lambda x: x.threshold,
+                           self.attributes.metric_computer.metric_definitions))
+        if metric_definitions:
+            return [definition.threshold for definition in metric_definitions]
 
     @staticmethod
     def __is_raw_emon_dataframe(df: Union[RawDataFrame, pd.DataFrame]):
@@ -1092,6 +1236,29 @@ class _SocketDataView(_DataView):
                          exclude_any_device_containing=['THREAD'],
                          device_filter_mode='exclude'
                          )
+        self._thresholds = pd.DataFrame()
+
+    @property
+    def thresholds(self) -> pd.DataFrame:
+        return self._thresholds
+
+    def generate_summary(self, event_df: pd.DataFrame, stats_df: pd.DataFrame = pd.DataFrame()) -> ViewData:
+        summary_view = super().generate_summary(event_df)
+        if self.attributes.metric_computer and self.attributes.metric_computer.metric_definitions:
+            self._set_threshold_df(summary_view.data)
+        return ViewData(self.attributes.clone(update={'thresholds': self._thresholds}), summary_view.data)
+
+    def _set_threshold_df(self, summary_view_df: pd.DataFrame) -> None:
+        threshold_definitions = self._get_threshold_definitions()
+        if threshold_definitions:
+            threshold_metric_computer = ThresholdMetricComputer(threshold_definitions)
+            self._thresholds = threshold_metric_computer.compute_metric(summary_view_df)
+
+    def _get_threshold_definitions(self):
+        metric_definitions = list(filter(lambda x: x.threshold,
+                           self.attributes.metric_computer.metric_definitions))
+        if metric_definitions:
+            return [definition.threshold for definition in metric_definitions]
 
     def _override_constant_values(self, symbol_table):
         # Adjust the value of the "system.socket_count" constant to 1 to properly compute socket-level metrics
@@ -1101,6 +1268,24 @@ class _SocketDataView(_DataView):
         return updated_system_information
 
 
+class _DieView(_DataView):
+    """
+    View definition for the die summary and detail views
+    """
+
+    def __init__(self, config: ViewAttributes):
+        super().__init__(config,
+                         summary_group_by=[rdc.NAME, rdc.SOCKET, rdc.DIE],
+                         aggregator_columns=[rdc.NAME, rdc.SOCKET, rdc.DIE, rdc.UNIT, rdc.TSC, rdc.VALUE],
+                         aggregator_group_by=[rdc.NAME, rdc.SOCKET, rdc.DIE, rdc.UNIT],
+                         details_group_by=[rdc.GROUP, rdc.TIMESTAMP, rdc.TSC, rdc.NAME, rdc.SOCKET, rdc.DIE],
+                         details_index=[rdc.GROUP, rdc.TIMESTAMP, rdc.SOCKET, rdc.DIE],
+                         device_filter=['SYSTEM'] + config.device.exclusions,
+                         exclude_any_device_containing=['THREAD'],
+                         device_filter_mode='exclude'
+                         )
+
+
 class _CoreDataView(_DataView):
     """
     View definition for the Core summary and detail views
@@ -1227,3 +1412,17 @@ class _NullMetricComputer(MetricComputer):
     @property
     def metric_definitions(self) -> List[MetricDefinition]:
         return []
+
+
+class ArrayMetricCalculationError(Exception):
+    def __init__(self, original_exception=None, message="Failed to calculate array metric due to array size. "
+                "Consider adjusting the chunk size using the '--chunk-size' command-line option to work around "
+                "this issue."):
+        if original_exception:
+            error_type = type(original_exception).__name__
+            if 'Unable to allocate' in str(original_exception):
+                message += f" Additionally, consider closing any other memory-intensive applications running " \
+                "in the background."
+            message += f" (Original error type: {error_type}, message: {str(original_exception)})"
+
+        super().__init__(message)
