@@ -1,6 +1,6 @@
 # Copyright (C) 2023 Intel Corporation
 # SPDX-License-Identifier: MIT
-
+import logging
 import os
 from abc import abstractmethod, ABC
 
@@ -12,7 +12,7 @@ from datetime import datetime
 from enum import Enum, auto
 from functools import reduce
 from pathlib import Path
-from typing import List, Dict, Generator, Any, Optional, TextIO, Pattern, Union
+from typing import List, Dict, Generator, Any, Optional, TextIO, Pattern, Union, Type
 
 import numpy as np
 import pytz
@@ -221,7 +221,7 @@ class DataParser(ABC):
     Handles event reading, event device classification, partitioning, and dataframe generation from data files.
     """
 
-    line_class: _Line = None
+    line_class: Type[_Line] = None
 
     collector: str = None
 
@@ -321,7 +321,7 @@ class DataParser(ABC):
         :return: a generator for event values, represented as a pandas dataframe with the following structure:
                  rows: a single event value
                  columns:
-                   TimeStamp: sample timestamp
+                   timestamp: sample timestamp
                    socket: socket/package number (0 based)
                    device: event type/source, e.g. CORE, UNCORE, ...
                    core: core number (0 based)
@@ -374,12 +374,14 @@ class DataParser(ABC):
                 @return DataFrame: Contains a row for every event, sample, and value within the raw data file.
                 """
                 dataframe_builder = _EventDataFrameBuilder(self._data_parser.system_info)
+                previous_sample = datetime.min
                 for sample in samples:
-                    if len(sample.events) == 0 and not sample.TimeStamp:
+                    if len(sample.events) == 0 and not sample.timestamp:
                         continue
+                    previous_sample = self.__get_valid_timestamp(previous_sample, sample)
                     for event in sample.events.values():
                         if exclude_invalid_events and self._excluded_event_tracker.is_invalid_event(event):
-                            self._excluded_event_tracker.add_exclusion(sample.TimeStamp, event.name)
+                            self._excluded_event_tracker.add_exclusion(sample.timestamp, event.name)
                             continue
                         sample.detect_and_update_topdown_event_values(event.name)
                         dataframe_builder.append_event_values(sample, event)
@@ -388,6 +390,15 @@ class DataParser(ABC):
                 self._excluded_event_tracker.report_excluded_events()
                 return RawDataFrame(events_df)
 
+            def __get_valid_timestamp(self, previous_sample, sample):
+                if not sample.timestamp:
+                    return previous_sample
+                if sample.timestamp <= previous_sample:
+                    input_file = os.path.basename(self._data_parser.input_file)
+                    raise ValueError(f'Error parsing {input_file}: Timestamp {sample.timestamp.strftime(self._data_parser.attributes.date_format)[:-3]} out of order. '
+                        f'Remove out of order samples to resolve this issue. This is usually an out-of-order duplicate timestamp at the end of the input file.')
+                return sample.timestamp
+
         def verify_preconditions():
             if self.system_info.ref_tsc == 0:
                 raise ValueError('Unable to determine system frequency. '
@@ -518,19 +529,20 @@ class _TopdownEventInfo:
         self.__perf_metrics: List[str] = []
         self.__divisor_values: Union[np.ndarray, None] = None
         self.__multiplier_values: Union[np.ndarray, None] = None
+        self.__skip_sample = False
 
-    def set_info(self, events: Dict[str, _Line]):
+    def set_info(self, events: Dict[str, _Line], timestamp: datetime):
         topdown_events = {k: e for k, e in events.items() if self.__is_topdown_event(e.name)}
         if not topdown_events:
             return
         event_values = {k: e.values for k, e in topdown_events.items()}
         self.__perf_metrics = list(filter(lambda e: e.lower().startswith(self.PERF_METRICS), topdown_events.keys()))
-        self.__set_normalized_topdown_event_divisor_values(event_values)
+        self.__set_normalized_topdown_event_divisor_values(event_values, timestamp)
         self.__set_topdown_event_multiplier_values(events)
 
     def is_valid(self, event_name: str):
         if event_name in self.__perf_metrics and self.__divisor_values is not None and self.__multiplier_values is \
-                not None:
+                not None and not self.__skip_sample:
             return True
         return False
 
@@ -541,10 +553,21 @@ class _TopdownEventInfo:
         if self.MULTIPLIER_EVENT in events:
             self.__multiplier_values = events[self.MULTIPLIER_EVENT].values
 
-    def __set_normalized_topdown_event_divisor_values(self, values):
+    def __set_normalized_topdown_event_divisor_values(self, values, timestamp: str):
         normalized_events = list(filter(lambda e: self.__is_normalizing_topdown_event(e), self.__perf_metrics))
-        if normalized_events:
+        if self.__all_topdown_events_exist_in_sample(normalized_events):
             self.__divisor_values = reduce(np.add, [values[e] for e in normalized_events])
+        else:
+            missing_topdown_events = set(_TopdownEventInfo.NORMALIZED_TOPDOWN_EVENTS) - set(normalized_events)
+            if normalized_events:
+                logging.warning(f'Missing the following topdown event/s at timestamp {timestamp}:'
+                                f' {missing_topdown_events} '
+                                f'Skipping topdown event normalization. To avoid this warning, remove the following '
+                                f'event/s at that timestamp from the input data file: {normalized_events}')
+            self.__skip_sample = True
+
+    def __all_topdown_events_exist_in_sample(self, normalized_events):
+        return len(normalized_events) == len(_TopdownEventInfo.NORMALIZED_TOPDOWN_EVENTS)
 
     def __is_topdown_event(self, event_name: str) -> bool:
         return event_name.lower().startswith(self.PERF_METRICS) or event_name.startswith(self.TOPDOWN_SLOTS)
@@ -566,7 +589,7 @@ class _Sample:
     """
 
     def __init__(self, perfmon_parser: DataParser, data, sample_number, block_number):
-        self.TimeStamp = None
+        self.timestamp = None
         self.timestamps = set()
         self.__perfmon_parser = perfmon_parser
         self.events: Dict[str, _Line] = {}
@@ -579,11 +602,11 @@ class _Sample:
         for line in data:
             line_values = line.split(self.__perfmon_parser.attributes.value_separator)
             if self.__perfmon_parser.attributes.date_pattern.match(line):
-                self.TimeStamp = self.__perfmon_parser.convert_to_datetime_from_line(line)
-            if self.__is_event_line(line_values):
+                self.timestamp = self.__perfmon_parser.convert_to_datetime_from_line(line)
+            if self.__line_contains_event_values(line_values):
                 try:
                     event = self._line_class(line_values, self.__perfmon_parser.system_info.unique_os_processors,
-                                             self.TimeStamp)
+                                             self.timestamp)
                     self.events[event.name] = event
                     self.timestamps.add(event.timestamp)
                 except Exception as e:
@@ -602,11 +625,13 @@ class _Sample:
             self.duration = 0
 
         try:
-            self._topdown_info.set_info(self.events)
+            if self.timestamp:
+                self._topdown_info.set_info(self.events, self.timestamp.strftime(
+                    self.__perfmon_parser.attributes.date_format)[:-3])
         except ValueError as e:
             raise ValueError(f' {e}: Corrupt input data in sample {sample_number} at timestamp '
-                             f'{self.TimeStamp.strftime("%m/%d/%Y %H:%M:%S.%f")[:-3]}. There is an unrecoverable '
-                             f' error in the data file. Users can try deleting the corresponding sample.')
+                             f'{self.timestamp.strftime(self.__perfmon_parser.attributes.date_format)[:-3]}. There '
+                             f'is an unrecoverable error in the data file. Users can try deleting the corresponding sample.')
 
     def detect_and_update_topdown_event_values(self, event_name: str):
         """
@@ -616,7 +641,7 @@ class _Sample:
             self.events[event_name].values = self._topdown_info.get_updated_values(self.events[event_name].values)
 
     @staticmethod
-    def __is_event_line(line_values):
+    def __line_contains_event_values(line_values):
         return len(line_values) > 1
 
 
@@ -967,13 +992,14 @@ class _EventDataFrameBuilder:
 
     def _append_core_event(self, sample: _Sample, event: _Line, unit_count: int) -> None:
         # tuple parameter order follows RawDataFrameColumns. All entries must be accounted for
-        self.__data.extend(tuple(((sample.TimeStamp,
+        self.__data.extend(tuple(((sample.timestamp,
                                    self.system_info.socket_map[processor],
                                    self.system_info.core_type_map[processor],
                                    self.system_info.core_map[processor],
                                    self.system_info.thread_map[processor],
                                    processor,
                                    self.system_info.module_map[processor],
+                                   self.system_info.die_map.get(processor, np.nan),
                                    sample.tsc_count,
                                    sample.block_number,
                                    event.name,
@@ -983,13 +1009,14 @@ class _EventDataFrameBuilder:
 
     def _append_thread_event(self, sample: _Sample, event: _Line, unit_count: int) -> None:
         # tuple parameter order follows RawDataFrameColumns. All entries must be accounted for
-        self.__data.extend(tuple(((sample.TimeStamp,
+        self.__data.extend(tuple(((sample.timestamp,
                                    self.system_info.socket_map[processor],
                                    event.device + '_' + self.system_info.core_type_map[processor],
                                    self.system_info.core_map[processor],
                                    self.system_info.thread_map[processor],
                                    processor,
                                    self.system_info.module_map[processor],
+                                   self.system_info.die_map.get(processor, np.nan),
                                    sample.tsc_count,
                                    sample.block_number,
                                    event.name,
@@ -1000,8 +1027,8 @@ class _EventDataFrameBuilder:
     def _append_asymmetric_noncore_event(self, sample: _Sample, event: _Line, unit_count: int, pcie_id: str) -> None:
         socket_map = self.system_info.pcie_units[pcie_id]
         # tuple parameter order follows RawDataFrameColumns. All entries must be accounted for
-        self.__data.extend(tuple(((sample.TimeStamp, socket_map[index],
-                                   event.device, None, None, index, None, sample.tsc_count,
+        self.__data.extend(tuple(((sample.timestamp, socket_map[index],
+                                   event.device, None, None, index, None, None, sample.tsc_count,
                                    sample.block_number, event.name, event.values[index])
                                   for index in range(unit_count))))
 
@@ -1009,38 +1036,41 @@ class _EventDataFrameBuilder:
         socket_count = np.unique(list(self.system_info.socket_map.values())).size
         units_per_socket = unit_count // socket_count
         # tuple parameter order follows RawDataFrameColumns. All entries must be accounted for
-        self.__data.extend(tuple(((sample.TimeStamp, index // units_per_socket,
-                                   event.device, None, None, index % units_per_socket, None, sample.tsc_count,
+        self.__data.extend(tuple(((sample.timestamp, index // units_per_socket,
+                                   event.device, None, None, index % units_per_socket, None, None, sample.tsc_count,
                                    sample.block_number, event.name, event.values[index])
                                   for index in range(unit_count))))
 
     def _append_tsc(self, sample: _Sample) -> None:
         # Inject the TSC value as a set of TSC core events. Some metric formulas need TSC as a core event
         # tuple parameter order follows RawDataFrameColumns. All entries must be accounted for
-        self.__data.extend(tuple(((sample.TimeStamp, self.system_info.socket_map[processor],
+        self.__data.extend(tuple(((sample.timestamp, self.system_info.socket_map[processor],
                                    self.system_info.core_type_map[processor],
                                    self.system_info.core_map[processor], self.system_info.thread_map[processor],
                                    processor, self.system_info.module_map[processor],
+                                   self.system_info.die_map.get(processor, np.nan),
                                    sample.tsc_count, sample.block_number,
                                    'TSC', sample.tsc_count)
                                   for index, processor in enumerate(self.system_info.unique_os_processors))))
 
     def _append_sampling_time(self, sample: _Sample) -> None:
         # append parameter order follows RawDataFrameColumns. All entries must be accounted for
-        self.__data.extend(tuple(((sample.TimeStamp, self.system_info.socket_map[processor],
+        self.__data.extend(tuple(((sample.timestamp, self.system_info.socket_map[processor],
                                    self.system_info.core_type_map[processor],
                                    self.system_info.core_map[processor], self.system_info.thread_map[processor],
                                    processor, self.system_info.module_map[processor],
+                                   self.system_info.die_map.get(processor, np.nan),
                                    sample.tsc_count, sample.block_number,
                                    '$samplingTime', sample.duration)
                                   for index, processor in enumerate(self.system_info.unique_os_processors))))
 
     def _append_processed_samples(self, sample: _Sample) -> None:
         # append parameter order follows RawDataFrameColumns. All entries must be accounted for
-        self.__data.extend(tuple(((sample.TimeStamp, self.system_info.socket_map[processor],
+        self.__data.extend(tuple(((sample.timestamp, self.system_info.socket_map[processor],
                                    self.system_info.core_type_map[processor],
                                    self.system_info.core_map[processor], self.system_info.thread_map[processor],
                                    processor, self.system_info.module_map[processor],
+                                   self.system_info.die_map.get(processor, np.nan),
                                    sample.tsc_count, sample.block_number,
                                    '$processed_samples', 1)
                                   for index, processor in enumerate(self.system_info.unique_os_processors))))
