@@ -8,6 +8,7 @@ from functools import reduce
 from pathlib import Path
 from typing import List, Dict, Any, Union
 
+import numpy as np
 import pandas as pd
 
 from mpp.core.devices import Device, DeviceType
@@ -23,6 +24,8 @@ class UnitNames:
     CORE_TYPE: str
     CORE: str
     THREAD: str
+    DIE: str = ''
+    CORE_ARCH: str = ''
     MEMORY_CHANNELS: str = 'channels_populated'
 
 
@@ -84,7 +87,9 @@ class SystemInformationParser:
         self.__core_type_map = {}
         self.__unique_core_types = []
         self.__module_map = {}
+        self.__die_map = {}
         self.__has_modules = False
+        self.__has_die = False
         self._ref_tsc = 0
         self.__parser_state = None
         self.attributes: Dict[str, Any] = {}
@@ -150,6 +155,20 @@ class SystemInformationParser:
         """
         return self.__module_map
 
+    @property
+    def die_map(self):
+        """
+        :return: a dict mapping a logical core number to its CBB (Core Building Block)
+        """
+        return self.__die_map
+
+    @property
+    def has_die(self) -> bool:
+        """
+        :return: a bool specifying if the platform has die information (non-NaN die values)
+        """
+        return self.__has_die
+
     @property
     def has_modules(self) -> bool:
         """
@@ -738,12 +757,12 @@ class SystemInformationParser:
         else:
             self.__has_modules = True
 
+        if self.parser_attributes.units.DIE in df.columns:
+            df[self.parser_attributes.units.DIE] = df[self.parser_attributes.units.DIE].astype(int)
+            self.__has_die = True
+
         try:
-            df = pd.concat([df[[self.parser_attributes.units.OS_PROCESSOR, self.parser_attributes.units.SOCKET,
-                                self.parser_attributes.units.CORE, self.parser_attributes.units.THREAD]].astype(
-                int),
-                df[self.parser_attributes.units.CORE_TYPE], df[self.parser_attributes.units.MODULE].astype(int)],
-                axis=1)
+            df = self._get_processor_map_df(df)
             self.__socket_map = dict(zip(df[self.parser_attributes.units.OS_PROCESSOR].values,
                                          df[self.parser_attributes.units.SOCKET].values))
             self.__core_map = dict(zip(df[self.parser_attributes.units.OS_PROCESSOR].values,
@@ -754,14 +773,26 @@ class SystemInformationParser:
                                             df[self.parser_attributes.units.CORE_TYPE].str.lower().values))
             self.__module_map = dict(zip(df[self.parser_attributes.units.OS_PROCESSOR].values,
                                          df[self.parser_attributes.units.MODULE].values))
+            if self.parser_attributes.units.DIE in df.columns:
+                self.__die_map = dict(zip(df[self.parser_attributes.units.OS_PROCESSOR].values,
+                                      df[self.parser_attributes.units.DIE].values))
             self.__unique_core_types = list(set(self.core_type_map.values()))
             self.__unique_os_processors = list(self.core_map.keys())
 
-        except ValueError:
+        except ValueError as e:
             # TODO: log an error
             # Swallow exception so that the parser doesn't crash
             pass
 
+    def _get_processor_map_df(self, df):
+        str_columns = [self.parser_attributes.units.CORE_TYPE, self.parser_attributes.units.CORE_ARCH]
+        numeric_columns = list(set(df.columns) - set(str_columns))
+        numeric_columns = list(filter(lambda col: col in [getattr(self.parser_attributes.units, f) for f in
+                                                          self.parser_attributes.units.__dataclass_fields__],
+                                      numeric_columns))
+        df[numeric_columns] = df[numeric_columns].astype(int)
+        return df
+
     @abstractmethod
     def _set_ref_tsc(self):
         pass
