@@ -1,6 +1,6 @@
 /* DIE indexing 
 
-   Copyright (C) 2022-2025 Free Software Foundation, Inc.
+   Copyright (C) 2022-2024 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -24,13 +24,17 @@
 #include "cp-support.h"
 #include "c-lang.h"
 #include "ada-lang.h"
+#include "dwarf2/tag.h"
 #include "event-top.h"
+#include "exceptions.h"
 #include "split-name.h"
 #include "observable.h"
 #include "run-on-main-thread.h"
 #include <algorithm>
 #include "gdbsupport/gdb-safe-ctype.h"
 #include "gdbsupport/selftest.h"
+#include "gdbsupport/task-group.h"
+#include "gdbsupport/thread-pool.h"
 #include <chrono>
 #include <unordered_set>
 #include "cli/cli-cmds.h"
@@ -211,14 +215,15 @@ cooked_index_entry::matches (domain_search_flags kind) const
 /* See cooked-index.h.  */
 
 const char *
-cooked_index_entry::full_name (struct obstack *storage, bool for_main) const
+cooked_index_entry::full_name (struct obstack *storage, bool for_main,
+			       const char *default_sep) const
 {
   const char *local_name = for_main ? name : canonical;
 
   if ((flags & IS_LINKAGE) != 0 || get_parent () == nullptr)
     return local_name;
 
-  const char *sep = nullptr;
+  const char *sep = default_sep;
   switch (lang)
     {
     case language_cplus:
@@ -233,7 +238,9 @@ cooked_index_entry::full_name (struct obstack *storage, bool for_main) const
       break;
 
     default:
-      return local_name;
+      if (sep == nullptr)
+	return local_name;
+      break;
     }
 
   get_parent ()->write_scope (storage, sep, for_main);
@@ -284,7 +291,7 @@ cooked_index_shard::add (sect_offset die_offset, enum dwarf_tag tag,
 
 /* See cooked-index.h.  */
 
-gdb::unique_xmalloc_ptr<char>
+void
 cooked_index_shard::handle_gnat_encoded_entry (cooked_index_entry *entry,
 					       htab_t gnat_entries)
 {
@@ -294,7 +301,10 @@ cooked_index_shard::handle_gnat_encoded_entry (cooked_index_entry *entry,
      source charset does not affect the indexer directly.  */
   std::string canonical = ada_decode (entry->name, false, false, false);
   if (canonical.empty ())
-    return {};
+    {
+      entry->canonical = entry->name;
+      return;
+    }
   std::vector<std::string_view> names = split_name (canonical.c_str (),
 						    split_style::DOT_STYLE);
   std::string_view tail = names.back ();
@@ -325,7 +335,9 @@ cooked_index_shard::handle_gnat_encoded_entry (cooked_index_entry *entry,
     }
 
   entry->set_parent (parent);
-  return make_unique_xstrndup (tail.data (), tail.length ());
+  auto new_canon = make_unique_xstrndup (tail.data (), tail.length ());
+  entry->canonical = new_canon.get ();
+  m_names.push_back (std::move (new_canon));
 }
 
 /* See cooked-index.h.  */
@@ -385,17 +397,7 @@ cooked_index_shard::finalize (const parent_map_map *parent_maps)
       if ((entry->flags & IS_LINKAGE) != 0)
 	entry->canonical = entry->name;
       else if (entry->lang == language_ada)
-	{
-	  gdb::unique_xmalloc_ptr<char> canon_name
-	    = handle_gnat_encoded_entry (entry, gnat_entries.get ());
-	  if (canon_name == nullptr)
-	    entry->canonical = entry->name;
-	  else
-	    {
-	      entry->canonical = canon_name.get ();
-	      m_names.push_back (std::move (canon_name));
-	    }
-	}
+	handle_gnat_encoded_entry (entry, gnat_entries.get ());
       else if (entry->lang == language_cplus || entry->lang == language_c)
 	{
 	  void **slot = htab_find_slot (seen_names.get (), entry,
@@ -466,7 +468,7 @@ cooked_index_shard::find (const std::string &name, bool completing) const
 void
 cooked_index_worker::start ()
 {
-  gdb::thread_pool::g_thread_pool->post_task ([=] ()
+  gdb::thread_pool::g_thread_pool->post_task ([this] ()
   {
     try
       {
@@ -651,7 +653,7 @@ cooked_index::set_contents (vec_type &&vec, deferred_warnings *warn,
      finalization.  However, that would take a slot in the global
      thread pool, and if enough such tasks were submitted at once, it
      would cause a livelock.  */
-  gdb::task_group finalizers ([=] ()
+  gdb::task_group finalizers ([this, warn] ()
   {
     m_state->set (cooked_state::FINALIZED);
     m_state->write_to_cache (index_for_writing (), warn);
@@ -800,7 +802,8 @@ cooked_index::dump (gdbarch *arch)
       gdb_printf ("    [%zu] ((cooked_index_entry *) %p)\n", i++, entry);
       gdb_printf ("    name:       %s\n", entry->name);
       gdb_printf ("    canonical:  %s\n", entry->canonical);
-      gdb_printf ("    qualified:  %s\n", entry->full_name (&temp_storage, false));
+      gdb_printf ("    qualified:  %s\n",
+		  entry->full_name (&temp_storage, false, "::"));
       gdb_printf ("    DWARF tag:  %s\n", dwarf_tag_name (entry->tag));
       gdb_printf ("    flags:      %s\n", to_string (entry->flags).c_str ());
       gdb_printf ("    DIE offset: %s\n", sect_offset_str (entry->die_offset));
