@@ -75,7 +75,7 @@ protected:
     Status Convert8u32f(Image *pSrcData)
     {
         IppStatus ippSts;
-        IppiSize roi = {static_cast<int>(pSrcData->m_size.width), static_cast<int>(pSrcData->m_size.height)};
+        IppiSize roi{static_cast<int>(pSrcData->m_size.width), static_cast<int>(pSrcData->m_size.height)};
 
         if (pSrcData->m_samples == 1) {
             ippSts =
@@ -100,7 +100,7 @@ protected:
     Status Convert32f8u(Image *pDstData)
     {
         IppStatus ippSts;
-        IppiSize roi = {static_cast<int>(pDstData->m_size.width), static_cast<int>(pDstData->m_size.height)};
+        IppiSize roi{static_cast<int>(pDstData->m_size.width), static_cast<int>(pDstData->m_size.height)};
 
         if (pDstData->m_samples == 1) {
             ippSts = ippiConvert_32f8u_C1R((Ipp32f *)m_tmpData32f.ptr(), (int)m_tmpData32f.m_step, (Ipp8u *)pDstData->ptr(), (int)pDstData->m_step,
