@@ -298,22 +298,35 @@ public:
         if (!m_pThreads || !m_pParams)
             return STS_ERR_ALLOC;
 
-        unsigned int iBlockSize = (unsigned int)(pSrcImage->m_size.height / m_iThreads);
-        unsigned int iRemainder = (unsigned int)(pSrcImage->m_size.height - iBlockSize * m_iThreads);
+        const long long maskHalfHeight = m_filterBoxMask.height / 2;
+
+        const long long iBlockSize1 = pSrcImage->m_size.height / m_iThreads;
+        const long long iBlockSize2 = iBlockSize1 + 1;
+
+        const unsigned int iThreads2 = static_cast<unsigned int>(pSrcImage->m_size.height % m_iThreads);
+        const unsigned int iThreads1 = m_iThreads - iThreads2;
 
         IppiSize roiSize;
         int iBufferSize = 0;
 
+        long long y = 0LL;
         for (unsigned int i = 0; i < m_iThreads; i++) {
-            m_pParams[i].roi.x = 0;
-            m_pParams[i].roi.y = i * iBlockSize;
-            m_pParams[i].roi.width = pSrcImage->m_size.width;
-            m_pParams[i].roi.height = (i == m_iThreads) ? iRemainder : iBlockSize;
+            const unsigned int iBlockSize = i < iThreads1 ? iBlockSize1 : iBlockSize2;
 
-            if (i != 0) // non-top
-                m_pParams[i].border = (IppiBorderType)(m_pParams[i].border | ippBorderInMemTop);
-            if (i != (m_iThreads - 1)) // non-bottom
-                m_pParams[i].border = (IppiBorderType)(m_pParams[i].border | ippBorderInMemBottom);
+            m_pParams[i].roi.x = 0LL;
+            m_pParams[i].roi.y = y;
+            m_pParams[i].roi.width = pSrcImage->m_size.width;
+            m_pParams[i].roi.height = iBlockSize;
+
+            if (maskHalfHeight > 0) {
+                if (y >= maskHalfHeight) {
+                    m_pParams[i].border = static_cast<IppiBorderType>(m_pParams[i].border | ippBorderInMemTop);
+                }
+                if (y + (iBlockSize - 1) + maskHalfHeight < pSrcImage->m_size.height) {
+                    m_pParams[i].border = static_cast<IppiBorderType>(m_pParams[i].border | ippBorderInMemBottom);
+                }
+            }
+            y += iBlockSize;
 
             roiSize.width = (int)m_pParams[i].roi.width;
             roiSize.height = (int)m_pParams[i].roi.height;
