@@ -1,7 +1,6 @@
 /* Interface between gdb and its extension languages.
 
-   Copyright (C) 2014-2025 Free Software Foundation, Inc.
-   Copyright (C) 2018-2025 Intel Corporation
+   Copyright (C) 2014-2024 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -85,7 +84,7 @@ const struct extension_language_defn extension_language_gdb =
 
 static const std::array<const extension_language_defn *, 2> extension_languages
 {
-  /* To preserve existing behaviour, python should always appear first.  */
+  /* To preserve existing behavior, python should always appear first.  */
   &extension_language_python,
   &extension_language_guile,
 };
@@ -585,7 +584,8 @@ apply_ext_lang_ptwrite_filter (btrace_thread_info *btinfo)
    preserve_one_value.  */
 
 void
-preserve_ext_lang_values (struct objfile *objfile, htab_t copied_types)
+preserve_ext_lang_values (struct objfile *objfile,
+			  copied_types_hash_t &copied_types)
 {
   for (const struct extension_language_defn *extlang : extension_languages)
     {
@@ -681,7 +681,7 @@ static bool quit_flag;
 
 /* The current extension language we've called out to, or
    extension_language_gdb if there isn't one.
-   This must be set everytime we call out to an extension language, and reset
+   This must be set every time we call out to an extension language, and reset
    to the previous value when it returns.  Note that the previous value may
    be a different (or the same) extension language.  */
 static const struct extension_language_defn *active_ext_lang
@@ -1054,7 +1054,7 @@ ext_lang_print_insn (struct gdbarch *gdbarch, CORE_ADDR address,
 
 /* See extension.h.  */
 
-ext_lang_missing_debuginfo_result
+ext_lang_missing_file_result
 ext_lang_handle_missing_debuginfo (struct objfile *objfile)
 {
   for (const struct extension_language_defn *extlang : extension_languages)
@@ -1062,7 +1062,7 @@ ext_lang_handle_missing_debuginfo (struct objfile *objfile)
       if (extlang->ops == nullptr
 	  || extlang->ops->handle_missing_debuginfo == nullptr)
 	continue;
-      ext_lang_missing_debuginfo_result result
+      ext_lang_missing_file_result result
 	= extlang->ops->handle_missing_debuginfo (extlang, objfile);
       if (!result.filename ().empty () || result.try_again ())
 	return result;
@@ -1071,6 +1071,28 @@ ext_lang_handle_missing_debuginfo (struct objfile *objfile)
   return {};
 }
 
+/* See extension.h.  */
+
+ext_lang_missing_file_result
+ext_lang_find_objfile_from_buildid (program_space *pspace,
+				    const struct bfd_build_id *build_id,
+				    const char *filename)
+{
+  for (const struct extension_language_defn *extlang : extension_languages)
+    {
+      if (extlang->ops == nullptr
+	  || extlang->ops->find_objfile_from_buildid == nullptr)
+	continue;
+      ext_lang_missing_file_result result
+	= extlang->ops->find_objfile_from_buildid (extlang, pspace, build_id,
+						   filename);
+      if (!result.filename ().empty () || result.try_again ())
+	return result;
+    }
+
+  return {};
+}
+
 /* Called via an observer before gdb prints its prompt.
    Iterate over the extension languages giving them a chance to
    change the prompt.  The first one to change the prompt wins,
