@@ -1,7 +1,6 @@
 /* Generate a core file for the inferior process.
 
-   Copyright (C) 2001-2025 Free Software Foundation, Inc.
-   Copyright (C) 2014-2025 Intel Corporation
+   Copyright (C) 2001-2024 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -271,13 +270,14 @@ call_target_sbrk (int sbrk_arg)
   struct value *sbrk_fn, *ret;
   bfd_vma tmp;
 
-  if (lookup_minimal_symbol ("sbrk", NULL, NULL).minsym != NULL)
+  if (lookup_minimal_symbol (current_program_space, "sbrk").minsym != nullptr)
     {
       sbrk_fn = find_function_in_inferior ("sbrk", &sbrk_objf);
       if (sbrk_fn == NULL)
 	return (bfd_vma) 0;
     }
-  else if (lookup_minimal_symbol ("_sbrk", NULL, NULL).minsym != NULL)
+  else if (lookup_minimal_symbol (current_program_space, "_sbrk").minsym
+	   != nullptr)
     {
       sbrk_fn = find_function_in_inferior ("_sbrk", &sbrk_objf);
       if (sbrk_fn == NULL)
@@ -930,9 +930,8 @@ Argument is optional filename.  Default filename is 'core.PROCESS_ID'."));
 			    &maint_gcore_emit_xml_tdesc, _("\
 Set whether gcore emits a xml-target-description."), _("\
 Show whether gore emits a xml-target-description."), _("\
-By default, gcore emits the note NT_GDB_TDESC containing an \
-xml-target-description.  Disabling this setting will cause gcore \
-to no longer emit this note."),
+By default, gcore emits the note NT_GDB_TDESC.\n\
+Disabling this setting will cause gcore to no longer emit this note."),
 			    nullptr,
 			    show_gcore_xml_target_description,
 			    &maint_gcore_set_cmdlist,
