@@ -1,7 +1,6 @@
 # Dynamic architecture support for GDB, the GNU debugger.
 
-# Copyright (C) 1998-2025 Free Software Foundation, Inc.
-# Copyright (C) 2019-2025 Intel Corporation
+# Copyright (C) 1998-2024 Free Software Foundation, Inc.
 
 # This file is part of GDB.
 
@@ -552,7 +551,6 @@ Value(
     invalid=False,
 )
 
-
 Method(
     comment="""
 Convert stab register number (from `r' declaration) to a gdb REGNUM.
@@ -1297,7 +1295,7 @@ non-significant bits and sign-extends things as needed.  It gets used to
 remove non-address bits from pointers used for watchpoints.
 """,
     type="CORE_ADDR",
-    name="remove_non_addr_bits_wpt",
+    name="remove_non_address_bits_watchpoint",
     params=[("CORE_ADDR", "pointer")],
     predefault="default_remove_non_address_bits",
     invalid=False,
@@ -1316,7 +1314,7 @@ non-significant bits and sign-extends things as needed.  It gets used to
 remove non-address bits from pointers used for breakpoints.
 """,
     type="CORE_ADDR",
-    name="remove_non_addr_bits_bpt",
+    name="remove_non_address_bits_breakpoint",
     params=[("CORE_ADDR", "pointer")],
     predefault="default_remove_non_address_bits",
     invalid=False,
@@ -1332,11 +1330,10 @@ of the address.
 
 Given a pointer for the architecture, this hook removes all the
 non-significant bits and sign-extends things as needed.  It gets used to
-remove non-address bits from any pointer used to access memory (called in
-memory_xfer_partial).
+remove non-address bits from any pointer used to access memory.
 """,
     type="CORE_ADDR",
-    name="remove_non_addr_bits_memory",
+    name="remove_non_address_bits_memory",
     params=[("CORE_ADDR", "pointer")],
     predefault="default_remove_non_address_bits",
     invalid=False,
@@ -1659,9 +1656,18 @@ Method(
 )
 
 Method(
-    type="unsigned int",
-    name="address_space_from_type_flags",
-    params=[("type_instance_flags", "type_flags")],
+    comment="""
+Translate the given address ADDR using the address class TYPE_INSTANCE_FLAGS.
+ADDR_SPACE_PTR is set to the address space of the translated address.
+Returns the translated address.
+""",
+    type="CORE_ADDR",
+    name="translate_address",
+    params=[
+        ("type_instance_flags", "type_flags"),
+        ("CORE_ADDR", "addr"),
+        ("unsigned int *", "addr_space_ptr")
+    ],
     predicate=True,
     invalid=True,
 )
@@ -2939,6 +2945,26 @@ information about it is available via the 'info devices' command.
     invalid=False,
 )
 
+Method(
+    comment="""
+Examine the core file bfd object CBFD and try to extract the name of
+the current executable and the argument list, which are return in a
+core_file_exec_context object.
+
+If for any reason the details can't be extracted from CBFD then an
+empty context is returned.
+
+It is required that the current inferior be the one associated with
+CBFD, strings are read from the current inferior using target methods
+which all assume current_inferior() is the one to read from.
+""",
+    type="core_file_exec_context",
+    name="core_parse_exec_context",
+    params=[("bfd *", "cbfd")],
+    predefault="default_core_parse_exec_context",
+    invalid=False,
+)
+
 Method(
     comment="Reserve space on the stack for a value of the given type.",
     type="CORE_ADDR",
@@ -3067,12 +3093,12 @@ Return a gdbarch corresponding to the given target description.
 Method(
     comment="""
 Some targets support special hardware-assisted control-flow protection
-technologies.  For example, the Control-flow Enforcement Technology (CET)
-on x86 provides a shadow stack and indirect branch tracking.
+technologies.  For example, the Intel Control-Flow Enforcement Technology
+(Intel CET) on x86 provides a shadow stack and indirect branch tracking.
 
 For GDB shadow stack support the following methods or values have to be
 provided:
-- get_shadow_stack_pointer for displaced stepping 
+- get_shadow_stack_pointer for displaced stepping
 - address_in_shadow_stack_memory_range and the value
   shadow_stack_element_size_aligned for inferior calls.
 For inferior calls, the gdbarch value ssp_regnum has to be provided, too.
@@ -3083,7 +3109,7 @@ Return current shadow stack pointer, if possible.
 """,
     type="std::optional<CORE_ADDR>",
     name="get_shadow_stack_pointer",
-    params=[],
+    params=[("regcache *", "regcache"), ("bool &", "shadow_stack_enabled")],
     predefault="default_get_shadow_stack_pointer",
     invalid=False,
 )
@@ -3096,11 +3122,8 @@ the case, assign the shadow stack memory range to RANGE
 """,
     type="bool",
     name="address_in_shadow_stack_memory_range",
-    params=[
-	("CORE_ADDR", "ssp"),
-	("std::pair<CORE_ADDR, CORE_ADDR> *", "range")
-    ],
-    predicate=True
+    params=[("CORE_ADDR", "ssp"), ("std::pair<CORE_ADDR, CORE_ADDR> *", "range")],
+    predicate=True,
 )
 
 Value(
@@ -3111,7 +3134,7 @@ element.
     type="int",
     name="shadow_stack_element_size_aligned",
     predefault="8",
-    invalid=False
+    invalid=False,
 )
 
 Method(
