@@ -1,6 +1,5 @@
 /* Multi-process/thread control defs for GDB, the GNU debugger.
-   Copyright (C) 1987-2025 Free Software Foundation, Inc.
-   Copyright (C) 2017-2025 Intel Corporation
+   Copyright (C) 1987-2024 Free Software Foundation, Inc.
    Contributed by Lynx Real-Time Systems, Inc.  Los Gatos, CA.
    
 
@@ -19,8 +18,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef GDBTHREAD_H
-#define GDBTHREAD_H
+#ifndef GDB_GDBTHREAD_H
+#define GDB_GDBTHREAD_H
 
 struct symtab;
 
@@ -38,6 +37,7 @@ struct symtab;
 #include "gdbsupport/intrusive_list.h"
 #include "thread-fsm.h"
 #include "language.h"
+#include <list>
 
 struct inferior;
 struct process_stratum_target;
@@ -216,8 +216,14 @@ struct thread_control_state
      step" behaves like "on" or "off".  */
   int stepping_command = 0;
 
+  /* A list of conditional breakpoints (if any) that the thread is evaluating.
+     This list is tracking breakpoint hits during expressions evaluation to make
+     sure we don't run into cycles.  */
+  std::list<breakpoint *> cond_eval_bps;
+
   /* True if the thread is evaluating a BP condition.  */
-  bool in_cond_eval = false;
+  bool in_cond_eval () const
+  { return !cond_eval_bps.empty (); };
 
   /* Whether the thread was replaying when the command was issued.  */
   bool is_replaying = false;
@@ -264,7 +270,7 @@ struct thread_suspend_state
      - If the thread is running, then this field has its value removed by
        calling stop_pc.reset() (see thread_info::set_executing()).
        Attempting to read a std::optional with no value is undefined
-       behaviour and will trigger an assertion error when _GLIBCXX_DEBUG is
+       behavior and will trigger an assertion error when _GLIBCXX_DEBUG is
        defined, which should make error easier to track down.  */
   std::optional<CORE_ADDR> stop_pc;
 };
@@ -704,7 +710,7 @@ private:
      1.2:[0-31]       Thread B    0x15ebc6ed in bar () at foo.c:20
 
      (gdb) thread 1.1:31
-     [Switching to thread 1.1:31 (Thread A lane 31)]  */
+     [Switching to thread 1.1:31]  */
   int simd_lane_num = 0;
 
   /* Cached active lanes mask for the thread.  The caching occurs during
@@ -881,6 +887,9 @@ extern bool in_thread_list (process_stratum_target *targ, ptid_t ptid);
    global id, not the system's).  */
 extern int valid_global_thread_id (int global_id);
 
+/* Check if SIMD_LANE is valid for the thread with global id GLOBAL_ID.  */
+extern bool valid_thread_simd_lane (int global_id, int simd_lane);
+
 /* Find thread by GDB global thread ID.  */
 struct thread_info *find_thread_global_id (int global_id);
 
@@ -1314,54 +1323,16 @@ extern int find_first_active_simd_lane (unsigned int mask);
 extern bool is_simd_lane_active (unsigned int mask, int lane);
 
 enum class simd_lane_order {
-  SIMD_LANE_ORDER_ASCENDING,
-  SIMD_LANE_ORDER_DESCENDING,
+  ASCENDING,
+  DESCENDING,
 };
 
-/* Execute function FUNC for all unmasked lanes in MASK.  FUNC should
-   match the following:
-
-   bool func (int lane_num)
-
-   First integer argument is the lane number, which corresponds
+/* Execute function FUNC for all unmasked lanes in MASK.
+   The integer argument of FUNC is the lane number, which corresponds
    to the current call.  If FUNC returns false, the loop breaks.
    ORDER defines the order of SIMD lane loop: ascending or descending.  */
-template<typename Func>
-void
-for_active_lanes (unsigned int mask, Func func,
-		  simd_lane_order order
-		    = simd_lane_order::SIMD_LANE_ORDER_ASCENDING)
-{
-  if (order == simd_lane_order::SIMD_LANE_ORDER_ASCENDING)
-    {
-      int lane = 0;
-
-      while (mask != 0)
-	{
-	  if ((mask & 0x1) != 0)
-	    {
-	      if (!func (lane))
-		break;
-	    }
-	  ++lane;
-	  mask >>= 1;
-	}
-    }
-  else
-    {
-      int lane = sizeof (unsigned int) * 8 - 1;
-
-      while (lane >= 0)
-	{
-	  if (((mask >> lane) & 0x1) != 0)
-	    {
-	      if (!func (lane))
-		break;
-	    }
-	  --lane;
-	}
-    }
-}
+extern void foreach_lane (unsigned int mask, std::function<bool (int)> func,
+			  simd_lane_order order = simd_lane_order::ASCENDING);
 
 /* Return THREAD's name.
 
@@ -1390,4 +1361,4 @@ extern void thread_try_catch_cmd (thread_info *thr,
 
 extern const char *thread_state_string (enum thread_state state);
 
-#endif /* GDBTHREAD_H */
+#endif /* GDB_GDBTHREAD_H */
