@@ -1,7 +1,6 @@
 /* Target-dependent code for the i386.
 
-   Copyright (C) 2001-2025 Free Software Foundation, Inc.
-   Copyright (C) 2013-2025 Intel Corporation
+   Copyright (C) 2001-2024 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -18,8 +17,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef I386_TDEP_H
-#define I386_TDEP_H
+#ifndef GDB_I386_TDEP_H
+#define GDB_I386_TDEP_H
 
 #include "gdbarch.h"
 #include "infrun.h"
@@ -73,37 +72,37 @@ struct i386_gdbarch_tdep : gdbarch_tdep_base
   size_t sizeof_fpregset = 0;
 
   /* Register number for %st(0).  The register numbers for the other
-     registers follow from this one.  Set this to -1 to indicate the
-     absence of an FPU.  */
-  int st0_regnum = 0;
+     registers follow from this one.  Set this to a value >= 0 if FPU is
+     present.  */
+  int st0_regnum = -1;
 
   /* Number of MMX registers.  */
   int num_mmx_regs = 0;
 
-  /* Register number for %mm0.  Set this to -1 to indicate the absence
-     of MMX support.  */
-  int mm0_regnum = 0;
+  /* Register number for %mm0.  Set this to a value >= 0 if MMX is
+     supported.  */
+  int mm0_regnum = -1;
 
   /* Number of pseudo YMM registers.  */
   int num_ymm_regs = 0;
 
-  /* Register number for %ymm0.  Set this to -1 to indicate the absence
-     of pseudo YMM register support.  */
-  int ymm0_regnum = 0;
+  /* Register number for %ymm0.  Set this to a value >= 0 if pseudo YMM
+     registers are supported.  */
+  int ymm0_regnum = -1;
 
   /* Number of AVX512 OpMask registers (K-registers)  */
   int num_k_regs = 0;
 
-  /* Register number for %k0.  Set this to -1 to indicate the absence
-     of AVX512 OpMask register support.  */
-  int k0_regnum = 0;
+  /* Register number for %k0.  Set this to a value >= 0 if AVX512 OpMask
+     is supported.  */
+  int k0_regnum = -1;
 
   /* Number of pseudo ZMM registers ($zmm0-$zmm31).  */
   int num_zmm_regs = 0;
 
-  /* Register number for %zmm0.  Set this to -1 to indicate the absence
-     of pseudo ZMM register support.  */
-  int zmm0_regnum = 0;
+  /* Register number for %zmm0.  Set this to a value >= 0 if pseudo ZMM
+     registers are supported.  */
+  int zmm0_regnum = -1;
 
   /* Number of byte registers.  */
   int num_byte_regs = 0;
@@ -111,25 +110,26 @@ struct i386_gdbarch_tdep : gdbarch_tdep_base
   /* Number of pseudo lower byte registers.  Only used for AMD64.  */
   int num_lower_byte_regs = 0;
 
-  /* Register pseudo number for %al.  */
-  int al_regnum = 0;
+  /* Register pseudo number for %al.  If supported, set this to a
+     value >= 0.  */
+  int al_regnum = -1;
 
   /* Number of pseudo word registers.  */
   int num_word_regs = 0;
 
-  /* Register number for %ax.  */
-  int ax_regnum = 0;
+  /* Register number for %ax.  If supported, set this to a value >= 0.  */
+  int ax_regnum = -1;
 
   /* Number of pseudo dword registers.  */
   int num_dword_regs = 0;
 
-  /* Register number for %eax.  Set this to -1 to indicate the absence
-     of pseudo dword register support.  */
-  int eax_regnum = 0;
+  /* Register number for %eax.  Set this to a value >= 0 if pseudo dword
+     registers are supported.  */
+  int eax_regnum = -1;
 
-  /* Register number for %eip.  Set this to -1 to indicate the absence
-     of %eip support.  Only used for AMD64.  */
-  int eip_regnum = 0;
+  /* Register number for %eip.  Set this to a value >= 0 in case of %eip
+     support.  Only used for AMD64.  */
+  int eip_regnum = -1;
 
   /* Number of core registers.  */
   int num_core_regs = 0;
@@ -143,14 +143,16 @@ struct i386_gdbarch_tdep : gdbarch_tdep_base
   /* Number of SSE registers added in AVX512.  */
   int num_xmm_avx512_regs = 0;
 
-  /* Register number of XMM16, the first XMM register added in AVX512.  */
-  int xmm16_regnum = 0;
+  /* Register number of XMM16, the first XMM register added in AVX512.
+     Set this to a value >= 0 if XMM registers are supported.  */
+  int xmm16_regnum = -1;
 
   /* Number of YMM registers added in AVX512.  */
   int num_ymm_avx512_regs = 0;
 
-  /* Register number of YMM16, the first YMM register added in AVX512.  */
-  int ymm16_regnum = 0;
+  /* Register number of YMM16, the first YMM register added in AVX512.
+     Set this to a value >= 0 if YMM registers are supported.  */
+  int ymm16_regnum = -1;
 
   /* Bits of the extended control register 0 (the XFEATURE_ENABLED_MASK
      register), excluding the x87 bit, which are supported by this GDB.  */
@@ -175,30 +177,30 @@ struct i386_gdbarch_tdep : gdbarch_tdep_base
   /* Dword register names.  Only used for AMD64.  */
   const char * const *dword_names = nullptr;
 
-  /* Register number for %ymm0h.  Set this to -1 to indicate the absence
-     of upper YMM register support.  */
-  int ymm0h_regnum = 0;
+  /* Register number for %ymm0h.  Set this to a value >= 0 if they are
+     supported.  */
+  int ymm0h_regnum = -1;
 
   /* Upper YMM register names.  Only used for tdesc_numbered_register.  */
   const char * const *ymmh_register_names = nullptr;
 
-  /* Register number for %ymm16h.  Set this to -1 to indicate the absence
-  of support for YMM16-31.  */
-  int ymm16h_regnum = 0;
+  /* Register number for %ymm16h.  Set this to a value >= 0 if they are
+     supported.  */
+  int ymm16h_regnum = -1;
 
   /* YMM16-31 register names.  Only used for tdesc_numbered_register.  */
   const char * const *ymm16h_register_names = nullptr;
 
-  /* Register number for %r16.  Set this to -1 to indicate the absence
-     r16-r31 registers.  */
-  int r16_regnum = 0;
+  /* Register number for %r16.  Set this to a value >= 0 if r16-r31
+     registers are supported.  Only used for AMD64.  */
+  int r16_regnum = -1;
 
   /* r16-r31 register names.  Only used for tdesc_numbered_register.  */
   const char * const *apx_register_names = nullptr;
 
-  /* Register number for %zmm0h.  Set this to -1 to indicate the absence
-     of ZMM_HI256 register support.  */
-  int zmm0h_regnum = 0;
+  /* Register number for %zmm0h.  Set this to a value >= 0 if ZMM_HI256
+     registers are supported.  */
+  int zmm0h_regnum = -1;
 
   /* OpMask register names.  */
   const char * const *k_register_names = nullptr;
@@ -215,40 +217,43 @@ struct i386_gdbarch_tdep : gdbarch_tdep_base
   /* Number of PKEYS registers.  */
   int num_pkeys_regs = 0;
 
-  /* Register number for PKRU register.  */
-  int pkru_regnum = 0;
+  /* Register number for PKRU register.  If supported, set this to a value
+     >= 0.  */
+  int pkru_regnum = -1;
 
   /* PKEYS register names.  */
   const char * const *pkeys_register_names = nullptr;
 
-  /* Shadow stack pointer register.  */
-  int ssp_regnum = 0;
-
-  /* Register number for AMX tilecfg register, including pseudo register.  */
-  int tilecfg_regnum = 0;
-  int tilecfg_raw_regnum = 0;
+  /* Register number for AMX tilecfg register, including pseudo register.
+     If supported, set them to a value >= 0.  */
+  int tilecfg_regnum = -1;
+  int tilecfg_raw_regnum = -1;
 
   /* Number of tilecfg registers, including pseudo register.  */
   int num_tilecfg_regs = 0;
-  int num_tilecfg_raw_regs = 0;
 
-  /* Register number for AMX tmm register, including pseudo registers.  */
-  int tmm_regnum = 0;
-  int tiledata_regnum = 0;
+  /* Register number for AMX tildata register, including the first pseudo
+     register from tmm0-tmm7.  If supported, set them to a value >= 0.  */
+  int tmm_regnum = -1;
+  int tiledata_regnum = -1;
 
   /* Number of AMX tmm registers, including pseudo registers.  */
   int num_tmm_regs = 0;
   int num_tiledata_regs = 0;
 
   /* AMX register names.  */
-  const char * const *tilecfg_raw_register_names;
-  const char * const *tilecfg_register_names;
-  const char * const *tmm_register_names;
-  const char * const *tiledata_register_names;
+  const char * const *tilecfg_raw_register_names = nullptr;
+  const char * const *tilecfg_register_names = nullptr;
+  const char * const *tmm_register_names = nullptr;
+  const char * const *tiledata_register_names = nullptr;
 
-  /* Register number for %fsbase.  Set this to -1 to indicate the
-     absence of segment base registers.  */
-  int fsbase_regnum = 0;
+  /* Register number for the shadow stack pointer register.  If supported,
+     set this to a value >= 0.  */
+  int ssp_regnum = -1;
+
+  /* Register number for %fsbase.  If supported, set this to a value
+     >= 0.  */
+  int fsbase_regnum = -1;
 
   /* Target description.  */
   const struct target_desc *tdesc = nullptr;
@@ -355,8 +360,6 @@ enum i386_regnum
   I386_ZMM7H_REGNUM = I386_ZMM0H_REGNUM + 7,
   I386_PKRU_REGNUM,
   I386_PL3_SSP_REGNUM,
-  I386_AMX_TILECFG_RAW_REGNUM,
-  I386_AMX_TILEDATA_REGNUM,
   I386_FSBASE_REGNUM,
   I386_GSBASE_REGNUM
 };
@@ -389,6 +392,7 @@ enum record_i386_regnum
   X86_RECORD_ES_REGNUM,
   X86_RECORD_FS_REGNUM,
   X86_RECORD_GS_REGNUM,
+  X86_RECORD_XMM0_REGNUM,
 };
 
 #define I386_NUM_GREGS	16
@@ -515,8 +519,11 @@ extern int i386_svr4_reg_to_regnum (struct gdbarch *gdbarch, int reg);
 
 extern int i386_process_record (struct gdbarch *gdbarch,
 				struct regcache *regcache, CORE_ADDR addr);
-extern const struct target_desc *i386_target_description (uint64_t xcr0,
-							  bool segments);
+
+/* Return the target description for the specified xsave features as
+   defined in XSTATE_BV_MASK and SEGMENTS.  */
+extern const struct target_desc *i386_target_description
+  (uint64_t xstate_bv_mask, bool segments);
 
 /* Functions and variables exported from i386-bsd-tdep.c.  */
 
@@ -624,4 +631,4 @@ private:
   std::vector<std::pair<uint16_t, uint8_t>> columns_and_rows;
 };
 
-#endif /* i386-tdep.h */
+#endif /* GDB_I386_TDEP_H */
