@@ -1,7 +1,6 @@
 /* Intel 387 floating point stuff.
 
-   Copyright (C) 1988-2025 Free Software Foundation, Inc.
-   Copyright (C) 2013-2025 Intel Corporation
+   Copyright (C) 1988-2024 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -351,7 +350,7 @@ i387_register_to_value (const frame_info_ptr &frame, int regnum,
 			int *optimizedp, int *unavailablep)
 {
   struct gdbarch *gdbarch = get_frame_arch (frame);
-  gdb_byte from[register_size (gdbarch, regnum)];
+  gdb::byte_vector from (register_size (gdbarch, regnum));
 
   gdb_assert (i386_fp_regnum_p (gdbarch, regnum));
 
@@ -366,13 +365,13 @@ i387_register_to_value (const frame_info_ptr &frame, int regnum,
 
   /* Convert to TYPE.  */
   auto from_view
-    = gdb::make_array_view (from, register_size (gdbarch, regnum));
+    = gdb::make_array_view (from.data (), register_size (gdbarch, regnum));
   frame_info_ptr next_frame = get_next_frame_sentinel_okay (frame);
   if (!get_frame_register_bytes (next_frame, regnum, 0, from_view, optimizedp,
 				 unavailablep))
     return 0;
 
-  target_float_convert (from, i387_ext_type (gdbarch), to, type);
+  target_float_convert (from.data (), i387_ext_type (gdbarch), to, type);
   *optimizedp = *unavailablep = 0;
   return 1;
 }
@@ -385,7 +384,7 @@ i387_value_to_register (const frame_info_ptr &frame, int regnum,
 			struct type *type, const gdb_byte *from)
 {
   struct gdbarch *gdbarch = get_frame_arch (frame);
-  gdb_byte to[register_size (gdbarch, regnum)];
+  gdb::byte_vector to (register_size (gdbarch, regnum));
 
   gdb_assert (i386_fp_regnum_p (gdbarch, regnum));
 
@@ -399,8 +398,8 @@ i387_value_to_register (const frame_info_ptr &frame, int regnum,
 
   /* Convert from TYPE.  */
   struct type *to_type = i387_ext_type (gdbarch);
-  target_float_convert (from, type, to, to_type);
-  auto to_view = gdb::make_array_view (to, to_type->length ());
+  target_float_convert (from, type, to.data (), to_type);
+  auto to_view = gdb::make_array_view (to.data (), to_type->length ());
   put_frame_register (get_next_frame_sentinel_okay (frame), regnum, to_view);
 }
 
@@ -763,11 +762,11 @@ static int xsave_avxh_offset[] =
   (xsave + (tdep)->xsave_layout.avx_offset			\
    + xsave_avxh_offset[regnum - I387_YMM0H_REGNUM (tdep)])
 
-/* At xsave_ymm_avx512_offset[REGNUM] you'll find the relative offset
+/* At xsave_ymm_h_avx512_offset[REGNUM] you'll find the relative offset
    within the ZMM region of the XSAVE extended state where the second
    128bits of GDB register YMM16 + REGNUM is stored.  */
 
-static int xsave_ymm_avx512_offset[] =
+static int xsave_ymm_h_avx512_offset[] =
 {
   16 + 0 * 64,		/* %ymm16 through...  */
   16 + 1 * 64,
@@ -787,9 +786,9 @@ static int xsave_ymm_avx512_offset[] =
   16 + 15 * 64		/* ...  %ymm31 (128 bits each).  */
 };
 
-#define XSAVE_YMM_AVX512_ADDR(tdep, xsave, regnum)			\
+#define XSAVE_YMM_H_AVX512_ADDR(tdep, xsave, regnum)			\
   (xsave + (tdep)->xsave_layout.zmm_offset				\
-   + xsave_ymm_avx512_offset[regnum - I387_YMM16H_REGNUM (tdep)])
+   + xsave_ymm_h_avx512_offset[regnum - I387_YMM16H_REGNUM (tdep)])
 
 /* At xsave_xmm_avx512_offset[REGNUM] you'll find the relative offset
    within the ZMM region of the XSAVE extended state where the first
@@ -1002,7 +1001,10 @@ i387_guess_xsave_layout (uint64_t xcr0, size_t xsave_size,
       layout.zmm_h_offset = 1152;
       layout.zmm_offset = 1664;
     }
-  else if (HAS_AVX (xcr0) && xsave_size == 832)
+  /* As MPX has been removed, we need the additional check
+     (xsave_size == 1088) to allow reading AVX registers from corefiles
+     on CPUs with MPX as the highest supported feature.  */
+  else if (HAS_AVX (xcr0) && (xsave_size == 832 || xsave_size == 1088))
     {
       /* Intel and AMD CPUs supporting AVX.  */
       layout.avx_offset = 576;
@@ -1103,7 +1105,6 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
   unsigned int zmm_endlo_regnum = I387_ZMM0H_REGNUM (tdep)
 				  + std::min (tdep->num_zmm_regs, 16);
   ULONGEST clear_bv;
-  static const gdb_byte zero[I386_MAX_REGISTER_SIZE] = { 0 };
   enum
     {
       none = 0x0,
@@ -1185,14 +1186,14 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 
     case apx:
       if ((clear_bv & X86_XSTATE_APX_F))
-	regcache->raw_supply (regnum, zero);
+	regcache->raw_supply_zeroed (regnum);
       else
 	regcache->raw_supply (regnum, XSAVE_APX_EGPR_ADDR (tdep, regs, regnum));
       return;
 
     case tilecfg:
       if ((clear_bv & X86_XSTATE_TILECFG))
-	regcache->raw_supply (regnum, zero);
+	regcache->raw_supply_zeroed (regnum);
       else
 	{
 	  regcache->raw_supply (regnum,
@@ -1202,7 +1203,7 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 
     case tiledata:
       if ((clear_bv & X86_XSTATE_TILEDATA))
-	regcache->raw_supply (regnum, zero);
+	regcache->raw_supply_zeroed (regnum);
       else
 	{
 	  regcache->raw_supply (regnum,
@@ -1212,14 +1213,14 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 
     case pkeys:
       if ((clear_bv & X86_XSTATE_PKRU))
-	regcache->raw_supply (regnum, zero);
+	regcache->raw_supply_zeroed (regnum);
       else
 	regcache->raw_supply (regnum, XSAVE_PKEYS_ADDR (tdep, regs, regnum));
       return;
 
     case avx512_zmm0_h:
       if ((clear_bv & X86_XSTATE_ZMM_H))
-	regcache->raw_supply (regnum, zero);
+	regcache->raw_supply_zeroed (regnum);
       else
 	regcache->raw_supply (regnum,
 			      XSAVE_AVX512_ZMM0_H_ADDR (tdep, regs, regnum));
@@ -1227,7 +1228,7 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 
     case avx512_zmm16_h:
       if ((clear_bv & X86_XSTATE_ZMM))
-	regcache->raw_supply (regnum, zero);
+	regcache->raw_supply_zeroed (regnum);
       else
 	regcache->raw_supply (regnum,
 			      XSAVE_AVX512_ZMM16_H_ADDR (tdep, regs, regnum));
@@ -1235,22 +1236,22 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 
     case avx512_k:
       if ((clear_bv & X86_XSTATE_K))
-	regcache->raw_supply (regnum, zero);
+	regcache->raw_supply_zeroed (regnum);
       else
 	regcache->raw_supply (regnum, XSAVE_AVX512_K_ADDR (tdep, regs, regnum));
       return;
 
     case avx512_ymmh_avx512:
       if ((clear_bv & X86_XSTATE_ZMM))
-	regcache->raw_supply (regnum, zero);
+	regcache->raw_supply_zeroed (regnum);
       else
 	regcache->raw_supply (regnum,
-			      XSAVE_YMM_AVX512_ADDR (tdep, regs, regnum));
+			      XSAVE_YMM_H_AVX512_ADDR (tdep, regs, regnum));
       return;
 
     case avx512_xmm_avx512:
       if ((clear_bv & X86_XSTATE_ZMM))
-	regcache->raw_supply (regnum, zero);
+	regcache->raw_supply_zeroed (regnum);
       else
 	regcache->raw_supply (regnum,
 			      XSAVE_XMM_AVX512_ADDR (tdep, regs, regnum));
@@ -1258,21 +1259,21 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 
     case avxh:
       if ((clear_bv & X86_XSTATE_AVX))
-	regcache->raw_supply (regnum, zero);
+	regcache->raw_supply_zeroed (regnum);
       else
 	regcache->raw_supply (regnum, XSAVE_AVXH_ADDR (tdep, regs, regnum));
       return;
 
     case sse:
       if ((clear_bv & X86_XSTATE_SSE))
-	regcache->raw_supply (regnum, zero);
+	regcache->raw_supply_zeroed (regnum);
       else
 	regcache->raw_supply (regnum, FXSAVE_ADDR (tdep, regs, regnum));
       return;
 
     case x87:
       if ((clear_bv & X86_XSTATE_X87))
-	regcache->raw_supply (regnum, zero);
+	regcache->raw_supply_zeroed (regnum);
       else
 	regcache->raw_supply (regnum, FXSAVE_ADDR (tdep, regs, regnum));
       return;
@@ -1286,7 +1287,7 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 	      for (i = I387_PKRU_REGNUM (tdep);
 		   i < I387_PKEYSEND_REGNUM (tdep);
 		   i++)
-		regcache->raw_supply (i, zero);
+		regcache->raw_supply_zeroed (i);
 	    }
 	  else
 	    {
@@ -1303,7 +1304,7 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 	  if ((clear_bv & X86_XSTATE_ZMM_H))
 	    {
 	      for (i = I387_ZMM0H_REGNUM (tdep); i < zmm_endlo_regnum; i++)
-		regcache->raw_supply (i, zero);
+		regcache->raw_supply_zeroed (i);
 	    }
 	  else
 	    {
@@ -1321,7 +1322,7 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 	      for (i = I387_K0_REGNUM (tdep);
 		   i < I387_KEND_REGNUM (tdep);
 		   i++)
-		regcache->raw_supply (i, zero);
+		regcache->raw_supply_zeroed (i);
 	    }
 	  else
 	    {
@@ -1339,15 +1340,15 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 	    {
 	      for (i = I387_ZMM16H_REGNUM (tdep);
 		   i < I387_ZMMENDH_REGNUM (tdep); i++)
-		regcache->raw_supply (i, zero);
+		regcache->raw_supply_zeroed (i);
 	      for (i = I387_YMM16H_REGNUM (tdep);
 		   i < I387_YMMH_AVX512_END_REGNUM (tdep);
 		   i++)
-		regcache->raw_supply (i, zero);
+		regcache->raw_supply_zeroed (i);
 	      for (i = I387_XMM16_REGNUM (tdep);
 		   i < I387_XMM_AVX512_END_REGNUM (tdep);
 		   i++)
-		regcache->raw_supply (i, zero);
+		regcache->raw_supply_zeroed (i);
 	    }
 	  else
 	    {
@@ -1358,7 +1359,8 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 	      for (i = I387_YMM16H_REGNUM (tdep);
 		   i < I387_YMMH_AVX512_END_REGNUM (tdep);
 		   i++)
-		regcache->raw_supply (i, XSAVE_YMM_AVX512_ADDR (tdep, regs, i));
+		regcache->raw_supply (i,
+				      XSAVE_YMM_H_AVX512_ADDR (tdep, regs, i));
 	      for (i = I387_XMM16_REGNUM (tdep);
 		   i < I387_XMM_AVX512_END_REGNUM (tdep);
 		   i++)
@@ -1373,7 +1375,7 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 	      for (i = I387_YMM0H_REGNUM (tdep);
 		   i < I387_YMMENDH_REGNUM (tdep);
 		   i++)
-		regcache->raw_supply (i, zero);
+		regcache->raw_supply_zeroed (i);
 	    }
 	  else
 	    {
@@ -1392,7 +1394,7 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 	      for (i = I387_R16_REGNUM (tdep);
 		   i < I387_APX_END_REGNUM (tdep);
 		   i++)
-		regcache->raw_supply (i, zero);
+		regcache->raw_supply_zeroed (i);
 	    }
 	  else
 	    {
@@ -1407,7 +1409,7 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
       if ((tdep->xcr0 & X86_XSTATE_TILECFG) != 0)
 	{
 	  if ((clear_bv & X86_XSTATE_TILECFG) != 0)
-	    regcache->raw_supply (I387_TILECFG_RAW_REGNUM (tdep), zero);
+	    regcache->raw_supply_zeroed (I387_TILECFG_RAW_REGNUM (tdep));
 	  else
 	    {
 	      i = I387_TILECFG_RAW_REGNUM (tdep);
@@ -1420,7 +1422,7 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
       if ((tdep->xcr0 & X86_XSTATE_TILEDATA) != 0)
 	{
 	  if ((clear_bv & X86_XSTATE_TILEDATA) != 0)
-	    regcache->raw_supply (I387_TILEDATA_REGNUM (tdep), zero);
+	    regcache->raw_supply_zeroed (I387_TILEDATA_REGNUM (tdep));
 	  else
 	    {
 	      i = I387_TILEDATA_REGNUM (tdep);
@@ -1437,7 +1439,7 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 	      for (i = I387_XMM0_REGNUM (tdep);
 		   i < I387_MXCSR_REGNUM (tdep);
 		   i++)
-		regcache->raw_supply (i, zero);
+		regcache->raw_supply_zeroed (i);
 	    }
 	  else
 	    {
@@ -1455,7 +1457,7 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 	      for (i = I387_ST0_REGNUM (tdep);
 		   i < I387_FCTRL_REGNUM (tdep);
 		   i++)
-		regcache->raw_supply (i, zero);
+		regcache->raw_supply_zeroed (i);
 	    }
 	  else
 	    {
@@ -1490,7 +1492,7 @@ i387_supply_xsave (struct regcache *regcache, int regnum,
 		regcache->raw_supply (i, buf);
 	      }
 	    else
-	      regcache->raw_supply (i, zero);
+	      regcache->raw_supply_zeroed (i);
 	  }
 	/* Most of the FPU control registers occupy only 16 bits in
 	   the xsave extended state.  Give those a special treatment.  */
@@ -1569,6 +1571,7 @@ i387_collect_xsave (const struct regcache *regcache, int regnum,
   enum bfd_endian byte_order = gdbarch_byte_order (gdbarch);
   i386_gdbarch_tdep *tdep = gdbarch_tdep<i386_gdbarch_tdep> (gdbarch);
   gdb_byte *p, *regs = (gdb_byte *) xsave;
+  gdb_byte raw[I386_MAX_REGISTER_SIZE];
   ULONGEST initial_xstate_bv, clear_bv, xstate_bv = 0;
   unsigned int i;
   /* See the comment in i387_supply_xsave().  */
@@ -1711,7 +1714,7 @@ i387_collect_xsave (const struct regcache *regcache, int regnum,
 	    memset (XSAVE_AVX512_ZMM16_H_ADDR (tdep, regs, i), 0, 32);
 	  for (i = I387_YMM16H_REGNUM (tdep);
 	       i < I387_YMMH_AVX512_END_REGNUM (tdep); i++)
-	    memset (XSAVE_YMM_AVX512_ADDR (tdep, regs, i), 0, 16);
+	    memset (XSAVE_YMM_H_AVX512_ADDR (tdep, regs, i), 0, 16);
 	  for (i = I387_XMM16_REGNUM (tdep);
 	       i < I387_XMM_AVX512_END_REGNUM (tdep); i++)
 	    memset (XSAVE_XMM_AVX512_ADDR (tdep, regs, i), 0, 16);
@@ -1749,21 +1752,13 @@ i387_collect_xsave (const struct regcache *regcache, int regnum,
 					byte_order, I387_FCTRL_INIT_VAL);
 	      else
 		memset (FXSAVE_ADDR (tdep, regs, i), 0,
-			regcache_register_size (regcache, i));
+			regcache->register_size (i));
 	    }
 	}
     }
 
   if (regclass == all)
     {
-      /* This used to blindly allocate I386_MAX_REGISTER_SIZE of space.
-	 With AMX that became a bit much to do unconditionally.  For now
-	 this seems to be the best trade-off between saving space and
-	 the performance penalty for adding individual allocations.  */
-      const uint32_t buf_size
-	  = (tdep->xcr0 & X86_XSTATE_TILEDATA) ? I386_MAX_REGISTER_SIZE : 64;
-      gdb_byte raw[buf_size];
-
       /* Check if any APX registers are changed.  */
       if ((tdep->xcr0 & X86_XSTATE_APX_F))
 	{
@@ -1868,7 +1863,7 @@ i387_collect_xsave (const struct regcache *regcache, int regnum,
 	       i < I387_YMMH_AVX512_END_REGNUM (tdep); i++)
 	    {
 	      regcache->raw_collect (i, raw);
-	      p = XSAVE_YMM_AVX512_ADDR (tdep, regs, i);
+	      p = XSAVE_YMM_H_AVX512_ADDR (tdep, regs, i);
 	      if (memcmp (raw, p, 16) != 0)
 		{
 		  xstate_bv |= X86_XSTATE_ZMM;
@@ -1952,7 +1947,6 @@ i387_collect_xsave (const struct regcache *regcache, int regnum,
   else
     {
       /* Check if REGNUM is changed.  */
-      gdb_byte raw[register_size (gdbarch, regnum)];
       regcache->raw_collect (regnum, raw);
 
       switch (regclass)
@@ -2032,7 +2026,7 @@ i387_collect_xsave (const struct regcache *regcache, int regnum,
 
 	case avx512_ymmh_avx512:
 	  /* This is an upper YMM16-31 register.  */
-	  p = XSAVE_YMM_AVX512_ADDR (tdep, regs, regnum);
+	  p = XSAVE_YMM_H_AVX512_ADDR (tdep, regs, regnum);
 	  if (memcmp (raw, p, 16) != 0)
 	    {
 	      xstate_bv |= X86_XSTATE_ZMM;
@@ -2151,11 +2145,10 @@ i387_collect_xsave (const struct regcache *regcache, int regnum,
 	  }
 	else
 	  {
-	    int regsize = register_size (gdbarch, i);
+	    int regsize;
 
-	    gdb_byte raw[regsize];
 	    regcache->raw_collect (i, raw);
-
+	    regsize = regcache->register_size (i);
 	    p = FXSAVE_ADDR (tdep, regs, i);
 	    if (memcmp (raw, p, regsize))
 	      {
