@@ -1,8 +1,7 @@
 /* Variables that describe the inferior process running under GDB:
    Where it is, why it stopped, and how to step it.
 
-   Copyright (C) 1986-2025 Free Software Foundation, Inc.
-   Copyright (C) 2021-2025 Intel Corporation
+   Copyright (C) 1986-2024 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -19,8 +18,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#if !defined (INFERIOR_H)
-#define INFERIOR_H 1
+#ifndef GDB_INFERIOR_H
+#define GDB_INFERIOR_H
 
 #include <exception>
 #include <list>
@@ -65,6 +64,7 @@ struct thread_info;
 #include "displaced-stepping.h"
 
 #include <unordered_map>
+#include <optional>
 
 struct infcall_suspend_state;
 struct infcall_control_state;
@@ -87,13 +87,7 @@ struct infcall_suspend_state_deleter
 	/* If we are restoring the inferior state due to an exception,
 	   some error message will be printed.  So, only warn the user
 	   when we cannot restore during normal execution.  */
-	bool unwinding;
-#if __cpp_lib_uncaught_exceptions
-	unwinding = std::uncaught_exceptions () > 0;
-#else
-	unwinding = std::uncaught_exception ();
-#endif
-	if (!unwinding)
+	if (std::uncaught_exceptions () == 0)
 	  warning (_("Failed to restore inferior state: %s"), e.what ());
       }
   }
@@ -328,10 +322,7 @@ struct inferior_control_state
   enum stop_kind stop_soon;
 
   /* The waitstatus for this inferior's last event.  */
-  struct target_waitstatus waitstatus {};
-
-  /* If true WAITSTATUS hasn't been handled yet.  */
-  bool waitstatus_pending_p = false;
+  std::optional<target_waitstatus> waitstatus;
 };
 
 /* Initialize the inferior-related global state.  */
@@ -885,4 +876,4 @@ valid_global_inferior_id (int id)
   return false;
 }
 
-#endif /* !defined (INFERIOR_H) */
+#endif /* GDB_INFERIOR_H */
