@@ -1,7 +1,6 @@
 /* Target interface for Intel GT based on level-zero for gdbserver.
 
-   Copyright (C) 2020-2025 Free Software Foundation, Inc.
-   Copyright (C) 2020-2025 Intel Corporation
+   Copyright (C) 2020-2022 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -70,16 +69,15 @@ intelgt_uint_reg_type (tdesc_feature *feature, uint32_t bitsize,
 static void
 intelgt_add_regset (tdesc_feature *feature, long &regnum, const char *prefix,
 		    uint32_t count, const char *group, uint32_t bitsize,
-		    bool is_writable, const char *type, expedite_t &expedite)
+		    bool is_writable, const char *type,
+		    const std::initializer_list<unsigned int> &expedite = {})
 {
   for (uint32_t reg = 0; reg < count; ++reg)
     {
       std::string name = std::string (prefix) + std::to_string (reg);
 
-      bool is_expedited = false;
-      for (const char *exp_reg : expedite)
-	if (name == exp_reg)
-	  is_expedited = true;
+      bool is_expedited = (std::find (expedite.begin (), expedite.end (), reg)
+			  != expedite.end ());
 
       tdesc_create_reg (feature, name.c_str (), regnum++, is_writable, group,
 			bitsize, type, is_expedited);
@@ -89,58 +87,116 @@ intelgt_add_regset (tdesc_feature *feature, long &regnum, const char *prefix,
 /* Control Register details.  */
 
 enum
-  {
-    /* The position of the Breakpoint Suppress bit in CR0.0.  */
-    intelgt_cr0_0_breakpoint_suppress = 15,
+{
+  /* The position of the Breakpoint Suppress bit in CR0.0.  */
+  intelgt_cr0_0_breakpoint_suppress = 15,
 
-    /* The position of the Breakpoint Status and Control bit in CR0.1.  */
-    intelgt_cr0_1_breakpoint_status = 31,
+  /* The position of the Breakpoint Status and Control bit in CR0.1.  */
+  intelgt_cr0_1_breakpoint_status = 31,
 
-    /* The position of the External Halt Status and Control bit in CR0.1.  */
-    intelgt_cr0_1_external_halt_status = 30,
+  /* The position of the External Halt Status and Control bit in CR0.1.  */
+  intelgt_cr0_1_external_halt_status = 30,
 
-    /* The position of the Software Exception Control bit in CR0.1.  */
-    intelgt_cr0_1_software_exception_control = 29,
+  /* The position of the Software Exception Control bit in CR0.1.  */
+  intelgt_cr0_1_software_exception_control = 29,
 
-    /* The position of the Illegal Opcode Exception Status bit in CR0.1.  */
-    intelgt_cr0_1_illegal_opcode_status = 28,
+  /* The position of the Illegal Opcode Exception Status bit in CR0.1.  */
+  intelgt_cr0_1_illegal_opcode_status = 28,
 
-    /* The position of the Force Exception Status and Control bit in CR0.1.  */
-    intelgt_cr0_1_force_exception_status = 26,
+  /* The position of the Force Exception Status and Control bit in CR0.1.  */
+  intelgt_cr0_1_force_exception_status = 26,
 
-    /* The position of the Page Fault Status bit in CR0.1.
-       This is a software convention using a reserved bit to indicate
-       page faults by the user mode driver.  */
-    intelgt_cr0_1_pagefault_status = 16,
+  /* The position of the Page Fault Status bit in CR0.1.
+     This is a software convention using a reserved bit to indicate
+     page faults by the user mode driver.  */
+  intelgt_cr0_1_pagefault_status = 16,
 };
 
+static uint32_t
+get_device_id (const ze_device_info *device)
+{
+  gdb_assert (device != nullptr);
+  return device->properties.deviceId;
+}
+
+/* Read DST.size () bytes from register REGNUM at OFFSET in REGCACHE and write
+   to DST.  */
+
+static void
+intelgt_read_register_part (regcache *regcache, int regnum, int offset,
+			    gdb::array_view<gdb_byte> dst)
+{
+  int regsize = register_size (regcache->tdesc, regnum);
+  gdb_assert (offset >= 0);
+  gdb_assert (offset + dst.size () <= regsize);
+
+  collect_register_part (regcache, regnum, offset, dst);
+
+  enum register_status status = regcache->get_register_status (regnum);
+  switch (status)
+    {
+    case REG_VALID:
+    case REG_DIRTY:
+      return;
+
+    case REG_UNKNOWN:
+      internal_error (_("unknown register '%s'."),
+		      register_name (regcache->tdesc, regnum));
+
+    case REG_UNAVAILABLE:
+      error (_("Register '%s' is not available"),
+	     register_name (regcache->tdesc, regnum));
+    }
+
+  internal_error (_("unknown register status: %d."), status);
+}
+
+/* Write SRC.size () bytes to register REGNUM at OFFSET in REGCACHE.  */
+
+static void
+intelgt_write_register_part (regcache *regcache, int regnum, int offset,
+			     gdb::array_view<const gdb_byte> src)
+{
+  int regsize = register_size (regcache->tdesc, regnum);
+  gdb_assert (offset >= 0);
+  gdb_assert (offset + src.size () <= regsize);
+
+  std::vector<gdb_byte> buf (src.size ());
+  collect_register_part (regcache, regnum, offset,
+			 gdb::array_view<gdb_byte> (std::move (buf)));
+
+  enum register_status status = regcache->get_register_status (regnum);
+  switch (status)
+    {
+    case REG_VALID:
+    case REG_DIRTY:
+      supply_register_part (regcache, regnum, offset, src);
+      return;
+
+    case REG_UNKNOWN:
+      internal_error (_("unknown register '%s'."),
+		      register_name (regcache->tdesc, regnum));
+
+    case REG_UNAVAILABLE:
+      error (_("Register '%s' is not available"),
+	     register_name (regcache->tdesc, regnum));
+    }
+
+  internal_error (_("unknown register status: %d."), status);
+}
+
 /* Return CR0.SUBREG in REGCACHE.  */
 
 static uint32_t
 intelgt_read_cr0 (regcache *regcache, int subreg)
 {
-  int cr0regno = find_regno (regcache->tdesc, "cr0");
-  int cr0size = register_size (regcache->tdesc, cr0regno);
-  uint32_t cr0[16];
-  gdb_assert (cr0size <= sizeof (cr0));
-  gdb_assert (cr0size >= sizeof (cr0[0]) * (subreg + 1));
-  collect_register (regcache, cr0regno, cr0);
+  int regno = find_regno (regcache->tdesc, "cr0");
 
-  enum register_status cr0status = regcache->get_register_status (cr0regno);
-  switch (cr0status)
-    {
-    case REG_VALID:
-    case REG_DIRTY:
-      return cr0[subreg];
+  uint32_t value = 0;
+  gdb::array_view<gdb_byte> buf ((gdb_byte *) &value, sizeof (value));
+  intelgt_read_register_part (regcache, regno, subreg * sizeof (value), buf);
 
-    case REG_UNKNOWN:
-      internal_error (_("unknown register 'cr0'."));
-
-    case REG_UNAVAILABLE:
-      error (_("cr0 is not available"));
-    }
-
-  internal_error (_("unknown register status: %d."), cr0status);
+  return value;
 }
 
 /* Write VALUE into CR0.SUBREG in REGCACHE.  */
@@ -148,48 +204,10 @@ intelgt_read_cr0 (regcache *regcache, int subreg)
 static void
 intelgt_write_cr0 (regcache *regcache, int subreg, uint32_t value)
 {
-  int cr0regno = find_regno (regcache->tdesc, "cr0");
-  int cr0size = register_size (regcache->tdesc, cr0regno);
-  uint32_t cr0[16];
-  gdb_assert (cr0size <= sizeof (cr0));
-  gdb_assert (cr0size >= sizeof (cr0[0]) * (subreg + 1));
-  collect_register (regcache, cr0regno, cr0);
-
-  enum register_status cr0status = regcache->get_register_status (cr0regno);
-  switch (cr0status)
-    {
-    case REG_VALID:
-    case REG_DIRTY:
-      cr0[subreg] = value;
-      supply_register (regcache, cr0regno, cr0);
-      return;
-
-    case REG_UNKNOWN:
-      internal_error (_("unknown register 'cr0'."));
-
-    case REG_UNAVAILABLE:
-      error (_("cr0 is not available"));
-    }
-
-  internal_error (_("unknown register status: %d."), cr0status);
-}
-
-/* Return CR0.SUBREG for TP.  */
-
-static uint32_t
-intelgt_read_cr0 (thread_info *tp, int subreg)
-{
-  struct regcache *regcache = get_thread_regcache (tp, /* fetch = */ false);
-  return intelgt_read_cr0 (regcache, subreg);
-}
-
-/* Write VALUE into CR0.SUBREG for TP.  */
-
-static void
-intelgt_write_cr0 (thread_info *tp, int subreg, uint32_t value)
-{
-  struct regcache *regcache = get_thread_regcache (tp, /* fetch = */ false);
-  intelgt_write_cr0 (regcache, subreg, value);
+  int regno = find_regno (regcache->tdesc, "cr0");
+  gdb::array_view<const gdb_byte> buf ((const gdb_byte *) &value,
+				       sizeof (value));
+  intelgt_write_register_part (regcache, regno, subreg * sizeof (value), buf);
 }
 
 static unsigned int
@@ -238,13 +256,6 @@ device_uuid_str (const uint8_t uuid[], size_t size)
   return sstream.str ();
 }
 
-static uint32_t
-get_device_id (ze_device_info *device)
-{
-  gdb_assert (device != nullptr);
-  return device->properties.deviceId;
-}
-
 /* Target op definitions for Intel GT target based on level-zero.  */
 
 class intelgt_ze_target : public ze_target
@@ -295,10 +306,8 @@ protected:
 
 private:
   /* Add a register set for REGPROP on DEVICE to REGSETS and increment REGNUM
-     accordingly.
-
-     May optionally add registers to EXPEDITE.  */
-  void add_regset (target_desc *tdesc, const ze_device_properties_t &device,
+     accordingly.  */
+  void add_regset (target_desc *tdesc, const ze_device_info &dinfo,
 		   const zet_debug_regset_properties_t &regprop,
 		   long &regnum, ze_regset_info_t &regsets);
 };
@@ -403,6 +412,7 @@ intelgt_ze_target::is_device_supported
   bool have_ce = false;
   bool have_sba = false;
   bool have_scrbase = false;
+  bool have_modeflags = false;
   for (const zet_debug_regset_properties_t &regprop : regset_properties)
     {
       if (regprop.count < 1)
@@ -443,6 +453,10 @@ intelgt_ze_target::is_device_supported
 	case ZET_DEBUG_REGSET_TYPE_THREAD_SCRATCH_INTEL_GPU:
 	  have_scrbase = true;
 	  break;
+
+	case ZET_DEBUG_REGSET_TYPE_MODE_FLAGS_INTEL_GPU:
+	  have_modeflags = true;
+	  break;
 	}
     }
 
@@ -454,7 +468,8 @@ intelgt_ze_target::is_device_supported
       return false;
     }
 
-  if (have_grf && have_isabase && have_cr && have_sr && have_ce)
+  if (have_grf && have_cr && have_sr && have_ce
+      && (have_isabase || have_modeflags))
     return true;
 
   dprintf ("unsupported device (%" PRIx32 "): %s", properties.deviceId,
@@ -475,7 +490,7 @@ intelgt_ze_target::create_tdesc
 
   target_desc_up tdesc = allocate_target_description ();
   set_tdesc_architecture (tdesc.get (), "intelgt");
-  set_tdesc_osabi (tdesc.get (), "GNU/Linux");
+  set_tdesc_osabi (tdesc.get (), GDB_OSABI_LINUX);
 
   std::string device_uuid = device_uuid_str (
     dinfo->properties.uuid.id, sizeof (dinfo->properties.uuid.id));
@@ -501,12 +516,12 @@ intelgt_ze_target::create_tdesc
   long regnum = 0;
   ze_regset_info_up regset_info { new ze_regset_info_t };
   for (const zet_debug_regset_properties_t &regprop : regset_properties)
-    add_regset (tdesc.get (), properties, regprop, regnum,
+    add_regset (tdesc.get (), *dinfo, regprop, regnum,
 		*regset_info);
 
 
   target_desc *tret = tdesc.get ();
-  init_target_desc (tret);
+  init_target_desc (tret, nullptr, GDB_OSABI_LINUX);
 
   /* Devices can have several tdescs.  One is created during attach to the
      device.  Others may be created during thread stop event
@@ -522,10 +537,12 @@ target_stop_reason
 intelgt_ze_target::get_stop_reason (thread_info *tp, gdb_signal &signal)
 {
   ze_device_thread_t thread = ze_thread_id (tp);
+  regcache *regcache = get_thread_regcache (tp, /* fetch = */ false);
+
   uint32_t cr0[3] = {
-    intelgt_read_cr0 (tp, 0),
-    intelgt_read_cr0 (tp, 1),
-    intelgt_read_cr0 (tp, 2)
+    intelgt_read_cr0 (regcache, 0),
+    intelgt_read_cr0 (regcache, 1),
+    intelgt_read_cr0 (regcache, 2)
   };
 
   dprintf ("thread %s (%s) stopped, cr0.0=%" PRIx32 ", .1=%" PRIx32
@@ -548,7 +565,7 @@ intelgt_ze_target::get_stop_reason (thread_info *tp, gdb_signal &signal)
   if ((cr0[1] & (1 << intelgt_cr0_1_pagefault_status)) != 0)
     {
       cr0[1] &= ~(1 << intelgt_cr0_1_pagefault_status);
-      intelgt_write_cr0 (tp, 1, cr0[1]);
+      intelgt_write_cr0 (regcache, 1, cr0[1]);
 
       signal = GDB_SIGNAL_SEGV;
       return TARGET_STOPPED_BY_NO_REASON;
@@ -557,7 +574,7 @@ intelgt_ze_target::get_stop_reason (thread_info *tp, gdb_signal &signal)
   if ((cr0[1] & (1 << intelgt_cr0_1_breakpoint_status)) != 0)
     {
       cr0[1] &= ~(1 << intelgt_cr0_1_breakpoint_status);
-      intelgt_write_cr0 (tp, 1, cr0[1]);
+      intelgt_write_cr0 (regcache, 1, cr0[1]);
 
       /* We cannot distinguish a single step exception from a breakpoint
 	 exception just by looking at CR0.
@@ -599,7 +616,7 @@ intelgt_ze_target::get_stop_reason (thread_info *tp, gdb_signal &signal)
   if ((cr0[1] & (1 << intelgt_cr0_1_illegal_opcode_status)) != 0)
     {
       cr0[1] &= ~(1 << intelgt_cr0_1_illegal_opcode_status);
-      intelgt_write_cr0 (tp, 1, cr0[1]);
+      intelgt_write_cr0 (regcache, 1, cr0[1]);
 
       signal = GDB_SIGNAL_ILL;
       return TARGET_STOPPED_BY_NO_REASON;
@@ -608,7 +625,7 @@ intelgt_ze_target::get_stop_reason (thread_info *tp, gdb_signal &signal)
   if ((cr0[1] & (1 << intelgt_cr0_1_software_exception_control)) != 0)
     {
       cr0[1] &= ~(1 << intelgt_cr0_1_software_exception_control);
-      intelgt_write_cr0 (tp, 1, cr0[1]);
+      intelgt_write_cr0 (regcache, 1, cr0[1]);
 
       signal = GDB_EXC_SOFTWARE;
       return TARGET_STOPPED_BY_NO_REASON;
@@ -619,7 +636,7 @@ intelgt_ze_target::get_stop_reason (thread_info *tp, gdb_signal &signal)
     {
       cr0[1] &= ~(1 << intelgt_cr0_1_force_exception_status);
       cr0[1] &= ~(1 << intelgt_cr0_1_external_halt_status);
-      intelgt_write_cr0 (tp, 1, cr0[1]);
+      intelgt_write_cr0 (regcache, 1, cr0[1]);
 
       signal = GDB_SIGNAL_TRAP;
       return TARGET_STOPPED_BY_NO_REASON;
@@ -668,7 +685,7 @@ intelgt_ze_target::read_inst (thread_info *tp, CORE_ADDR pc,
     return status;
 
   uint32_t device_id = get_device_id (ze_thread_device (tp));
-  if (intelgt::inst_length (buffer, device_id) == intelgt::inst_length_full ())
+  if (intelgt::inst_length (buffer, device_id) == intelgt::MAX_INST_LENGTH)
     return -EIO;
 
   memset (buffer + intelgt::COMPACT_INST_LENGTH, 0,
@@ -710,7 +727,6 @@ intelgt_ze_target::is_at_eot (thread_info *tp)
       return false;
     }
 
-  uint8_t opc;
   uint32_t device_id = get_device_id (ze_thread_device (tp));
   intelgt::xe_version device_version = intelgt::get_xe_version (device_id);
   switch (device_version)
@@ -720,22 +736,30 @@ intelgt_ze_target::is_at_eot (thread_info *tp)
     case intelgt::XE_HPC:
     case intelgt::XE2:
     case intelgt::XE3:
-      opc = inst[0] & intelgt::opc_mask;
+      {
+	/* The opcode mask for bits 6:0.  */
+	constexpr uint8_t OPC_MASK = 0x7f;
+	switch (inst[0] & OPC_MASK)
+	  {
+	  case 0x31: /* send */
+	  case 0x32: /* sendc */
+	    {
+	      /* The End Of Thread control.  Only used for SEND and
+		 SENDC.  */
+	      constexpr uint8_t CTRL_EOT_SEND = 34;
+	      return intelgt::get_inst_bit (inst, CTRL_EOT_SEND);
+	    }
+
+	  default:
+	    return false;
+	  }
+      }
+
+    case intelgt::XE_INVALID:
       break;
-
-    default:
-      error (_("Unsupported device id 0x%" PRIx32), device_id);
     }
 
-  switch (opc)
-    {
-    case intelgt::opc_send:
-    case intelgt::opc_sendc:
-      return intelgt::get_inst_bit (inst, intelgt::ctrl_eot_send);
-
-    default:
-      return false;
-    }
+  error (_("Unsupported device id 0x%" PRIx32), device_id);
 }
 
 /* Return whether erratum #18020355813 applies.  */
@@ -857,13 +881,12 @@ intelgt_ze_target::prepare_thread_resume (thread_info *tp)
 }
 
 void
-intelgt_ze_target::add_regset (target_desc *tdesc,
-			       const ze_device_properties_t &device,
+intelgt_ze_target::add_regset (target_desc *tdesc, const ze_device_info &dinfo,
 			       const zet_debug_regset_properties_t &regprop,
 			       long &regnum, ze_regset_info_t &regsets)
 {
-  expedite_t expedite;
   tdesc_feature *feature = nullptr;
+  const ze_device_properties_t &device = dinfo.properties;
 
   ze_regset_info regset = {};
   regset.type = (uint32_t) regprop.type;
@@ -896,19 +919,32 @@ intelgt_ze_target::add_regset (target_desc *tdesc,
   switch (regprop.type)
     {
     case ZET_DEBUG_REGSET_TYPE_GRF_INTEL_GPU:
-      feature = tdesc_create_feature (tdesc, intelgt::feature_grf);
+      {
+	intelgt::xe_version device_version
+	  = intelgt::get_xe_version (device.deviceId);
 
-      expedite.push_back ("r0");
-      expedite.push_back (
-	(std::string ("r") + std::to_string (regprop.count - 1))
-	  .c_str ());
+	switch (device_version)
+	  {
+	  case intelgt::XE_HP:
+	  case intelgt::XE_HPG:
+	  case intelgt::XE_HPC:
+	  case intelgt::XE2:
+	  case intelgt::XE3:
+	    feature = tdesc_create_feature (tdesc, intelgt::feature_grf);
 
-      intelgt_add_regset (feature, regnum, "r", regprop.count, "grf",
-			  regprop.bitSize, regset.is_writeable,
-			  intelgt_uint_reg_type (feature, regprop.bitSize,
-						 32u),
-			  expedite);
-      break;
+	    intelgt_add_regset (feature, regnum, "r", regprop.count, "grf",
+				regprop.bitSize, regset.is_writeable,
+				intelgt_uint_reg_type (feature,
+						       regprop.bitSize, 32u),
+				{ 0, regprop.count - 1 });
+	    break;
+
+	  default:
+	    gdb_assert_not_reached ("Unexpected device id 0x%" PRIx32,
+				    device.deviceId);
+	  }
+	break;
+      }
 
     case ZET_DEBUG_REGSET_TYPE_ADDR_INTEL_GPU:
       feature = tdesc_create_feature (tdesc, intelgt::feature_addr);
@@ -916,8 +952,7 @@ intelgt_ze_target::add_regset (target_desc *tdesc,
       intelgt_add_regset (feature, regnum, "a", regprop.count, "arf",
 			  regprop.bitSize, regset.is_writeable,
 			  intelgt_uint_reg_type (feature, regprop.bitSize,
-						 16u),
-			  expedite);
+						 16u));
       break;
 
     case ZET_DEBUG_REGSET_TYPE_FLAG_INTEL_GPU:
@@ -926,8 +961,7 @@ intelgt_ze_target::add_regset (target_desc *tdesc,
       intelgt_add_regset (feature, regnum, "f", regprop.count, "arf",
 			  regprop.bitSize, regset.is_writeable,
 			  intelgt_uint_reg_type (feature, regprop.bitSize,
-						 16u),
-			  expedite);
+						 16u));
       break;
 
     case ZET_DEBUG_REGSET_TYPE_CE_INTEL_GPU:
@@ -938,8 +972,6 @@ intelgt_ze_target::add_regset (target_desc *tdesc,
 
       feature = tdesc_create_feature (tdesc, intelgt::feature_ce);
 
-      expedite.push_back ("ce");
-
       tdesc_create_reg (feature, "ce", regnum++, regset.is_writeable, "arf",
 			regprop.bitSize,
 			intelgt_uint_reg_type (feature, regprop.bitSize,
@@ -950,23 +982,21 @@ intelgt_ze_target::add_regset (target_desc *tdesc,
     case ZET_DEBUG_REGSET_TYPE_SR_INTEL_GPU:
       feature = tdesc_create_feature (tdesc, intelgt::feature_sr);
 
-      expedite.push_back ("sr0");
       intelgt_add_regset (feature, regnum, "sr", regprop.count, "arf",
 			  regprop.bitSize, regset.is_writeable,
 			  intelgt_uint_reg_type (feature, regprop.bitSize,
 						 32u),
-			  expedite);
+			  { 0 });
       break;
 
     case ZET_DEBUG_REGSET_TYPE_CR_INTEL_GPU:
       feature = tdesc_create_feature (tdesc, intelgt::feature_cr);
 
-      expedite.push_back ("cr0");
       intelgt_add_regset (feature, regnum, "cr", regprop.count, "arf",
 			  regprop.bitSize, regset.is_writeable,
 			  intelgt_uint_reg_type (feature, regprop.bitSize,
 						 32u),
-			  expedite);
+			  { 0 });
       break;
 
     case ZET_DEBUG_REGSET_TYPE_TDR_INTEL_GPU:
@@ -975,8 +1005,7 @@ intelgt_ze_target::add_regset (target_desc *tdesc,
       intelgt_add_regset (feature, regnum, "tdr", regprop.count, "arf",
 			  regprop.bitSize, regset.is_writeable,
 			  intelgt_uint_reg_type (feature, regprop.bitSize,
-						 16u),
-			  expedite);
+						 16u));
       break;
 
     case ZET_DEBUG_REGSET_TYPE_ACC_INTEL_GPU:
@@ -985,8 +1014,7 @@ intelgt_ze_target::add_regset (target_desc *tdesc,
       intelgt_add_regset (feature, regnum, "acc", regprop.count, "arf",
 			  regprop.bitSize, regset.is_writeable,
 			  intelgt_uint_reg_type (feature, regprop.bitSize,
-						 32u),
-			  expedite);
+						 32u));
       break;
 
     case ZET_DEBUG_REGSET_TYPE_MME_INTEL_GPU:
@@ -995,8 +1023,7 @@ intelgt_ze_target::add_regset (target_desc *tdesc,
       intelgt_add_regset (feature, regnum, "mme", regprop.count, "arf",
 			  regprop.bitSize, regset.is_writeable,
 			  intelgt_uint_reg_type (feature, regprop.bitSize,
-						 32u),
-			  expedite);
+						 32u));
       break;
 
     case ZET_DEBUG_REGSET_TYPE_SP_INTEL_GPU:
@@ -1042,10 +1069,7 @@ intelgt_ze_target::add_regset (target_desc *tdesc,
 		bool is_expedited = false;
 		if ((strcmp (sbaregs[reg], "genstbase") == 0)
 		    || (strcmp (sbaregs[reg], "isabase") == 0))
-		  {
-		    is_expedited = true;
-		    expedite.push_back (sbaregs[reg]);
-		  }
+		  is_expedited = true;
 
 		tdesc_create_reg (feature, sbaregs[reg], regnum++,
 				  regset.is_writeable, "virtual",
@@ -1067,8 +1091,7 @@ intelgt_ze_target::add_regset (target_desc *tdesc,
       intelgt_add_regset (feature, regnum, "dbg", regprop.count, "arf",
 			  regprop.bitSize, regset.is_writeable,
 			  intelgt_uint_reg_type (feature, regprop.bitSize,
-						 32u),
-			  expedite);
+						 32u));
       break;
 
     case ZET_DEBUG_REGSET_TYPE_FC_INTEL_GPU:
@@ -1077,19 +1100,26 @@ intelgt_ze_target::add_regset (target_desc *tdesc,
       intelgt_add_regset (feature, regnum, "fc", regprop.count, "arf",
 			  regprop.bitSize, regset.is_writeable,
 			  intelgt_uint_reg_type (feature, regprop.bitSize,
-						 32u),
-			  expedite);
+						 32u));
+      break;
+
+    case ZET_DEBUG_REGSET_TYPE_MSG_INTEL_GPU:
+      feature = tdesc_create_feature (tdesc, intelgt::feature_msg);
+
+      intelgt_add_regset (feature, regnum, "msg", regprop.count, "arf",
+			  regprop.bitSize, regset.is_writeable,
+			  intelgt_uint_reg_type (feature, regprop.bitSize,
+						 32u));
       break;
 
     case ZET_DEBUG_REGSET_TYPE_MODE_FLAGS_INTEL_GPU:
       feature = tdesc_create_feature (tdesc, intelgt::feature_mf);
 
-      expedite.push_back ("mf0");
       intelgt_add_regset (feature, regnum, "mf", regprop.count, "virtual",
 			  regprop.bitSize, regset.is_writeable,
 			  intelgt_uint_reg_type (feature, regprop.bitSize,
 						 regprop.bitSize),
-			  expedite);
+			  { 0 });
       break;
 
     case ZET_DEBUG_REGSET_TYPE_DEBUG_SCRATCH_INTEL_GPU:
@@ -1130,8 +1160,7 @@ intelgt_ze_target::add_regset (target_desc *tdesc,
       intelgt_add_regset (feature, regnum, "scrbase", regprop.count, "virtual",
 			  regprop.bitSize, regset.is_writeable,
 			  intelgt_uint_reg_type (feature, regprop.bitSize,
-						 regprop.bitSize),
-			  expedite);
+						 regprop.bitSize));
       break;
 
     case ZET_DEBUG_REGSET_TYPE_SCALAR_INTEL_GPU:
@@ -1139,8 +1168,7 @@ intelgt_ze_target::add_regset (target_desc *tdesc,
 
       intelgt_add_regset (feature, regnum, "s", regprop.count, "arf",
 			  regprop.bitSize, regset.is_writeable,
-			  intelgt_uint_reg_type (feature, regprop.bitSize, 8u),
-			  expedite);
+			  intelgt_uint_reg_type (feature, regprop.bitSize, 8u));
       break;
 
     case ZET_DEBUG_REGSET_TYPE_INVALID_INTEL_GPU:
