@@ -191,7 +191,11 @@ iwiWarpAffine_InitAlloc(IwiWarpAffineSpec **ppSpec, IwiSize _srcSize, IwiSize _d
         OWN_MEM_FREE(pInitBuf);
 
     if (status < 0)
+    {
+        OWN_MEM_FREE(spec.pSpec);
+        spec.pSpec = 0;
         return status;
+    }
 
     spec.initialized = OWN_INIT_MAGIC_NUM;
     // Allocate spec structure
