@@ -1,7 +1,6 @@
 /* GNU/Linux/x86-64 specific low level interface, for the remote server
    for GDB.
-   Copyright (C) 2002-2025 Free Software Foundation, Inc.
-   Copyright (C) 2020-2025 Intel Corporation
+   Copyright (C) 2002-2024 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -30,8 +29,14 @@
 
 #ifdef __x86_64__
 #include "nat/amd64-linux-siginfo.h"
+#include "arch/amd64-linux-tdesc.h"
+#else
+#include "nat/i386-linux.h"
 #endif
 
+#include "arch/i386-linux-tdesc.h"
+#include "arch/x86-linux-tdesc-features.h"
+
 #include "gdb_proc_service.h"
 /* Don't include elf/common.h if linux/elf.h got included by
    gdb_proc_service.h.  */
@@ -46,7 +51,7 @@
 #include "nat/linux-nat.h"
 #include "nat/x86-linux.h"
 #include "nat/x86-linux-dregs.h"
-#include "linux-x86-tdesc.h"
+#include "nat/x86-linux-tdesc.h"
 
 #ifdef __x86_64__
 static target_desc_up tdesc_amd64_linux_no_xml;
@@ -249,9 +254,9 @@ static const int x86_64_regmap[] =
   -1, -1, -1, -1, -1, -1, -1, -1,
   -1, -1, -1, -1, -1, -1, -1, -1,
   -1,					/* pkru  */
-  -1,					/* CET user mode register PL3_SSP.  */
   -1,					/* AMX TILECFG register.  */
   -1,					/* AMX TILEDATA: tmm0 ... tmm7.  */
+  -1,					/* CET user mode register PL3_SSP.  */
   -1, -1, -1, -1, -1, -1, -1, -1,       /* r16...r31 (APX).  */
   -1, -1, -1, -1, -1, -1, -1, -1,
 };
@@ -284,7 +289,7 @@ static /*const*/ int i386_regmap[] =
 static int
 is_64bit_tdesc (thread_info *thread)
 {
-  return register_size (get_thread_process (thread)->tdesc, 0) == 8;
+  return register_size (thread->process ()->tdesc, 0) == 8;
 }
 
 #endif
@@ -299,7 +304,7 @@ ps_get_thread_area (struct ps_prochandle *ph,
 #ifdef __x86_64__
   lwp_info *lwp = find_lwp_pid (ptid_t (lwpid));
   gdb_assert (lwp != nullptr);
-  int use_64bit = is_64bit_tdesc (get_lwp_thread (lwp));
+  int use_64bit = is_64bit_tdesc (lwp->thread);
 
   if (use_64bit)
     {
@@ -344,7 +349,7 @@ x86_target::low_get_thread_area (int lwpid, CORE_ADDR *addr)
   lwp_info *lwp = find_lwp_pid (ptid_t (lwpid));
   gdb_assert (lwp != nullptr);
 #ifdef __x86_64__
-  int use_64bit = is_64bit_tdesc (get_lwp_thread (lwp));
+  int use_64bit = is_64bit_tdesc (lwp->thread);
 
   if (use_64bit)
     {
@@ -360,8 +365,8 @@ x86_target::low_get_thread_area (int lwpid, CORE_ADDR *addr)
 #endif
 
   {
-    struct thread_info *thr = get_lwp_thread (lwp);
-    struct regcache *regcache = get_thread_regcache (thr);
+    thread_info *thr = lwp->thread;
+    regcache *regcache = get_thread_regcache (thr);
     unsigned int desc[4];
     ULONGEST gs = 0;
     const int reg_thread_area = 3; /* bits to scale down register value.  */
@@ -372,7 +377,7 @@ x86_target::low_get_thread_area (int lwpid, CORE_ADDR *addr)
     idx = gs >> reg_thread_area;
 
     if (ptrace (PTRACE_GET_THREAD_AREA,
-		lwpid_of (thr),
+		thr->id.lwp (),
 		(void *) (long) idx, (unsigned long) &desc) < 0)
       return -1;
 
@@ -833,7 +838,7 @@ x86_target::low_siginfo_fixup (siginfo_t *ptrace, gdb_byte *inf, int direction)
 {
 #ifdef __x86_64__
   unsigned int machine;
-  int tid = lwpid_of (current_thread);
+  int tid = current_thread->id.lwp ();
   int is_elf64 = linux_pid_exe_is_elf_64_file (tid, &machine);
 
   /* Is the inferior 32-bit?  If so, then fixup the siginfo object.  */
@@ -851,181 +856,87 @@ x86_target::low_siginfo_fixup (siginfo_t *ptrace, gdb_byte *inf, int direction)
 
 static int use_xml;
 
-/* Format of XSAVE extended state is:
-	struct
-	{
-	  fxsave_bytes[0..463]
-	  sw_usable_bytes[464..511]
-	  xstate_hdr_bytes[512..575]
-	  avx_bytes[576..831]
-	  future_state etc
-	};
-
-  Same memory layout will be used for the coredump NT_X86_XSTATE
-  representing the XSAVE extended state registers.
-
-  The first 8 bytes of the sw_usable_bytes[464..467] is the OS enabled
-  extended state mask, which is the same as the extended control register
-  0 (the XFEATURE_ENABLED_MASK register), XCR0.  We can use this mask
-  together with the mask saved in the xstate_hdr_bytes to determine what
-  states the processor/OS supports and what state, used or initialized,
-  the process/thread is in.  */
-#define I386_LINUX_XSAVE_XCR0_OFFSET 464
-
-/* Does the current host support the GETFPXREGS request?  The header
-   file may or may not define it, and even if it is defined, the
-   kernel will return EIO if it's running on a pre-SSE processor.  */
-int have_ptrace_getfpxregs =
-#ifdef HAVE_PTRACE_GETFPXREGS
-  -1
-#else
-  0
-#endif
-;
-
 /* Get Linux/x86 target description from running target.  */
 
 static const struct target_desc *
-x86_linux_read_description (void)
+x86_linux_read_description ()
 {
-  unsigned int machine;
-  int is_elf64;
-  int xcr0_features;
-  int tid;
-  static uint64_t xcr0;
-  static int xsave_len;
-  struct regset_info *regset;
+  int tid = current_thread->id.lwp ();
 
-  tid = lwpid_of (current_thread);
-
-  is_elf64 = linux_pid_exe_is_elf_64_file (tid, &machine);
-
-  if (sizeof (void *) == 4)
-    {
-      if (is_elf64 > 0)
-       error (_("Can't debug 64-bit process with 32-bit GDBserver"));
-#ifndef __x86_64__
-      else if (machine == EM_X86_64)
-       error (_("Can't debug x86-64 process with 32-bit GDBserver"));
-#endif
-    }
-
-#if !defined __x86_64__ && defined HAVE_PTRACE_GETFPXREGS
-  if (machine == EM_386 && have_ptrace_getfpxregs == -1)
-    {
-      elf_fpxregset_t fpxregs;
-
-      if (ptrace (PTRACE_GETFPXREGS, tid, 0, (long) &fpxregs) < 0)
-	{
-	  have_ptrace_getfpxregs = 0;
-	  have_ptrace_getregset = TRIBOOL_FALSE;
-	  return i386_linux_read_description (X86_XSTATE_X87);
-	}
-      else
-	have_ptrace_getfpxregs = 1;
-    }
-#endif
+  /* If we are not allowed to send an XML target description then we need
+     to use the hard-wired target descriptions.  This corresponds to GDB's
+     default machine for x86.
 
+     This check needs to occur before any returns statements that might
+     generate some alternative target descriptions.  */
   if (!use_xml)
     {
-      /* Don't use XML.  */
+      x86_linux_arch_size arch_size = x86_linux_ptrace_get_arch_size (tid);
+      bool is_64bit = arch_size.is_64bit ();
+      bool is_x32 = arch_size.is_x32 ();
+
+      if (sizeof (void *) == 4 && is_64bit && !is_x32)
+	error (_("Can't debug 64-bit process with 32-bit GDBserver"));
+
 #ifdef __x86_64__
-      if (machine == EM_X86_64)
+      if (is_64bit && !is_x32)
 	return tdesc_amd64_linux_no_xml.get ();
       else
 #endif
 	return tdesc_i386_linux_no_xml.get ();
     }
 
-  if (have_ptrace_getregset == TRIBOOL_UNKNOWN)
+  /* If have_ptrace_getregset is changed to true by calling
+     x86_linux_tdesc_for_tid then we will perform some additional
+     initialisation.  */
+  bool have_ptrace_getregset_was_unknown
+    = have_ptrace_getregset == TRIBOOL_UNKNOWN;
+
+  /* Get pointers to where we should store the xstate_bv and xsave_layout
+     values.  These will be filled in by x86_linux_tdesc_for_tid the first
+     time that the function is called.  Subsequent calls will not modify
+     the stored values.  */
+  std::pair<uint64_t *, x86_xsave_layout *> storage
+    = i387_get_xsave_storage ();
+
+  const target_desc *tdesc
+    = x86_linux_tdesc_for_tid (tid, storage.first, storage.second);
+
+  if (have_ptrace_getregset_was_unknown
+      && have_ptrace_getregset == TRIBOOL_TRUE)
     {
-      uint64_t xstateregs[(X86_XSTATE_SSE_SIZE / sizeof (uint64_t))];
-      struct iovec iov;
+      int xsave_len = x86_xsave_length ();
 
-      iov.iov_base = xstateregs;
-      iov.iov_len = sizeof (xstateregs);
-
-      /* Check if PTRACE_GETREGSET works.  */
-      if (ptrace (PTRACE_GETREGSET, tid,
-		  (unsigned int) NT_X86_XSTATE, (long) &iov) < 0)
-	have_ptrace_getregset = TRIBOOL_FALSE;
-      else
+      /* Use PTRACE_GETREGSET if it is available.  */
+      for (regset_info *regset = x86_regsets;
+	   regset->fill_function != nullptr;
+	   regset++)
 	{
-	  have_ptrace_getregset = TRIBOOL_TRUE;
 
-	  /* Get XCR0 from XSAVE extended state.  */
-	  xcr0 = xstateregs[(I386_LINUX_XSAVE_XCR0_OFFSET
-			     / sizeof (uint64_t))];
-
-	  xsave_len = x86_xsave_length ();
-
-	  /* Use PTRACE_GETREGSET if it is available.  */
-	  for (regset = x86_regsets;
-	       regset->fill_function != NULL; regset++)
-	  {
-	    if (regset->get_request == PTRACE_GETREGSET)
-	      {
-		if (regset->nt_type == NT_X86_XSTATE)
-		  regset->size = xsave_len;
-		else if (regset->nt_type == NT_X86_SHSTK)
-		  {
-		    /* We must configure the size of the NT_X86_SHSTK regset
-		       from non-zero value to it's appropriate size, even though
-		       the ptrace call is only tested for NT_X86_XSTATE request,
-		       because the NT_X86_SHSTK regset is of type
-		       OPTIONAL_RUNTIME_REGS.  A ptrace call with NT_X86_SHSTK
-		       request may only be successful later on, once shadow
-		       stack is enabled for the current thread.  */
+	  if (regset->get_request == PTRACE_GETREGSET)
+	    {
+	      if (regset->nt_type == NT_X86_XSTATE)
+		regset->size = xsave_len;
+	      else if (regset->nt_type == NT_X86_SHSTK)
+		{
+		  /* We must configure the size of the NT_X86_SHSTK regset
+		     from non-zero value to it's appropriate size, even though
+		     the ptrace call is only tested for NT_X86_XSTATE request,
+		     because the NT_X86_SHSTK regset is of type
+		     OPTIONAL_RUNTIME_REGS.  A ptrace call with NT_X86_SHSTK
+		     request may only be successful later on, once shadow
+		     stack is enabled for the current thread.  */
 		    regset->size = sizeof (CORE_ADDR);
-		  }
-		else
-		  gdb_assert_not_reached ("invalid regset type.");
-	      }
-	    else if (regset->type != GENERAL_REGS)
-	      regset->size = 0;
-	  }
+		}
+	      else
+		gdb_assert_not_reached ("invalid regset type.");
+	    }
+	  else if (regset->type != GENERAL_REGS)
+	    regset->size = 0;
 	}
     }
 
-  /* Check the native XCR0 only if PTRACE_GETREGSET is available.  */
-  xcr0_features = (have_ptrace_getregset == TRIBOOL_TRUE
-		   && (xcr0 & X86_XSTATE_ALL_MASK));
-
-  if (xcr0_features)
-    i387_set_xsave_mask (xcr0, xsave_len);
-
-  if (machine == EM_X86_64)
-    {
-#ifdef __x86_64__
-      const target_desc *tdesc = NULL;
-      bool ssp_enabled = x86_check_ssp_support (tid);
-
-      if (xcr0_features)
-	{
-	  tdesc = amd64_linux_read_description (xcr0 & X86_XSTATE_ALL_MASK,
-						!is_elf64, ssp_enabled);
-	}
-
-      if (tdesc == NULL)
-	tdesc = amd64_linux_read_description (X86_XSTATE_SSE_MASK, !is_elf64,
-					      ssp_enabled);
-      return tdesc;
-#endif
-    }
-  else
-    {
-      const target_desc *tdesc = NULL;
-
-      if (xcr0_features)
-	  tdesc = i386_linux_read_description (xcr0 & X86_XSTATE_ALL_MASK);
-
-      if (tdesc == NULL)
-	tdesc = i386_linux_read_description (X86_XSTATE_SSE);
-
-      return tdesc;
-    }
-
-  gdb_assert_not_reached ("failed to return tdesc");
+  return tdesc;
 }
 
 /* Update all the target description of all processes; a new GDB
@@ -2999,16 +2910,29 @@ x86_target::low_supports_range_stepping ()
 int
 x86_target::get_ipa_tdesc_idx ()
 {
-  const struct target_desc *tdesc = current_process ()->tdesc;
+  const target_desc *tdesc = current_process ()->tdesc;
 
+  if (!use_xml)
+    {
+      /* If USE_XML is false then we should be using one of these target
+	 descriptions, see x86_linux_read_description for where we choose
+	 one of these.  Both of these descriptions are created from this
+	 fixed xcr0 value X86_XSTATE_SSE_MASK.  */
+      gdb_assert (tdesc == tdesc_i386_linux_no_xml.get ()
 #ifdef __x86_64__
-  return amd64_get_ipa_tdesc_idx (tdesc);
-#endif
+		  || tdesc == tdesc_amd64_linux_no_xml.get ()
+#endif /* __x86_64__ */
+		  );
+      return x86_linux_xstate_bv_mask_to_tdesc_idx (X86_XSTATE_SSE_MASK);
+    }
 
-  if (tdesc == tdesc_i386_linux_no_xml.get ())
-    return X86_TDESC_SSE;
+  /* The xstate_bv value and xsave layout value are cached when the target
+     description is read.  Grab their cache location, and use the cached
+     value to calculate a tdesc index.  */
+  std::pair<uint64_t *, x86_xsave_layout *> storage
+    = i387_get_xsave_storage ();
 
-  return i386_get_ipa_tdesc_idx (tdesc);
+  return x86_linux_xstate_bv_mask_to_tdesc_idx (*storage.first);
 }
 
 /* The linux target ops object.  */
