@@ -1,6 +1,5 @@
 /* MI Command Set - stack commands.
-   Copyright (C) 2000-2025 Free Software Foundation, Inc.
-   Copyright (C) 2024-2025 Intel Corporation
+   Copyright (C) 2000-2024 Free Software Foundation, Inc.
    Contributed by Cygnus Solutions (a Red Hat company).
 
    This file is part of GDB.
@@ -894,9 +893,14 @@ mi_cmd_shadow_stack_list_frames (const char *command,
     error (_("-shadow-stack-list-frames: Printing of shadow stack \
 	      backtrace is not supported for the current target."));
 
+
+  regcache *regcache = get_thread_regcache (inferior_thread ());
+  bool shadow_stack_enabled = false;
+
   std::optional<CORE_ADDR> start_ssp
-    = gdbarch_get_shadow_stack_pointer (gdbarch);
-  if (!start_ssp.has_value ())
+    = gdbarch_get_shadow_stack_pointer (gdbarch, regcache,
+					shadow_stack_enabled);
+  if (!start_ssp.has_value () || !shadow_stack_enabled)
     error (_("-shadow-stack-list-frames: Shadow stack is not enabled for \
 	      the current target."));
 
