@@ -1,6 +1,5 @@
 /* MI Command Set - varobj commands.
-   Copyright (C) 2000-2025 Free Software Foundation, Inc.
-   Copyright (C) 2023-2025 Intel Corporation
+   Copyright (C) 2000-2024 Free Software Foundation, Inc.
 
    Contributed by Cygnus Solutions (a Red Hat company).
 
@@ -188,7 +187,7 @@ mi_cmd_var_create (const char *command, const char *const *argv, int argc)
   ui_out_emit_list list_emitter (uiout, "vars");
 
   /* Create vars for every lane from the mask.  */
-  for_active_lanes (lanes, [&] (int lane)
+  foreach_lane (lanes, [&] (int lane)
     {
       /* Lane specific name.  */
       std::string var_name = string_printf ("%s-%d", name, lane);
