@@ -157,6 +157,7 @@ integer, parameter :: MPI_ERR_SESSION                  = 75
 integer, parameter :: MPI_ERR_PROC_ABORTED             = 76
 integer, parameter :: MPI_ERR_VALUE_TOO_LARGE          = 77
 integer, parameter :: MPI_ERR_ERRHANDLER               = 80
+integer, parameter :: MPI_ERR_ABI                      = 81
 integer, parameter :: MPI_ERR_LASTCODE                 = 1073741823 ! 0x3fffffff
 
 ! Predefined error handlers
@@ -285,6 +286,11 @@ type(MPI_Datatype), parameter   :: MPI_INTEGER2        = MPI_Datatype(1275068975
 type(MPI_Datatype), parameter   :: MPI_INTEGER4        = MPI_Datatype(1275069488)
 type(MPI_Datatype), parameter   :: MPI_INTEGER8        = MPI_Datatype(1275070513)
 type(MPI_Datatype), parameter   :: MPI_INTEGER16       = MPI_Datatype(MPI_DATATYPE_NULL%MPI_VAL)
+type(MPI_Datatype), parameter   :: MPI_LOGICAL1        = MPI_Datatype(1275068743)
+type(MPI_Datatype), parameter   :: MPI_LOGICAL2        = MPI_Datatype(1275069000)
+type(MPI_Datatype), parameter   :: MPI_LOGICAL4        = MPI_Datatype(1275069513)
+type(MPI_Datatype), parameter   :: MPI_LOGICAL8        = MPI_Datatype(1275070538)
+type(MPI_Datatype), parameter   :: MPI_LOGICAL16       = MPI_Datatype(MPI_DATATYPE_NULL%MPI_VAL)
 type(MPI_Datatype), parameter   :: MPI_REAL4           = MPI_Datatype(1275069479)
 type(MPI_Datatype), parameter   :: MPI_REAL8           = MPI_Datatype(1275070505)
 type(MPI_Datatype), parameter   :: MPI_REAL16          = MPI_Datatype(1275072555)
