@@ -22,6 +22,7 @@
 
 #pragma once
 
+#include <sycl/__spirv/spirv_ops.hpp>
 #include <sycl/bit_cast.hpp>      // for sycl::bit_cast
 #include <sycl/builtins.hpp>      // for ceil, cos, exp, exp10, exp2
 #include <sycl/detail/memcpy.hpp> // sycl::detail::memcpy
@@ -163,6 +164,45 @@ fabs(T x) {
 #endif
 }
 
+/******************* rsqrt ********************/
+
+template <typename T>
+std::enable_if_t<std::is_same_v<T, bfloat16>, T> rsqrt(T x) {
+  return sycl::ext::oneapi::bfloat16{sycl::rsqrt(float{x})};
+}
+
+// TODO: If N is divisible by 2, we can call rsqrt for two packed values instead
+// of scalar on NVIDIA and pISA targets.
+template <size_t N>
+sycl::marray<bfloat16, N> rsqrt(sycl::marray<bfloat16, N> x) {
+  sycl::marray<bfloat16, N> res;
+  for (size_t i = 0; i < N; i++) {
+    res[i] = rsqrt(x[i]);
+  }
+  return res;
+}
+
+// Overload for BF16 vec and swizzles.
+template <typename T, int N = num_elements_v<T>>
+std::enable_if_t<is_vec_or_swizzle_bf16_v<T>, sycl::vec<bfloat16, N>>
+rsqrt(T x) {
+#if defined(__SYCL_DEVICE_ONLY__) && (defined(__SPIR__) || defined(__SPIRV__))
+  // Convert BFloat16 vector to float vec.
+  sycl::vec<float, N> FVec =
+      x.template convert<float, sycl::rounding_mode::automatic>();
+  auto Res = rsqrt(FVec);
+  return Res.template convert<bfloat16>();
+#else  // defined(__SYCL_DEVICE_ONLY__) && (defined(__SPIR__) ||
+       // defined(__SPIRV__))
+  sycl::vec<bfloat16, N> res;
+  for (size_t i = 0; i < N; i++) {
+    res[i] = rsqrt(x[i]);
+  }
+  return res;
+#endif // defined(__SYCL_DEVICE_ONLY__) && (defined(__SPIR__) ||
+       // defined(__SPIRV__))
+}
+
 /******************* fmin ********************/
 
 template <typename T>
@@ -474,10 +514,6 @@ BFLOAT16_MATH_FP32_WRAPPERS(rint)
 BFLOAT16_MATH_FP32_WRAPPERS_MARRAY(rint)
 BFLOAT16_MATH_FP32_WRAPPERS_VEC(rint)
 
-BFLOAT16_MATH_FP32_WRAPPERS(rsqrt)
-BFLOAT16_MATH_FP32_WRAPPERS_MARRAY(rsqrt)
-BFLOAT16_MATH_FP32_WRAPPERS_VEC(rsqrt)
-
 BFLOAT16_MATH_FP32_WRAPPERS(sin)
 BFLOAT16_MATH_FP32_WRAPPERS_MARRAY(sin)
 BFLOAT16_MATH_FP32_WRAPPERS_VEC(sin)
