@@ -89,7 +89,7 @@ static constexpr ext::oneapi::experimental::architecture
         ext::oneapi::experimental::architecture::intel_gpu_bdw;
 static constexpr ext::oneapi::experimental::architecture
     max_intel_gpu_architecture =
-        ext::oneapi::experimental::architecture::intel_gpu_ptl_u;
+        ext::oneapi::experimental::architecture::intel_gpu_wcl;
 
 static constexpr ext::oneapi::experimental::architecture
     min_nvidia_gpu_architecture =
@@ -186,11 +186,9 @@ static constexpr ext::oneapi::experimental::architecture
 #ifndef __SYCL_TARGET_INTEL_GPU_BMG_G21__
 #define __SYCL_TARGET_INTEL_GPU_BMG_G21__ 0
 #endif
-// INTEL_COLLAB
 #ifndef __SYCL_TARGET_INTEL_GPU_BMG_G31__
 #define __SYCL_TARGET_INTEL_GPU_BMG_G31__ 0
 #endif
-// end INTEL_COLLAB
 #ifndef __SYCL_TARGET_INTEL_GPU_LNL_M__
 #define __SYCL_TARGET_INTEL_GPU_LNL_M__ 0
 #endif
@@ -200,11 +198,9 @@ static constexpr ext::oneapi::experimental::architecture
 #ifndef __SYCL_TARGET_INTEL_GPU_PTL_U__
 #define __SYCL_TARGET_INTEL_GPU_PTL_U__ 0
 #endif
-// INTEL_COLLAB
 #ifndef __SYCL_TARGET_INTEL_GPU_WCL__
 #define __SYCL_TARGET_INTEL_GPU_WCL__ 0
 #endif
-// end INTEL_COLLAB
 #ifndef __SYCL_TARGET_NVIDIA_GPU_SM_50__
 #define __SYCL_TARGET_NVIDIA_GPU_SM_50__ 0
 #endif
@@ -404,15 +400,11 @@ static constexpr bool is_allowable_aot_mode =
     (__SYCL_TARGET_INTEL_GPU_MTL_H__ == 1) ||
     (__SYCL_TARGET_INTEL_GPU_ARL_H__ == 1) ||
     (__SYCL_TARGET_INTEL_GPU_BMG_G21__ == 1) ||
-    // INTEL_COLLAB
     (__SYCL_TARGET_INTEL_GPU_BMG_G31__ == 1) ||
-    // end INTEL_COLLAB
     (__SYCL_TARGET_INTEL_GPU_LNL_M__ == 1) ||
     (__SYCL_TARGET_INTEL_GPU_PTL_H__ == 1) ||
     (__SYCL_TARGET_INTEL_GPU_PTL_U__ == 1) ||
-    // INTEL_COLLAB
     (__SYCL_TARGET_INTEL_GPU_WCL__ == 1) ||
-    // end INTEL_COLLAB
     (__SYCL_TARGET_NVIDIA_GPU_SM_50__ == 1) ||
     (__SYCL_TARGET_NVIDIA_GPU_SM_52__ == 1) ||
     (__SYCL_TARGET_NVIDIA_GPU_SM_53__ == 1) ||
@@ -557,11 +549,9 @@ get_current_architecture_aot() {
 #if __SYCL_TARGET_INTEL_GPU_BMG_G21__
   return ext::oneapi::experimental::architecture::intel_gpu_bmg_g21;
 #endif
-// INTEL_COLLAB
 #if __SYCL_TARGET_INTEL_GPU_BMG_G31__
   return ext::oneapi::experimental::architecture::intel_gpu_bmg_g31;
 #endif
-// end INTEL_COLLAB
 #if __SYCL_TARGET_INTEL_GPU_LNL_M__
   return ext::oneapi::experimental::architecture::intel_gpu_lnl_m;
 #endif
@@ -571,11 +561,9 @@ get_current_architecture_aot() {
 #if __SYCL_TARGET_INTEL_GPU_PTL_U__
   return ext::oneapi::experimental::architecture::intel_gpu_ptl_u;
 #endif
-// INTEL_COLLAB
 #if __SYCL_TARGET_INTEL_GPU_WCL__
   return ext::oneapi::experimental::architecture::intel_gpu_wcl;
 #endif
-// end INTEL_COLLAB
 #if __SYCL_TARGET_NVIDIA_GPU_SM_50__
   return ext::oneapi::experimental::architecture::nvidia_gpu_sm_50;
 #endif
