@@ -65,7 +65,7 @@ __SYCL_CONVERGENT__ extern SYCL_EXTERNAL __SYCL_EXPORT
     __spirv_GroupNonUniformShuffleUp(__spv::Scope::Flag, T, unsigned) noexcept;
 #endif
 
-namespace syclcompat {
+namespace [[deprecated("syclcompat is deprecated")]] syclcompat {
 
 namespace detail {
 
@@ -86,10 +86,15 @@ template <typename T> struct DataType<sycl::vec<T, 2>> {
   using T2 = detail::complex_type<T>;
 };
 
+template <typename T = void>
 inline void matrix_mem_copy(void *to_ptr, const void *from_ptr, int to_ld,
                             int from_ld, int rows, int cols, int elem_size,
                             sycl::queue queue = syclcompat::get_default_queue(),
                             bool async = false) {
+  static_assert(
+      std::is_same_v<T, void>,
+      "syclcompat::matrix_mem_copy only accepts a dummy template parameter, T "
+      "= void, which prevents SYCL kernel generation by default.");
   if (to_ptr == from_ptr && to_ld == from_ld) {
     return;
   }
