@@ -67,9 +67,9 @@
       integer(kind=omp_integer_kind)kmp_version_minor
       parameter(kmp_version_minor=0)
       integer(kind=omp_integer_kind)kmp_version_build
-      parameter(kmp_version_build=20250422)
+      parameter(kmp_version_build=20250910)
       character(*)kmp_build_date
-      parameter(kmp_build_date='2025-04-25 19-16-16 UTC')
+      parameter(kmp_build_date='2025-09-10 19-02-30 UTC')
 
       integer(kind=omp_sched_kind)omp_sched_static
       parameter(omp_sched_static=1)
@@ -300,10 +300,8 @@
       parameter(omp_ifr_hip=5)
       integer(kind=omp_interop_fr_kind)omp_ifr_level_zero
       parameter(omp_ifr_level_zero=6)
-      integer(kind=omp_interop_fr_kind)omp_ifr_unified_runtime
-      parameter(omp_ifr_unified_runtime=7)
       integer(kind=omp_interop_fr_kind)omp_ifr_last
-      parameter(omp_ifr_last=8)
+      parameter(omp_ifr_last=7)
 
       integer(kind=omp_interop_kind)omp_interop_none
       parameter(omp_interop_none=0)
