@@ -16,7 +16,7 @@
 
   
 #if !defined(_NO_IPP_DEPRECATED)
-#pragma message ("code path e9 is deprecated, lower optimizations level y8 is used")
+#pragma message ("code path e9 is deprecated, y8 optimizations level is used")
 #endif
 #define ippcpGetLibVersion y8_ippcpGetLibVersion
 #define cryptoGetLibVersion y8_cryptoGetLibVersion
@@ -237,6 +237,7 @@
 #define ippsHashMessage_rmf y8_ippsHashMessage_rmf
 #define ippsHashMethodGetInfo y8_ippsHashMethodGetInfo
 #define ippsHashGetInfo_rmf y8_ippsHashGetInfo_rmf
+#define ippsHashSqueeze_rmf y8_ippsHashSqueeze_rmf
 #define ippsMGF y8_ippsMGF
 #define ippsMGF1_rmf y8_ippsMGF1_rmf
 #define ippsMGF2_rmf y8_ippsMGF2_rmf
@@ -259,6 +260,8 @@
 #define ippsHMACGetTag_rmf y8_ippsHMACGetTag_rmf
 #define ippsHMACMessage_rmf y8_ippsHMACMessage_rmf
 #define ippsHKDF y8_ippsHKDF
+#define ippsHKDF_extract y8_ippsHKDF_extract
+#define ippsHKDF_expand y8_ippsHKDF_expand
 #define ippsBigNumGetSize y8_ippsBigNumGetSize
 #define ippsBigNumInit y8_ippsBigNumInit
 #define ippsCmpZero_BN y8_ippsCmpZero_BN
@@ -503,8 +506,18 @@
 #define ippsXMSSSign y8_ippsXMSSSign
 #define ippsXMSSVerify y8_ippsXMSSVerify
 #define ippsLMSBufferGetSize y8_ippsLMSBufferGetSize
+#define ippsLMSVerifyBufferGetSize y8_ippsLMSVerifyBufferGetSize
 #define ippsLMSSignatureStateGetSize y8_ippsLMSSignatureStateGetSize
 #define ippsLMSPublicKeyStateGetSize y8_ippsLMSPublicKeyStateGetSize
 #define ippsLMSSetPublicKeyState y8_ippsLMSSetPublicKeyState
 #define ippsLMSSetSignatureState y8_ippsLMSSetSignatureState
 #define ippsLMSVerify y8_ippsLMSVerify
+#define ippsMLKEM_GetSize y8_ippsMLKEM_GetSize
+#define ippsMLKEM_GetInfo y8_ippsMLKEM_GetInfo
+#define ippsMLKEM_Init y8_ippsMLKEM_Init
+#define ippsMLKEM_KeyGenBufferGetSize y8_ippsMLKEM_KeyGenBufferGetSize
+#define ippsMLKEM_EncapsBufferGetSize y8_ippsMLKEM_EncapsBufferGetSize
+#define ippsMLKEM_DecapsBufferGetSize y8_ippsMLKEM_DecapsBufferGetSize
+#define ippsMLKEM_KeyGen y8_ippsMLKEM_KeyGen
+#define ippsMLKEM_Encaps y8_ippsMLKEM_Encaps
+#define ippsMLKEM_Decaps y8_ippsMLKEM_Decaps
