@@ -63,6 +63,7 @@ using device_atomic_ref = sycl::atomic_ref<T,
 
 void GenerateProblem(SparseMatrix & A, Vector * b, Vector * x, Vector * xexact,
                      sycl::queue & main_queue, int runRealRef) {
+  (void)runRealRef; // to prevent compiler warning
 
   // The call to this reference version of GenerateProblem can be replaced with custom code.
   // However, the data structures must remain unchanged such that the CheckProblem function is satisfied.
@@ -89,8 +90,7 @@ void GenerateProblem(SparseMatrix & A, Vector * b, Vector * x, Vector * xexact,
   //global_int_t ipz = A.geom->ipz;
   int npx = A.geom->npx;
   int npy = A.geom->npy;
-  int npz = A.geom->npz;
-  double omp1,omp2;
+  //int npz = A.geom->npz;
 
 //    std::cout << "gnx = " << gnx << ", gny = " << gny << ", gnz = " << gnz << std::endl;
 //    std::cout << "npx = " << npx << ", npy = " << npy << ", npz = " << npz << std::endl;
@@ -188,9 +188,6 @@ void GenerateProblem(SparseMatrix & A, Vector * b, Vector * x, Vector * xexact,
   //local_int_t *numOfBoundaryRows = (local_int_t *)sparse_malloc_shared(sizeof(local_int_t) * 1, main_queue);
   local_int_t numOfBoundaryRows = 0;
 
-  local_int_t local_work_group_size = 256;
-  local_int_t total_size = 0;
-
   sycl::event setup_bdryRows_ev;
 {
 
@@ -474,7 +471,7 @@ void GenerateProblem(SparseMatrix & A, Vector * b, Vector * x, Vector * xexact,
     ev = main_queue.memcpy(itmp_host, itmp_dev, 1*sizeof(local_int_t), {ev});
     main_queue.memcpy(map_neib_recv_h, map_neib_recv_d, A.geom->size * sizeof(local_int_t), {ev}).wait();
     A.work = map_neib_recv_h; // save host version
-    
+
 
     localNumberOfNonzeros += itmp_host[0]; // record unpredictable count of local nonzeros
 
