@@ -97,6 +97,7 @@ sycl::event printGraph(sycl::queue &queue, int rank,
                        const std::vector<sycl::event> &dependencies)
 {
     sycl::event last;
+    (void)matrixValues; // to prevent compiler warning
 
     char fname_perm[80];
     char fname_A[80];
@@ -176,7 +177,6 @@ sycl::event printPerm(sycl::queue &queue, const int rank,
     sycl::event last;
 
     char fname_perm[80];
-    char fname_A[80];
     sprintf(fname_perm, "perm%04d_rank%d.txt", nrow, rank);
     std::ofstream fout_perm;
     fout_perm.open(fname_perm);
@@ -326,6 +326,10 @@ sycl::event colorize_graph_direct(sycl::queue &queue, int rank,
                                   local_int_t &nColors, local_int_t *xcolors_dev,
                                   const std::vector<sycl::event> dependencies)
 {
+    (void)rank; // to prevent compiler warning
+    (void)nonzerosInRow; // to prevent compiler warning
+    (void)mtxIndL; // to prevent compiler warning
+    (void)matrixValues; // to prevent compiler warning
 
     // color unset value
     const local_int_t unset = UNSET;
@@ -466,6 +470,9 @@ sycl::event colorize_graph(sycl::queue &queue, const int rank,
                            local_int_t &nColors, local_int_t *xcolors_dev,
                            const std::vector<sycl::event> dependencies)
 {
+    (void)rank; // to prevent compiler warning
+    (void)matrixValues; // to prevent compiler warning
+
     sycl::event ev_chain;
 
     int width = 64 / sizeof(local_int_t);
@@ -572,7 +579,7 @@ sycl::event colorize_graph(sycl::queue &queue, const int rank,
                         const local_uint_t row_val = weight_dev[row]; // get value for row to compare to neighbors
 
                         // loop through neighbors to find independent set
-                        for (char k = 0; k < nonzerosInRow[row]; ++k)
+                        for (uint8_t k = 0; k < nonzerosInRow[row]; ++k)
                         {
                             const local_int_t neighbor_ind = mtxIndL[row][k];
                             if (neighbor_ind < nrow) {
