@@ -105,12 +105,11 @@ static inline void regPrefixSum(vec &simdReg) {
 // final reduction. One thread to compute prefix all remaining entries
 template<size_t simdLen, bool useBlockLoadStore, typename int_t>
 void prefixSum_singleThread(sycl::item<1> it, int_t *acc, uint32_t stride_elems, uint32_t remaining) {
+  (void)it; // to prevent compiler warning
 
   // simdLen when data is interpreted as 32b
   constexpr size_t simdLen32 = sizeof(int_t) == 4 ? simdLen : 2 * simdLen;
 
-  auto h_pos = it.get_id(0);
-
   // 32b offset okay, working memory size will not exceed L2 cache size
   // this is handled at driver level (prefix_sum_esimd3)
   esimd::simd<uint32_t, simdLen32> voff(0,1);
@@ -452,6 +451,7 @@ template <size_t blockSize, bool prevUpdate, typename int_t>
 static inline sycl::event prefixSumSingleWGDriver(sycl::queue &q, int rank, int_t *buf,
                                            uint32_t elem_stride, uint32_t n_entries,
                                            const std::vector<sycl::event>& dependencies) {
+  (void)rank;
 
   constexpr size_t simdLen = sizeof(int_t) == 4 ? 32 : 16;
 
@@ -483,7 +483,7 @@ template <size_t blockSize, typename int_t>
 static inline sycl::event localReductionDriver(sycl::queue &q, int rank, int_t *buf, uint32_t elem_stride,
                                         uint32_t thread_stride, uint32_t n_entries,
                                         const std::vector<sycl::event>& dependencies) {
-
+  (void)rank; // to prevent compiler warning
   constexpr size_t simdLen = sizeof(int_t) == 4 ? 32 : 16;
 
   auto last = q.submit([&](sycl::handler &cgh) {
@@ -515,6 +515,7 @@ template <size_t blockSize, bool prevUpdate, typename int_t>
 static inline sycl::event localPrefixSumDriver(sycl::queue &q, int rank, int_t *buf, uint32_t elem_stride,
                                         uint32_t thread_stride, uint32_t n_entries,
                                         const std::vector<sycl::event>& dependencies) {
+  (void)rank;
 
   constexpr size_t simdLen = sizeof(int_t) == 4 ? 32 : 16;
 
@@ -552,7 +553,6 @@ static inline sycl::event hierarchical_prefix(sycl::queue &q, int rank, int_t *b
                                  const std::vector<sycl::event>& dependencies = {})
 {
   constexpr size_t remainder_threshold = 2 * blockSize;
-  constexpr size_t simdLen = sizeof(int_t) == 4 ? 32 : 16;
 
   // If array is small enough just launch a single work-group kernel to compute prefix sum
   if (n_entries <= remainder_threshold) {
