@@ -99,15 +99,15 @@ extern __DPCPP_SYCL_EXTERNAL void __spirv_CooperativeMatrixStoreCheckedINTEL(
     std::size_t Stride, size_t Height, size_t Width, size_t CoordX,
     size_t CoordY, __spv::MatrixLayout Layout = L, int MemOperand = 0);
 
-template <typename TA, typename TB, typename TC, std::size_t M, std::size_t K,
-          std::size_t N, __spv::MatrixUse UA, __spv::MatrixUse UB,
-          __spv::MatrixUse UC,
+template <typename TA, typename TB, typename TC, typename TD, std::size_t M,
+          std::size_t K, std::size_t N, __spv::MatrixUse UA,
+          __spv::MatrixUse UB, __spv::MatrixUse UC,
           __spv::MatrixLayout LA = __spv::MatrixLayout::RowMajor,
           __spv::MatrixLayout LB = __spv::MatrixLayout::RowMajor,
           __spv::MatrixLayout LC = __spv::MatrixLayout::RowMajor,
           __spv::Scope::Flag S = __spv::Scope::Flag::Subgroup>
 extern __DPCPP_SYCL_EXTERNAL
-    __spv::__spirv_CooperativeMatrixKHR<TC, S, M, N, UC> *
+    __spv::__spirv_CooperativeMatrixKHR<TD, S, M, N, UC> *
     __spirv_CooperativeMatrixMulAddKHR(
         __spv::__spirv_CooperativeMatrixKHR<TA, S, M, K, UA> *A,
         __spv::__spirv_CooperativeMatrixKHR<TB, S, K, N, UB> *B,
@@ -258,74 +258,60 @@ template <typename RetT, class HandleT>
 extern __DPCPP_SYCL_EXTERNAL
     RetT __spirv_ConvertHandleToSampledImageINTEL(HandleT);
 
-#define __SYCL_OpGroupAsyncCopyGlobalToLocal __spirv_GroupAsyncCopy
-#define __SYCL_OpGroupAsyncCopyLocalToGlobal __spirv_GroupAsyncCopy
-
 // Atomic SPIR-V builtins
+// TODO: drop these forward-declarations.
+// As of now, compiler does not forward-declare long long overloads for
+// these and as such we can't drop anything from here. But ideally, we should
+// rely on the compiler to generate those - that would allow to drop
+// spirv_ops.hpp include from more files.
 #define __SPIRV_ATOMIC_LOAD(AS, Type)                                          \
-  extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicLoad(                        \
-      AS const Type *P, __spv::Scope::Flag S,                                  \
-      __spv::MemorySemanticsMask::Flag O);
+  extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicLoad(AS Type *P, int S,      \
+                                                       int O) noexcept;
 #define __SPIRV_ATOMIC_STORE(AS, Type)                                         \
   extern __DPCPP_SYCL_EXTERNAL void __spirv_AtomicStore(                       \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+      AS Type *P, int S, int O, Type V) noexcept;
 #define __SPIRV_ATOMIC_EXCHANGE(AS, Type)                                      \
   extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicExchange(                    \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+      AS Type *P, int S, int O, Type V) noexcept;
 #define __SPIRV_ATOMIC_CMP_EXCHANGE(AS, Type)                                  \
   extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicCompareExchange(             \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag E,    \
-      __spv::MemorySemanticsMask::Flag U, Type V, Type C);
+      AS Type *P, int S, int E, int U, Type V, Type C) noexcept;
 #define __SPIRV_ATOMIC_IADD(AS, Type)                                          \
   extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicIAdd(                        \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+      AS Type *P, int S, int O, Type V) noexcept;
 #define __SPIRV_ATOMIC_ISUB(AS, Type)                                          \
   extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicISub(                        \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+      AS Type *P, int S, int O, Type V) noexcept;
 #define __SPIRV_ATOMIC_FADD(AS, Type)                                          \
   extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicFAddEXT(                     \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+      AS Type *P, int S, int O, Type V) noexcept;
 #define __SPIRV_ATOMIC_SMIN(AS, Type)                                          \
   extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicSMin(                        \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+      AS Type *P, int S, int O, Type V) noexcept;
 #define __SPIRV_ATOMIC_UMIN(AS, Type)                                          \
   extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicUMin(                        \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+      AS Type *P, int S, int O, Type V) noexcept;
 #define __SPIRV_ATOMIC_FMIN(AS, Type)                                          \
   extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicFMinEXT(                     \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+      AS Type *P, int S, int O, Type V) noexcept;
 #define __SPIRV_ATOMIC_SMAX(AS, Type)                                          \
   extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicSMax(                        \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+      AS Type *P, int S, int O, Type V) noexcept;
 #define __SPIRV_ATOMIC_UMAX(AS, Type)                                          \
   extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicUMax(                        \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+      AS Type *P, int S, int O, Type V) noexcept;
 #define __SPIRV_ATOMIC_FMAX(AS, Type)                                          \
   extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicFMaxEXT(                     \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+      AS Type *P, int S, int O, Type V) noexcept;
 #define __SPIRV_ATOMIC_AND(AS, Type)                                           \
-  extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicAnd(                         \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+  extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicAnd(AS Type *P, int S,       \
+                                                      int O, Type V) noexcept;
 #define __SPIRV_ATOMIC_OR(AS, Type)                                            \
-  extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicOr(                          \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+  extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicOr(AS Type *P, int S, int O, \
+                                                     Type V) noexcept;
 #define __SPIRV_ATOMIC_XOR(AS, Type)                                           \
-  extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicXor(                         \
-      AS Type *P, __spv::Scope::Flag S, __spv::MemorySemanticsMask::Flag O,    \
-      Type V);
+  extern __DPCPP_SYCL_EXTERNAL Type __spirv_AtomicXor(AS Type *P, int S,       \
+                                                      int O, Type V) noexcept;
 
 #define __SPIRV_ATOMIC_FLOAT(AS, Type)                                         \
   __SPIRV_ATOMIC_FADD(AS, Type)                                                \
@@ -360,24 +346,21 @@ extern __DPCPP_SYCL_EXTERNAL
   template <typename T>                                                        \
   typename std::enable_if_t<                                                   \
       std::is_integral<T>::value && std::is_signed<T>::value, T>               \
-      __spirv_Atomic##Op(AS T *Ptr, __spv::Scope::Flag Memory,                 \
-                         __spv::MemorySemanticsMask::Flag Semantics,           \
-                         T Value) {                                            \
+      __spirv_Atomic##Op(AS T *Ptr, int Memory, int Semantics,                 \
+                         T Value) noexcept {                                   \
     return __spirv_AtomicS##Op(Ptr, Memory, Semantics, Value);                 \
   }                                                                            \
   template <typename T>                                                        \
   typename std::enable_if_t<                                                   \
       std::is_integral<T>::value && !std::is_signed<T>::value, T>              \
-      __spirv_Atomic##Op(AS T *Ptr, __spv::Scope::Flag Memory,                 \
-                         __spv::MemorySemanticsMask::Flag Semantics,           \
-                         T Value) {                                            \
+      __spirv_Atomic##Op(AS T *Ptr, int Memory, int Semantics,                 \
+                         T Value) noexcept {                                   \
     return __spirv_AtomicU##Op(Ptr, Memory, Semantics, Value);                 \
   }                                                                            \
   template <typename T>                                                        \
   typename std::enable_if_t<std::is_floating_point<T>::value, T>               \
-      __spirv_Atomic##Op(AS T *Ptr, __spv::Scope::Flag Memory,                 \
-                         __spv::MemorySemanticsMask::Flag Semantics,           \
-                         T Value) {                                            \
+      __spirv_Atomic##Op(AS T *Ptr, int Memory, int Semantics,                 \
+                         T Value) noexcept {                                   \
     return __spirv_AtomicF##Op##EXT(Ptr, Memory, Semantics, Value);            \
   }
 
@@ -420,101 +403,46 @@ __SPIRV_ATOMICS(__SPIRV_ATOMIC_MINMAX, Max)
 #undef __SPIRV_ATOMIC_UNSIGNED
 #undef __SPIRV_ATOMIC_XOR
 
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL dataT
-__spirv_SubgroupShuffleINTEL(dataT Data, uint32_t InvocationId) noexcept;
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL dataT
-__spirv_SubgroupShuffleDownINTEL(dataT Current, dataT Next,
-                                 uint32_t Delta) noexcept;
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL dataT
-__spirv_SubgroupShuffleUpINTEL(dataT Previous, dataT Current,
-                               uint32_t Delta) noexcept;
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL dataT
-__spirv_SubgroupShuffleXorINTEL(dataT Data, uint32_t Value) noexcept;
-
 template <typename dataT>
 __SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL dataT
 __spirv_SubgroupBlockReadINTEL(const __attribute__((opencl_global))
                                uint8_t *Ptr) noexcept;
 
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL void
-__spirv_SubgroupBlockWriteINTEL(__attribute__((opencl_global)) uint8_t *Ptr,
-                                dataT Data) noexcept;
-
 template <typename dataT>
 __SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL dataT
 __spirv_SubgroupBlockReadINTEL(const __attribute__((opencl_global))
                                uint16_t *Ptr) noexcept;
 
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL void
-__spirv_SubgroupBlockWriteINTEL(__attribute__((opencl_global)) uint16_t *Ptr,
-                                dataT Data) noexcept;
-
 template <typename dataT>
 __SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL dataT
 __spirv_SubgroupBlockReadINTEL(const __attribute__((opencl_global))
                                uint32_t *Ptr) noexcept;
 
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL void
-__spirv_SubgroupBlockWriteINTEL(__attribute__((opencl_global)) uint32_t *Ptr,
-                                dataT Data) noexcept;
-
 template <typename dataT>
 __SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL dataT
 __spirv_SubgroupBlockReadINTEL(const __attribute__((opencl_global))
                                uint64_t *Ptr) noexcept;
 
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL void
-__spirv_SubgroupBlockWriteINTEL(__attribute__((opencl_global)) uint64_t *Ptr,
-                                dataT Data) noexcept;
-
 template <typename dataT>
 __SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL dataT
 __spirv_SubgroupBlockReadINTEL(const __attribute__((opencl_local))
                                uint8_t *Ptr) noexcept;
 
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL void
-__spirv_SubgroupBlockWriteINTEL(__attribute__((opencl_local)) uint8_t *Ptr,
-                                dataT Data) noexcept;
-
 template <typename dataT>
 __SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL dataT
 __spirv_SubgroupBlockReadINTEL(const __attribute__((opencl_local))
                                uint16_t *Ptr) noexcept;
 
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL void
-__spirv_SubgroupBlockWriteINTEL(__attribute__((opencl_local)) uint16_t *Ptr,
-                                dataT Data) noexcept;
-
 template <typename dataT>
 __SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL dataT
 __spirv_SubgroupBlockReadINTEL(const __attribute__((opencl_local))
                                uint32_t *Ptr) noexcept;
 
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL void
-__spirv_SubgroupBlockWriteINTEL(__attribute__((opencl_local)) uint32_t *Ptr,
-                                dataT Data) noexcept;
-
 template <typename dataT>
 __SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL dataT
 __spirv_SubgroupBlockReadINTEL(const __attribute__((opencl_local))
                                uint64_t *Ptr) noexcept;
 
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL void
-__spirv_SubgroupBlockWriteINTEL(__attribute__((opencl_local)) uint64_t *Ptr,
-                                dataT Data) noexcept;
-
 template <int W, int rW>
 extern __DPCPP_SYCL_EXTERNAL sycl::detail::ap_int<rW>
 __spirv_FixedSqrtINTEL(sycl::detail::ap_int<W> a, bool S, int32_t I, int32_t rI,
@@ -891,10 +819,6 @@ extern __DPCPP_SYCL_EXTERNAL __ocl_WPipeTy<dataT>
 __spirv_CreatePipeFromPipeStorage_write(
     const ConstantPipeStorage *Storage) noexcept;
 
-extern __DPCPP_SYCL_EXTERNAL void
-__spirv_ocl_prefetch(const __attribute__((opencl_global)) char *Ptr,
-                     size_t NumBytes) noexcept;
-
 extern __DPCPP_SYCL_EXTERNAL float
 __spirv_ConvertBF16ToFINTEL(uint16_t) noexcept;
 extern __DPCPP_SYCL_EXTERNAL uint16_t
@@ -906,169 +830,6 @@ template <int N>
 extern __DPCPP_SYCL_EXTERNAL __ocl_vec_t<uint16_t, N>
     __spirv_ConvertFToBF16INTEL(__ocl_vec_t<float, N>) noexcept;
 
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL
-    __SYCL_EXPORT __ocl_vec_t<uint32_t, 4>
-    __spirv_GroupNonUniformBallot(uint32_t Execution, bool Predicate) noexcept;
-
-// TODO: I'm not 100% sure that these NonUniform instructions should be
-// convergent Following precedent set for GroupNonUniformBallot above
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT uint32_t
-__spirv_GroupNonUniformBallotBitCount(__spv::Scope::Flag, int,
-                                      __ocl_vec_t<uint32_t, 4>) noexcept;
-
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT int
-    __spirv_GroupNonUniformBallotFindLSB(__spv::Scope::Flag,
-                                         __ocl_vec_t<uint32_t, 4>) noexcept;
-
-template <typename ValueT, typename IdT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-    __spirv_GroupNonUniformBroadcast(__spv::Scope::Flag, ValueT, IdT);
-
-template <typename ValueT, typename IdT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-    __spirv_GroupNonUniformShuffle(__spv::Scope::Flag, ValueT, IdT) noexcept;
-
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT bool
-__spirv_GroupNonUniformAll(__spv::Scope::Flag, bool);
-
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT bool
-__spirv_GroupNonUniformAny(__spv::Scope::Flag, bool);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformSMin(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformUMin(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformFMin(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformSMax(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformUMax(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformFMax(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformIAdd(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformFAdd(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformIMul(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformFMul(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformBitwiseOr(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformBitwiseXor(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformBitwiseAnd(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformLogicalOr(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformLogicalAnd(__spv::Scope::Flag, unsigned int, ValueT);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformSMin(__spv::Scope::Flag, unsigned int, ValueT,
-                            unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformUMin(__spv::Scope::Flag, unsigned int, ValueT,
-                            unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformFMin(__spv::Scope::Flag, unsigned int, ValueT,
-                            unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformSMax(__spv::Scope::Flag, unsigned int, ValueT,
-                            unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformUMax(__spv::Scope::Flag, unsigned int, ValueT,
-                            unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformFMax(__spv::Scope::Flag, unsigned int, ValueT,
-                            unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformIAdd(__spv::Scope::Flag, unsigned int, ValueT,
-                            unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformFAdd(__spv::Scope::Flag, unsigned int, ValueT,
-                            unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformIMul(__spv::Scope::Flag, unsigned int, ValueT,
-                            unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformFMul(__spv::Scope::Flag, unsigned int, ValueT,
-                            unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformBitwiseOr(__spv::Scope::Flag, unsigned int, ValueT,
-                                 unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformBitwiseXor(__spv::Scope::Flag, unsigned int, ValueT,
-                                  unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformBitwiseAnd(__spv::Scope::Flag, unsigned int, ValueT,
-                                  unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformLogicalOr(__spv::Scope::Flag, unsigned int, ValueT,
-                                 unsigned int);
-
-template <typename ValueT>
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT ValueT
-__spirv_GroupNonUniformLogicalAnd(__spv::Scope::Flag, unsigned int, ValueT,
-                                  unsigned int);
-
 extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT void
 __clc_BarrierInitialize(int64_t *state, int32_t expected_count) noexcept;
 
@@ -1230,43 +991,4 @@ extern __DPCPP_SYCL_EXTERNAL RetT __spirv_TaskSequenceGetINTEL(
 extern __DPCPP_SYCL_EXTERNAL void __spirv_TaskSequenceReleaseINTEL(
     __spv::__spirv_TaskSequenceINTEL *TaskSequence) noexcept;
 
-#else  // if !__SYCL_DEVICE_ONLY__
-
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __ocl_event_t
-__SYCL_OpGroupAsyncCopyGlobalToLocal(__spv::Scope::Flag, dataT *Dest,
-                                     const dataT *Src, size_t NumElements,
-                                     size_t Stride, __ocl_event_t) noexcept {
-  for (size_t i = 0; i < NumElements; i++) {
-    Dest[i] = Src[i * Stride];
-  }
-  // A real instance of the class is not needed, return dummy pointer.
-  return nullptr;
-}
-
-template <typename dataT>
-__SYCL_CONVERGENT__ extern __ocl_event_t
-__SYCL_OpGroupAsyncCopyLocalToGlobal(__spv::Scope::Flag, dataT *Dest,
-                                     const dataT *Src, size_t NumElements,
-                                     size_t Stride, __ocl_event_t) noexcept {
-  for (size_t i = 0; i < NumElements; i++) {
-    Dest[i * Stride] = Src[i];
-  }
-  // A real instance of the class is not needed, return dummy pointer.
-  return nullptr;
-}
-
-extern __SYCL_EXPORT void __spirv_ocl_prefetch(const char *Ptr,
-                                               size_t NumBytes) noexcept;
-
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT void
-__spirv_ControlBarrier(__spv::Scope Execution, __spv::Scope Memory,
-                       uint32_t Semantics) noexcept;
-
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT void
-__spirv_MemoryBarrier(__spv::Scope Memory, uint32_t Semantics) noexcept;
-
-__SYCL_CONVERGENT__ extern __DPCPP_SYCL_EXTERNAL __SYCL_EXPORT void
-__spirv_GroupWaitEvents(__spv::Scope Execution, uint32_t NumEvents,
-                        __ocl_event_t *WaitEvents) noexcept;
 #endif // !__SYCL_DEVICE_ONLY__
