@@ -977,12 +977,15 @@ extern __DPCPP_SYCL_EXTERNAL int __imf_vimin_s32_relu(int x, int y);
 }
 #ifdef __GLIBC__
 namespace std {
-extern __DPCPP_SYCL_EXTERNAL void __glibcxx_assert_fail(const char *file,
-                                                        int line,
-                                                        const char *func,
-                                                        const char *cond);
+extern __DPCPP_SYCL_EXTERNAL void
+__glibcxx_assert_fail(const char *file, int line, const char *func,
+                      const char *cond) noexcept;
 } // namespace std
 extern "C" {
+extern __DPCPP_SYCL_EXTERNAL int feenableexcept(int excepts) noexcept(true);
+extern __DPCPP_SYCL_EXTERNAL int fedisableexcept(int excepts) noexcept(true);
+extern __DPCPP_SYCL_EXTERNAL int feclearexcept(int excepts) noexcept(true);
+extern __DPCPP_SYCL_EXTERNAL int fetestexcept(int excepts) noexcept(true);
 extern __DPCPP_SYCL_EXTERNAL void __assert_fail(const char *expr,
                                                 const char *file,
                                                 unsigned int line,
