@@ -14,11 +14,11 @@ namespace sycl {
 inline namespace _V1 {
 
 class handler;
+namespace ext::oneapi::experimental {
+
 namespace detail {
 class dynamic_parameter_impl;
-}
-
-namespace ext::oneapi::experimental {
+} // namespace detail
 
 class raw_kernel_arg {
 public:
