@@ -1,4 +1,4 @@
-# Copyright (C) 2019-2025 Free Software Foundation, Inc.
+# Copyright (C) 2019-2020 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -317,11 +317,13 @@ class IntelgtAutoAttach:
         gdb.events.gdb_exiting.connect(self.handle_gdb_exiting_event)
         gdb.events.exited.connect(self.handle_exited_event)
         gdb.events.before_prompt.connect(self.handle_before_prompt_event)
+        gdb.events.post_attach.connect(self.handle_post_attach_event)
         self.inf_dict = {}
         self.loaded_objfiles = set()
         self.host_inf_for_auto_remove = None
         self.enable_schedule_multiple_at_gt_removal = False
         self.gt_inferior_init_pending = False
+        self.live_attach_started = False
         # Env variable to pass custom flags to gdbserver such as
         # "--debug" and "--remote-debug" for debugging purposes.
         self.gdbserver_args = self.get_env_variable(
@@ -529,8 +531,18 @@ INTELGT_AUTO_ATTACH_GDBSERVER_GT_PATH is deprecated. Use INTELGT_AUTO_ATTACH_GDB
         if such an inferior was stored for removal."""
         self.remove_gt_inf_if_stored_for_removal()
 
-        """If the host was attached, we init gt inferiors here."""
-        if self.gt_inferior_init_pending:
+    @DebugLogger.log_call
+    def handle_post_attach_event(self, event):
+        """Handler for GDB's 'post attach' event.  If the host was
+        attached, we init gt inferiors here and make sure it is done
+        only once at a time.  Because the make_native_gdbserver function
+        during initialization also sends the attach command which can
+        be ignored."""
+        if event is None:
+            return
+
+        if self.gt_inferior_init_pending and not self.live_attach_started:
+            self.live_attach_started = True
             self.init_gt_inferiors()
 
     @DebugLogger.log_call
@@ -696,7 +708,8 @@ INTELGT_AUTO_ATTACH_GDBSERVER_GT_PATH is deprecated. Use INTELGT_AUTO_ATTACH_GDB
         # needs to resume the device explicitly.
 
         async_mode = not self.gt_inferior_init_pending
-        attach_cmd = f"attach {inf.pid}" + (" &" if async_mode else "")
+        attach_cmd = f"with remotetimeout 15 -- \
+			attach {inf.pid}" + (" &" if async_mode else "")
         DebugLogger.log(f"command: {attach_cmd}")
         gdb.execute(f"with print thread-events off -- {attach_cmd}",
                     False, capture_output)
@@ -727,7 +740,7 @@ Connection name '{connection}' not recognized.""")
                                      to_string = True).endswith("on.\n")
             if not is_nonstop:
                 gdb.execute("set schedule-multiple off")
-            gdb.execute("add-inferior -hidden -no-connection", False, True)
+            gdb.execute("add-inferior -no-connection", False, True)
 
             cli_suppressed = self.set_suppress_notifications("on")
             original_thread = gdb.selected_thread()
@@ -766,6 +779,7 @@ Connection name '{connection}' not recognized.""")
                 gdb.execute("set schedule-multiple on")
 
             self.gt_inferior_init_pending = False
+            self.live_attach_started = False
             return
 
     @staticmethod
