@@ -233,6 +233,7 @@
 #define ippsHashMessage_rmf l9_ippsHashMessage_rmf
 #define ippsHashMethodGetInfo l9_ippsHashMethodGetInfo
 #define ippsHashGetInfo_rmf l9_ippsHashGetInfo_rmf
+#define ippsHashSqueeze_rmf l9_ippsHashSqueeze_rmf
 #define ippsMGF l9_ippsMGF
 #define ippsMGF1_rmf l9_ippsMGF1_rmf
 #define ippsMGF2_rmf l9_ippsMGF2_rmf
@@ -255,6 +256,8 @@
 #define ippsHMACGetTag_rmf l9_ippsHMACGetTag_rmf
 #define ippsHMACMessage_rmf l9_ippsHMACMessage_rmf
 #define ippsHKDF l9_ippsHKDF
+#define ippsHKDF_extract l9_ippsHKDF_extract
+#define ippsHKDF_expand l9_ippsHKDF_expand
 #define ippsBigNumGetSize l9_ippsBigNumGetSize
 #define ippsBigNumInit l9_ippsBigNumInit
 #define ippsCmpZero_BN l9_ippsCmpZero_BN
@@ -499,8 +502,18 @@
 #define ippsXMSSSign l9_ippsXMSSSign
 #define ippsXMSSVerify l9_ippsXMSSVerify
 #define ippsLMSBufferGetSize l9_ippsLMSBufferGetSize
+#define ippsLMSVerifyBufferGetSize l9_ippsLMSVerifyBufferGetSize
 #define ippsLMSSignatureStateGetSize l9_ippsLMSSignatureStateGetSize
 #define ippsLMSPublicKeyStateGetSize l9_ippsLMSPublicKeyStateGetSize
 #define ippsLMSSetPublicKeyState l9_ippsLMSSetPublicKeyState
 #define ippsLMSSetSignatureState l9_ippsLMSSetSignatureState
 #define ippsLMSVerify l9_ippsLMSVerify
+#define ippsMLKEM_GetSize l9_ippsMLKEM_GetSize
+#define ippsMLKEM_GetInfo l9_ippsMLKEM_GetInfo
+#define ippsMLKEM_Init l9_ippsMLKEM_Init
+#define ippsMLKEM_KeyGenBufferGetSize l9_ippsMLKEM_KeyGenBufferGetSize
+#define ippsMLKEM_EncapsBufferGetSize l9_ippsMLKEM_EncapsBufferGetSize
+#define ippsMLKEM_DecapsBufferGetSize l9_ippsMLKEM_DecapsBufferGetSize
+#define ippsMLKEM_KeyGen l9_ippsMLKEM_KeyGen
+#define ippsMLKEM_Encaps l9_ippsMLKEM_Encaps
+#define ippsMLKEM_Decaps l9_ippsMLKEM_Decaps
