@@ -197,13 +197,13 @@ int TestCustomKernels(SparseMatrix &A, Vector &b, Vector &x, const int rank, con
 
     Vector r, w, y, y1, z, Ay, Az;
 
-    // vectors:  nCols x 1 
+    // vectors:  nCols x 1
     InitializeVectorDevice(r, nCols, queue);
     InitializeVectorDevice(w, nCols, queue);
     InitializeVectorDevice(y, nCols, queue);
     InitializeVectorDevice(y1, nCols, queue);
     InitializeVectorDevice(z, nCols, queue);
-    
+
     // vectors: nRows x 1     = [nRows x nCols] [nCols x 1]
     // use nCols as nCols >= nRows to make sure we have room
     InitializeVectorDevice(Ay, nCols, queue);
@@ -268,7 +268,7 @@ int TestCustomKernels(SparseMatrix &A, Vector &b, Vector &x, const int rank, con
 
     // copy over nnz for performance tests
     queue.memcpy(tmp_host, optData->ia + nRows, 1*sizeof(local_int_t)).wait();
-    const double  nnz = static_cast<double>(tmp_host[0]);
+    const std::int64_t nnz_a = static_cast<std::int64_t>(tmp_host[0]);
 
     bool test_passed = false;
 
@@ -282,10 +282,13 @@ int TestCustomKernels(SparseMatrix &A, Vector &b, Vector &x, const int rank, con
     sparse::init_matrix_handle(&hMatrixA);
     sparse::init_matrix_handle(&hMatrixB);
 
-    sparse::set_csr_data(queue, hMatrixA, nRows, nRows, mkl::index_base::zero,
+    sparse::set_csr_data(queue, hMatrixA, nRows, nRows, nnz_a, mkl::index_base::zero,
                          optData->ia, optData->ja, optData->a, {}).wait();
     if (A.geom->size > 1) {
-        sparse::set_csr_data(queue, hMatrixB, optData->nrow_b, nCols, mkl::index_base::zero,
+        // copy over nnz to set the data for matrix B
+        queue.memcpy(tmp_host, optData->ib + nRows_b, 1*sizeof(local_int_t)).wait();
+        const std::int64_t nnz_b = static_cast<std::int64_t>(tmp_host[0]);
+        sparse::set_csr_data(queue, hMatrixB, optData->nrow_b, nCols, nnz_b, mkl::index_base::zero,
                              optData->ib, optData->jb, optData->b).wait();
     }
 
@@ -337,7 +340,7 @@ int TestCustomKernels(SparseMatrix &A, Vector &b, Vector &x, const int rank, con
         };
         cgh.parallel_for<class axbpy_esimd>(sycl::nd_range<1>(ceil_div(nBlocks, nWG) * nWG, nWG), kernel);
     });
-    
+
     // reference code for axpby
     ev_ref = queue.submit([&](sycl::handler &cgh) {
         cgh.depends_on(ev_test);
@@ -349,7 +352,7 @@ int TestCustomKernels(SparseMatrix &A, Vector &b, Vector &x, const int rank, con
     });
 
     check_arrays(queue, nCols, zv, yv, tmp_dev, tmp_host, {ev_ref});
-    
+
     bool failed = (tmp_host[0] == 1);
     print_status(rank, size, "AXPBY", failed ? "failed" : "passed");
     if (failed) testck_data.count_fail++;
@@ -361,7 +364,7 @@ int TestCustomKernels(SparseMatrix &A, Vector &b, Vector &x, const int rank, con
 #endif
 
 #endif //TEST_AXPBY
-    
+
 
 #ifdef TEST_DOT
     // test ComputeDotProductLocal  rdotw_test = dot(r,w)
@@ -634,7 +637,7 @@ int TestCustomKernels(SparseMatrix &A, Vector &b, Vector &x, const int rank, con
 
 //    check_and_print_arrays(queue, nRows, zv, yv, tmp_dev, tmp_host, {ev_ref});
     check_arrays(queue, nRows, zv, yv, tmp_dev, tmp_host, {ev_ref});
-    
+
     failed = tmp_host[0] == 1;
     print_status(rank, size, "SpTRSV FWD", failed ? "failed" : "passed");
     if (failed) testck_data.count_fail++;
@@ -704,7 +707,7 @@ int TestCustomKernels(SparseMatrix &A, Vector &b, Vector &x, const int rank, con
                               1.0,
 #endif
                           hMatrixA, Azv, zv, {ev_test});
-    
+
     // Azv_out = zv_in + D*zv_out = 1.0 + D * zv
     ev_update = queue.submit([&](sycl::handler &cgh) {
         cgh.depends_on(ev_ref);
@@ -746,7 +749,7 @@ int TestCustomKernels(SparseMatrix &A, Vector &b, Vector &x, const int rank, con
     queue.memcpy(Ayv, wv, sizeof(double) * nRows).wait();
     queue.memcpy(Azv, wv, sizeof(double) * nRows).wait();
 
-    // Ayv = wv 
+    // Ayv = wv
     // solve (D+U) * yv_out = Ayv_in; and  Ayv_out = D*Ayv_in
     ev_test = custom::SpTRSV_FUSED(queue, sparseM, custom::uplo::upper_diagonal, Ayv, yv, {});
 
@@ -757,7 +760,7 @@ int TestCustomKernels(SparseMatrix &A, Vector &b, Vector &x, const int rank, con
                               1.0,
 #endif
                           hMatrixA, Azv, zv, {ev_test});
-    
+
     // Azv_out = D*Azv_in
     ev_update = queue.submit([&](sycl::handler &cgh) {
         cgh.depends_on(ev_ref);
