@@ -57,6 +57,7 @@
 #include <linux/errno.h>
 #include <linux/pci.h> /* "pci_get_domain_bus_and_slot" */
 #include <linux/delay.h> /* "udelay" */
+#include <linux/version.h>
 #include <asm/msr.h>
 #ifdef CONFIG_RPMSG_IPC
 	#include <asm/intel_mid_rpmsg.h>
@@ -119,6 +120,14 @@
  */
 #define ALL_32BITS_SET_MASK ((u32)-1)
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6, 16, 0)
+	#define sw_rdmsrq_safe rdmsrq_safe
+	#define sw_wrmsrq_safe wrmsrq_safe
+#else
+	#define sw_rdmsrq_safe rdmsrl_safe
+	#define sw_wrmsrq_safe wrmsrl_safe
+#endif
+
 /*
  * Local data structures.
  */
@@ -730,20 +739,20 @@ void sw_read_mailbox_info_i(char *dst_vals, int cpu,
 	if (mailbox->is_msr_type) {
 		u64 command = 0;
 
-		rdmsrl_safe(interface_address, &command);
+		sw_rdmsrq_safe(interface_address, &command);
 		command &= mailbox->command_mask;
 		command |= mailbox->command | (u64)0x1 << mailbox->run_busy_bit;
-		wrmsrl_safe(interface_address, command);
+		sw_wrmsrq_safe(interface_address, command);
 		do {
 			udelay(1);
-			rdmsrl_safe(interface_address, &command);
+			sw_rdmsrq_safe(interface_address, &command);
 		} while ((command & ((u64)0x1 << mailbox->run_busy_bit)) &&
 				++iter < MAX_MAILBOX_ITERS);
 		if (iter >= MAX_MAILBOX_ITERS) {
 			pw_pr_error("Couldn't write to BIOS mailbox\n");
 			command = MAX_UNSIGNED_64_BIT_VALUE;
 		} else
-			rdmsrl_safe(data_address, &command);
+			sw_rdmsrq_safe(data_address, &command);
 		switch (counter_size_in_bytes) {
 		case 4:
 			*((u32 *)dst_vals) = (u32)command;
@@ -910,7 +919,7 @@ void sw_write_msr_info_i(char *dst_vals, int cpu,
 		"ADDRESS = 0x%llx, CPU = %d, counter size = %u, value = %llu\n",
 		address, cpu, counter_size_in_bytes, write_value);
 	if (likely(cpu == RAW_CPU())) {
-		wrmsrl_safe((unsigned long)address, write_value);
+		sw_wrmsrq_safe((unsigned long)address, write_value);
 	} else {
 		u32 l = write_value & 0xffffffff;
 		u32 h = (write_value >> 32) & 0xffffffff;
@@ -968,14 +977,14 @@ void sw_write_mailbox_info_i(char *dst_vals, int cpu,
 	if (mailbox->is_msr_type) {
 		u64 command = 0;
 
-		rdmsrl_safe(interface_address, &command);
+		sw_rdmsrq_safe(interface_address, &command);
 		command &= mailbox->command_mask;
 		command |= mailbox->command |
 				(u64)0x1 << mailbox->run_busy_bit;
-		wrmsrl_safe(data_address, data);
-		wrmsrl_safe(interface_address, command);
+		sw_wrmsrq_safe(data_address, data);
+		sw_wrmsrq_safe(interface_address, command);
 		do {
-			rdmsrl_safe(interface_address, &command);
+			sw_rdmsrq_safe(interface_address, &command);
 		} while ((command & ((u64)0x1 << mailbox->run_busy_bit)) &&
 				++iter < MAX_MAILBOX_ITERS);
 	} else {
