@@ -168,6 +168,12 @@
            INTEGER ierror
       END SUBROUTINE PMPI_BARRIER
 
+      SUBROUTINE PMPI_FILE_DELETE(filename,info,ierror)
+           CHARACTER (LEN=*) filename
+           INTEGER info
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_DELETE
+
       SUBROUTINE PMPI_INFO_GET_STRING(info,key,buflen,value,flag,ierror)
            INTEGER info
            CHARACTER (LEN=*) key
@@ -266,6 +272,17 @@
            INTEGER ierror
       END SUBROUTINE PMPI_TYPE_CREATE_STRUCT
 
+      SUBROUTINE PMPI_FILE_GET_ATOMICITY(fh,flag,ierror)
+           INTEGER fh
+           LOGICAL flag
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_GET_ATOMICITY
+
+      SUBROUTINE PMPI_INFO_TOINT(info,ierror)
+           INTEGER info
+           INTEGER ierror
+      END SUBROUTINE PMPI_INFO_TOINT
+
       SUBROUTINE PMPI_GROUP_FROM_SESSION_PSET(session,pset_name,newgroup,ierror)
            INTEGER session
            CHARACTER (LEN=*) pset_name
@@ -326,6 +343,12 @@
            INTEGER ierror
       END SUBROUTINE PMPI_INFO_FREE
 
+      SUBROUTINE PMPI_FILE_GET_AMODE(fh,amode,ierror)
+           INTEGER fh
+           INTEGER amode
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_GET_AMODE
+
       SUBROUTINE PMPI_GRAPH_GET(comm,maxindex,maxedges,indx,edges,ierror)
            INTEGER comm
            INTEGER maxindex
@@ -354,6 +377,16 @@
            INTEGER ierror
       END SUBROUTINE PMPI_WIN_FREE
 
+      SUBROUTINE PMPI_FILE_GET_VIEW(fh,disp,etype,filetype,datarep,ierror)
+           USE MPI_CONSTANTS,ONLY:MPI_OFFSET_KIND
+           INTEGER fh
+           INTEGER(KIND=MPI_OFFSET_KIND) disp
+           INTEGER etype
+           INTEGER filetype
+           CHARACTER (LEN=*) datarep
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_GET_VIEW
+
       SUBROUTINE PMPI_SESSION_GET_NUM_PSETS(session,info,npset_names,ierror)
            INTEGER session
            INTEGER info
@@ -385,6 +418,12 @@
            INTEGER ierror
       END SUBROUTINE PMPI_BUFFER_FLUSH
 
+      SUBROUTINE PMPI_ABI_GET_VERSION(abi_major,abi_minor,ierror)
+           INTEGER abi_major
+           INTEGER abi_minor
+           INTEGER ierror
+      END SUBROUTINE PMPI_ABI_GET_VERSION
+
       SUBROUTINE PMPI_OPEN_PORT(info,port_name,ierror)
            INTEGER info
            CHARACTER (LEN=*) port_name
@@ -411,6 +450,11 @@
            INTEGER ierror
       END SUBROUTINE PMPI_FILE_CREATE_ERRHANDLER
 
+      SUBROUTINE PMPI_SESSION_TOINT(session,ierror)
+           INTEGER session
+           INTEGER ierror
+      END SUBROUTINE PMPI_SESSION_TOINT
+
       SUBROUTINE PMPI_COMM_CREATE_GROUP(comm,group,tag,newcomm,ierror)
            INTEGER comm
            INTEGER group
@@ -425,11 +469,6 @@
            INTEGER ierror
       END SUBROUTINE PMPI_ATTR_DELETE
 
-      SUBROUTINE PMPI_SESSION_FINALIZE(session,ierror)
-           INTEGER session
-           INTEGER ierror
-      END SUBROUTINE PMPI_SESSION_FINALIZE
-
       SUBROUTINE PMPI_STATUS_SET_SOURCE(status,source,ierror)
            USE MPI_CONSTANTS,ONLY:MPI_STATUS_SIZE
            INTEGER status(MPI_STATUS_SIZE)
@@ -437,6 +476,35 @@
            INTEGER ierror
       END SUBROUTINE PMPI_STATUS_SET_SOURCE
 
+      SUBROUTINE PMPI_SESSION_FINALIZE(session,ierror)
+           INTEGER session
+           INTEGER ierror
+      END SUBROUTINE PMPI_SESSION_FINALIZE
+
+      SUBROUTINE PMPI_GROUP_TOINT(group,ierror)
+           INTEGER group
+           INTEGER ierror
+      END SUBROUTINE PMPI_GROUP_TOINT
+
+      SUBROUTINE PMPI_FILE_SET_VIEW(fh,disp,etype,filetype,datarep,info,ierror)
+           USE MPI_CONSTANTS,ONLY:MPI_OFFSET_KIND
+           INTEGER fh
+           INTEGER(KIND=MPI_OFFSET_KIND) disp
+           INTEGER etype
+           INTEGER filetype
+           CHARACTER (LEN=*) datarep
+           INTEGER info
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_SET_VIEW
+
+      SUBROUTINE PMPI_FILE_SEEK(fh,offset,whence,ierror)
+           USE MPI_CONSTANTS,ONLY:MPI_OFFSET_KIND
+           INTEGER fh
+           INTEGER(KIND=MPI_OFFSET_KIND) offset
+           INTEGER whence
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_SEEK
+
       SUBROUTINE PMPI_SESSION_IFLUSH_BUFFER(session,request,ierror)
            INTEGER session
            INTEGER request
@@ -539,6 +607,13 @@
            INTEGER ierror
       END SUBROUTINE PMPI_INTERCOMM_MERGE
 
+      SUBROUTINE PMPI_FILE_PREALLOCATE(fh,size,ierror)
+           USE MPI_CONSTANTS,ONLY:MPI_OFFSET_KIND
+           INTEGER fh
+           INTEGER(KIND=MPI_OFFSET_KIND) size
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_PREALLOCATE
+
       SUBROUTINE PMPI_INFO_GET_NTHKEY(info,n,key,ierror)
            INTEGER info
            INTEGER n
@@ -546,6 +621,12 @@
            INTEGER ierror
       END SUBROUTINE PMPI_INFO_GET_NTHKEY
 
+      SUBROUTINE PMPI_FILE_SET_ATOMICITY(fh,flag,ierror)
+           INTEGER fh
+           LOGICAL flag
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_SET_ATOMICITY
+
       SUBROUTINE PMPI_TYPE_MATCH_SIZE(typeclass,size,datatype,ierror)
            INTEGER typeclass
            INTEGER size
@@ -635,6 +716,11 @@
            INTEGER ierror
       END SUBROUTINE PMPI_PARRIVED
 
+      SUBROUTINE PMPI_REQUEST_TOINT(request,ierror)
+           INTEGER request
+           INTEGER ierror
+      END SUBROUTINE PMPI_REQUEST_TOINT
+
       SUBROUTINE PMPI_GET_COUNT(status,datatype,count,ierror)
            USE MPI_CONSTANTS,ONLY:MPI_STATUS_SIZE
            INTEGER status(MPI_STATUS_SIZE)
@@ -695,6 +781,23 @@
            INTEGER ierror
       END SUBROUTINE PMPI_REQUEST_GET_STATUS_ALL
 
+      SUBROUTINE PMPI_FILE_GET_TYPE_EXTENT(fh,datatype,extent,ierror)
+           USE MPI_CONSTANTS,ONLY:MPI_ADDRESS_KIND
+           INTEGER fh
+           INTEGER datatype
+           INTEGER(KIND=MPI_ADDRESS_KIND) extent
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_GET_TYPE_EXTENT
+
+      SUBROUTINE PMPI_FILE_OPEN(comm,filename,amode,info,fh,ierror)
+           INTEGER comm
+           CHARACTER (LEN=*) filename
+           INTEGER amode
+           INTEGER info
+           INTEGER fh
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_OPEN
+
       SUBROUTINE PMPI_COMM_REMOTE_SIZE(comm,size,ierror)
            INTEGER comm
            INTEGER size
@@ -710,11 +813,21 @@
            INTEGER ierror
       END SUBROUTINE PMPI_PROBE
 
+      SUBROUTINE PMPI_FILE_TOINT(file,ierror)
+           INTEGER file
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_TOINT
+
       SUBROUTINE PMPI_WIN_WAIT(win,ierror)
            INTEGER win
            INTEGER ierror
       END SUBROUTINE PMPI_WIN_WAIT
 
+      SUBROUTINE PMPI_COMM_TOINT(comm,ierror)
+           INTEGER comm
+           INTEGER ierror
+      END SUBROUTINE PMPI_COMM_TOINT
+
       SUBROUTINE PMPI_TYPE_CREATE_SUBARRAY(ndims,array_of_sizes,&
                   array_of_subsizes,array_of_starts,order,oldtype,newtype,&
                   ierror)
@@ -813,6 +926,13 @@
            INTEGER ierror
       END SUBROUTINE PMPI_SESSION_GET_INFO
 
+      SUBROUTINE PMPI_FILE_GET_POSITION_SHARED(fh,offset,ierror)
+           USE MPI_CONSTANTS,ONLY:MPI_OFFSET_KIND
+           INTEGER fh
+           INTEGER(KIND=MPI_OFFSET_KIND) offset
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_GET_POSITION_SHARED
+
       SUBROUTINE PMPI_KEYVAL_FREE(keyval,ierror)
            INTEGER keyval
            INTEGER ierror
@@ -957,6 +1077,11 @@
            INTEGER ierror
       END SUBROUTINE PMPI_ERRHANDLER_GET
 
+      SUBROUTINE PMPI_ERRHANDLER_TOINT(errhandler,ierror)
+           INTEGER errhandler
+           INTEGER ierror
+      END SUBROUTINE PMPI_ERRHANDLER_TOINT
+
       SUBROUTINE PMPI_TYPE_LB(datatype,displacement,ierror)
            INTEGER datatype
            INTEGER displacement
@@ -995,6 +1120,12 @@
            INTEGER ierror
       END SUBROUTINE PMPI_WIN_FREE_KEYVAL
 
+      SUBROUTINE PMPI_FILE_GET_INFO(fh,info_used,ierror)
+           INTEGER fh
+           INTEGER info_used
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_GET_INFO
+
       SUBROUTINE PMPI_QUERY_THREAD(provided,ierror)
            INTEGER provided
            INTEGER ierror
@@ -1043,6 +1174,11 @@
            INTEGER ierror
       END SUBROUTINE PMPI_COMM_COMPARE
 
+      SUBROUTINE PMPI_BUFFER_IFLUSH(request,ierror)
+           INTEGER request
+           INTEGER ierror
+      END SUBROUTINE PMPI_BUFFER_IFLUSH
+
       SUBROUTINE PMPI_INFO_GET(info,key,valuelen,value,flag,ierror)
            INTEGER info
            CHARACTER (LEN=*) key
@@ -1052,11 +1188,6 @@
            INTEGER ierror
       END SUBROUTINE PMPI_INFO_GET
 
-      SUBROUTINE PMPI_BUFFER_IFLUSH(request,ierror)
-           INTEGER request
-           INTEGER ierror
-      END SUBROUTINE PMPI_BUFFER_IFLUSH
-
       SUBROUTINE PMPI_TYPE_VECTOR(count,blocklength,stride,oldtype,newtype,&
                   ierror)
            INTEGER count
@@ -1080,6 +1211,11 @@
            INTEGER ierror
       END SUBROUTINE PMPI_WIN_SET_ERRHANDLER
 
+      SUBROUTINE PMPI_FILE_CLOSE(fh,ierror)
+           INTEGER fh
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_CLOSE
+
       SUBROUTINE PMPI_COMM_SPAWN(command,argv,maxprocs,info,root,comm,intercomm,&
                   array_of_errcodes,ierror)
            CHARACTER (LEN=*) command
@@ -1093,6 +1229,13 @@
            INTEGER ierror
       END SUBROUTINE PMPI_COMM_SPAWN
 
+      SUBROUTINE PMPI_FILE_GET_POSITION(fh,offset,ierror)
+           USE MPI_CONSTANTS,ONLY:MPI_OFFSET_KIND
+           INTEGER fh
+           INTEGER(KIND=MPI_OFFSET_KIND) offset
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_GET_POSITION
+
       SUBROUTINE PMPI_COMM_SET_ERRHANDLER(comm,errhandler,ierror)
            INTEGER comm
            INTEGER errhandler
@@ -1139,9 +1282,9 @@
            INTEGER ierror
       END SUBROUTINE PMPI_TYPE_GET_EXTENT_X
 
-      SUBROUTINE PMPI_TYPE_CREATE_F90_REAL(precision,range,newtype,ierror)
-           INTEGER precision
-           INTEGER range
+      SUBROUTINE PMPI_TYPE_CREATE_F90_REAL(p,r,newtype,ierror)
+           INTEGER p
+           INTEGER r
            INTEGER newtype
            INTEGER ierror
       END SUBROUTINE PMPI_TYPE_CREATE_F90_REAL
@@ -1174,8 +1317,8 @@
            INTEGER ierror
       END SUBROUTINE PMPI_INFO_CREATE
 
-      SUBROUTINE PMPI_TYPE_CREATE_F90_INTEGER(range,newtype,ierror)
-           INTEGER range
+      SUBROUTINE PMPI_TYPE_CREATE_F90_INTEGER(r,newtype,ierror)
+           INTEGER r
            INTEGER newtype
            INTEGER ierror
       END SUBROUTINE PMPI_TYPE_CREATE_F90_INTEGER
@@ -1241,6 +1384,11 @@
            INTEGER ierror
       END SUBROUTINE PMPI_TYPE_CREATE_INDEXED_BLOCK
 
+      SUBROUTINE PMPI_ABI_GET_INFO(info,ierror)
+           INTEGER info
+           INTEGER ierror
+      END SUBROUTINE PMPI_ABI_GET_INFO
+
       SUBROUTINE PMPI_TYPE_CREATE_HVECTOR(count,blocklength,stride,oldtype,&
                   newtype,ierror)
            USE MPI_CONSTANTS,ONLY:MPI_ADDRESS_KIND
@@ -1274,6 +1422,11 @@
            INTEGER ierror
       END SUBROUTINE PMPI_INTERCOMM_CREATE
 
+      SUBROUTINE PMPI_OP_TOINT(op,ierror)
+           INTEGER op
+           INTEGER ierror
+      END SUBROUTINE PMPI_OP_TOINT
+
       SUBROUTINE PMPI_COMM_RANK(comm,rank,ierror)
            INTEGER comm
            INTEGER rank
@@ -1351,12 +1504,26 @@
            INTEGER ierror
       END SUBROUTINE PMPI_ERRHANDLER_SET
 
+      SUBROUTINE PMPI_FILE_GET_GROUP(fh,group,ierror)
+           INTEGER fh
+           INTEGER group
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_GET_GROUP
+
       SUBROUTINE PMPI_COMM_IFLUSH_BUFFER(comm,request,ierror)
            INTEGER comm
            INTEGER request
            INTEGER ierror
       END SUBROUTINE PMPI_COMM_IFLUSH_BUFFER
 
+      SUBROUTINE PMPI_FILE_GET_BYTE_OFFSET(fh,offset,disp,ierror)
+           USE MPI_CONSTANTS,ONLY:MPI_OFFSET_KIND
+           INTEGER fh
+           INTEGER(KIND=MPI_OFFSET_KIND) offset
+           INTEGER(KIND=MPI_OFFSET_KIND) disp
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_GET_BYTE_OFFSET
+
       SUBROUTINE PMPI_WIN_FLUSH(rank,win,ierror)
            INTEGER rank
            INTEGER win
@@ -1383,6 +1550,13 @@
            INTEGER ierror
       END SUBROUTINE PMPI_SESSION_SET_ERRHANDLER
 
+      SUBROUTINE PMPI_FILE_SET_SIZE(fh,size,ierror)
+           USE MPI_CONSTANTS,ONLY:MPI_OFFSET_KIND
+           INTEGER fh
+           INTEGER(KIND=MPI_OFFSET_KIND) size
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_SET_SIZE
+
       SUBROUTINE PMPI_TEST(request,flag,status,ierror)
            USE MPI_CONSTANTS,ONLY:MPI_STATUS_SIZE
            INTEGER request
@@ -1414,6 +1588,11 @@
            INTEGER ierror
       END SUBROUTINE PMPI_COMM_GET_INFO
 
+      SUBROUTINE PMPI_FILE_SYNC(fh,ierror)
+           INTEGER fh
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_SYNC
+
       SUBROUTINE PMPI_IPROBE(source,tag,comm,flag,status,ierror)
            USE MPI_CONSTANTS,ONLY:MPI_STATUS_SIZE
            INTEGER source
@@ -1466,11 +1645,35 @@
            INTEGER ierror
       END SUBROUTINE PMPI_ERRHANDLER_FREE
 
+      SUBROUTINE PMPI_FILE_SEEK_SHARED(fh,offset,whence,ierror)
+           USE MPI_CONSTANTS,ONLY:MPI_OFFSET_KIND
+           INTEGER fh
+           INTEGER(KIND=MPI_OFFSET_KIND) offset
+           INTEGER whence
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_SEEK_SHARED
+
       SUBROUTINE PMPI_WIN_UNLOCK_ALL(win,ierror)
            INTEGER win
            INTEGER ierror
       END SUBROUTINE PMPI_WIN_UNLOCK_ALL
 
+      SUBROUTINE PMPI_WIN_TOINT(win,ierror)
+           INTEGER win
+           INTEGER ierror
+      END SUBROUTINE PMPI_WIN_TOINT
+
+      SUBROUTINE PMPI_ABI_GET_FORTRAN_INFO(info,ierror)
+           INTEGER info
+           INTEGER ierror
+      END SUBROUTINE PMPI_ABI_GET_FORTRAN_INFO
+
+      SUBROUTINE PMPI_FILE_SET_INFO(fh,info,ierror)
+           INTEGER fh
+           INTEGER info
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_SET_INFO
+
       SUBROUTINE PMPI_TYPE_HINDEXED(count,array_of_blocklengths,&
                   array_of_displacements,oldtype,newtype,ierror)
            INTEGER count
@@ -1497,6 +1700,16 @@
            INTEGER ierror
       END SUBROUTINE PMPI_MPROBE
 
+      SUBROUTINE PMPI_TYPE_TOINT(datatype,ierror)
+           INTEGER datatype
+           INTEGER ierror
+      END SUBROUTINE PMPI_TYPE_TOINT
+
+      SUBROUTINE PMPI_MESSAGE_TOINT(message,ierror)
+           INTEGER message
+           INTEGER ierror
+      END SUBROUTINE PMPI_MESSAGE_TOINT
+
       SUBROUTINE PMPI_TYPE_SIZE(datatype,size,ierror)
            INTEGER datatype
            INTEGER size
@@ -1560,6 +1773,13 @@
            INTEGER ierror
       END SUBROUTINE PMPI_INTERCOMM_CREATE_FROM_GROUPS
 
+      SUBROUTINE PMPI_FILE_GET_SIZE(fh,size,ierror)
+           USE MPI_CONSTANTS,ONLY:MPI_OFFSET_KIND
+           INTEGER fh
+           INTEGER(KIND=MPI_OFFSET_KIND) size
+           INTEGER ierror
+      END SUBROUTINE PMPI_FILE_GET_SIZE
+
       SUBROUTINE PMPI_SESSION_FLUSH_BUFFER(session,ierror)
            INTEGER session
            INTEGER ierror
@@ -1622,9 +1842,9 @@
            INTEGER ierror
       END SUBROUTINE PMPI_CLOSE_PORT
 
-      SUBROUTINE PMPI_TYPE_CREATE_F90_COMPLEX(precision,range,newtype,ierror)
-           INTEGER precision
-           INTEGER range
+      SUBROUTINE PMPI_TYPE_CREATE_F90_COMPLEX(p,r,newtype,ierror)
+           INTEGER p
+           INTEGER r
            INTEGER newtype
            INTEGER ierror
       END SUBROUTINE PMPI_TYPE_CREATE_F90_COMPLEX
