@@ -1,7 +1,6 @@
 /* Branch trace support for GDB, the GNU debugger.
 
-   Copyright (C) 2013-2025 Free Software Foundation, Inc.
-   Copyright (C) 2013-2025 Intel Corporation
+   Copyright (C) 2013-2024 Free Software Foundation, Inc.
 
    Contributed by Intel Corp. <markus.t.metzger@intel.com>
 
@@ -20,6 +19,7 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
+#include "gdbsupport/gdb_vecs.h"
 #include "record.h"
 #include "record-btrace.h"
 #include "gdbthread.h"
@@ -748,7 +748,7 @@ btrace_find_line_range (CORE_ADDR pc)
     {
       /* The test of is_stmt here was added when the is_stmt field was
 	 introduced to the 'struct linetable_entry' structure.  This
-	 ensured that this loop maintained the same behaviour as before we
+	 ensured that this loop maintained the same behavior as before we
 	 introduced is_stmt.  That said, it might be that we would be
 	 better off not checking is_stmt here, this would lead to us
 	 possibly adding more line numbers to the range.  At the time this
@@ -3176,7 +3176,7 @@ show_record_pt_event_tracing_value (struct ui_file *file, int from_tty,
 #if (LIBIPT_VERSION >= 0x201)
   gdb_printf (file, _("record pt event-tracing is %s.\n"), value);
 #else
-  gdb_printf (_("Event-tracing support was disabled at compile time.\n"));
+  gdb_printf (_("Event-tracing is not supported by GDB.\n"));
 #endif /* defined (LIBIPT_VERSION >= 0x201) */
 }
 
@@ -3189,7 +3189,7 @@ set_record_pt_event_tracing_value (const char *args, int from_tty,
 #if (LIBIPT_VERSION >= 0x201)
   record_btrace_conf.pt.event_tracing = event_tracing;
 #else
-  gdb_printf (_("Event-tracing support was disabled at compile time.\n"));
+  gdb_printf (_("Event-tracing is not supported by GDB.\n"));
 #endif /* defined (LIBIPT_VERSION >= 0x201) */
 }
 
@@ -3236,10 +3236,10 @@ Set what memory accesses are allowed during replay."), _("\
 Show what memory accesses are allowed during replay."),
 			   _("Default is READ-ONLY.\n\n\
 The btrace record target does not trace data.\n\
-The memory therefore corresponds to the live target and not \
+The memory therefore corresponds to the live target and not\n\
 to the current replay position.\n\n\
 When READ-ONLY, allow accesses to read-only memory during replay.\n\
-When READ-WRITE, allow accesses to read-only and read-write memory during \
+When READ-WRITE, allow accesses to read-only and read-write memory during\n\
 replay."),
 			   NULL, cmd_show_replay_memory_access,
 			   &set_record_btrace_cmdlist,
@@ -3283,10 +3283,10 @@ Show the cpu to be used for trace decode."),
 			    &record_btrace_conf.bts.size,
 			    _("Set the record/replay bts buffer size."),
 			    _("Show the record/replay bts buffer size."), _("\
-When starting recording request a trace buffer of this size.  \
-The actual buffer size may differ from the requested size.  \
+When starting recording request a trace buffer of this size.\n\
+The actual buffer size may differ from the requested size.\n\
 Use \"info record\" to see the actual buffer size.\n\n\
-Bigger buffers allow longer recording but also take more time to process \
+Bigger buffers allow longer recording but also take more time to process\n\
 the recorded execution trace.\n\n\
 The trace buffer size may not be changed while recording."), NULL,
 			    show_record_bts_buffer_size_value,
@@ -3305,9 +3305,9 @@ The trace buffer size may not be changed while recording."), NULL,
 			    &record_btrace_conf.pt.size,
 			    _("Set the record/replay pt buffer size."),
 			    _("Show the record/replay pt buffer size."), _("\
-Bigger buffers allow longer recording but also take more time to process \
+Bigger buffers allow longer recording but also take more time to process\n\
 the recorded execution.\n\
-The actual buffer size may differ from the requested size.  Use \"info record\" \
+The actual buffer size may differ from the requested size.  Use \"info record\"\n\
 to see the actual buffer size."), NULL, show_record_pt_buffer_size_value,
 			    &set_record_btrace_pt_cmdlist,
 			    &show_record_btrace_pt_cmdlist);
@@ -3316,9 +3316,9 @@ to see the actual buffer size."), NULL, show_record_pt_buffer_size_value,
 			   _("Set event-tracing for record pt."),
 			   _("Show event-tracing for record pt."),
 			   _("\
-Use \"on\" to enable event tracing for recordings with Intel Processor Trace,  \
+Use \"on\" to enable event tracing for recordings with Intel Processor Trace,\n\
 and \"off\" to disable it.\n\
-Without an argument, event tracing is enabled.  Changing this setting has no\
+Without an argument, event tracing is enabled.  Changing this setting has no\n\
 effect on an active recording."),
 			   set_record_pt_event_tracing_value,
 			   show_record_pt_event_tracing_value,
