@@ -1,6 +1,5 @@
 /* Remote utility routines for the remote server for GDB.
-   Copyright (C) 1986-2025 Free Software Foundation, Inc.
-   Copyright (C) 2020-2025 Intel Corporation
+   Copyright (C) 1986-2024 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -25,6 +24,7 @@
 #include "tdesc.h"
 #include "debug.h"
 #include "dll.h"
+#include "gdbsupport/common-gdbthread.h"
 #include "gdbsupport/rsp-low.h"
 #include "gdbsupport/scope-exit.h"
 #include "gdbsupport/netstuff.h"
@@ -565,10 +565,11 @@ read_ptid (const char *buf, const char **obuf)
 {
   const char *p = buf;
   const char *pp;
-  ULONGEST pid = 0, tid = 0;
 
   if (*p == 'p')
     {
+      ULONGEST pid;
+
       /* Multi-process ptid.  */
       pp = unpack_varlen_hex (p + 1, &pid);
       if (*pp != '.')
@@ -576,15 +577,16 @@ read_ptid (const char *buf, const char **obuf)
 
       p = pp + 1;
 
-      tid = hex_or_minus_one (p, &pp);
+      ULONGEST tid = hex_or_minus_one (p, &pp);
 
       if (obuf)
 	*obuf = pp;
+
       return ptid_t (pid, tid);
     }
 
   /* No multi-process.  Just a tid.  */
-  tid = hex_or_minus_one (p, &pp);
+  ULONGEST tid = hex_or_minus_one (p, &pp);
 
   if (obuf)
     *obuf = pp;
@@ -596,7 +598,7 @@ read_ptid (const char *buf, const char **obuf)
   if (first_proc == nullptr)
     return null_ptid;
 
-  pid = pid_of (first_proc);
+  int pid = first_proc->pid;
 
   return ptid_t (pid, tid);
 }
