@@ -327,7 +327,7 @@ unc_mmio_multiple_bar_Write_PMU(VOID *param)
 			reg_value |= (U32)ECB_entries_reg_value(pecb, idx);
 		}
 
-		SEP_DRV_LOG_TRACE("va=0x%llx, ro=0x%x, rv=0x%x", virtual_addr,
+		SEP_DRV_LOG_TRACE("va=0x%llx, ro=0x%x, rv=0x%llx", virtual_addr,
 				  offset, reg_value);
 		if (IS_64BIT((U64)(ECB_entries_max_bits(pecb, idx)))) {
 			PCI_MMIO_Write_U64(virtual_addr, offset, reg_value);
