@@ -1,7 +1,6 @@
 /* Manage a shadow stack pointer for GDB, the GNU debugger.
 
-   Copyright (C) 2024-2025 Free Software Foundation, Inc.
-   Copyright (C) 2024-2025 Intel Corporation
+   Copyright (C) 2024 Free Software Foundation, Inc.
    This file is part of GDB.
 
    This program is free software; you can redistribute it and/or modify
@@ -66,15 +65,18 @@ update_shadow_stack_pointer (gdbarch *gdbarch, CORE_ADDR ssp,
 
 /* See shadow-stack.h.  */
 
-void shadow_stack_push (gdbarch *gdbarch, const CORE_ADDR new_addr)
+void shadow_stack_push (gdbarch *gdbarch, const CORE_ADDR new_addr,
+			regcache *regcache)
 {
   if (!gdbarch_address_in_shadow_stack_memory_range_p (gdbarch)
       || gdbarch_ssp_regnum (gdbarch) == -1)
     return;
 
+  bool shadow_stack_enabled;
   std::optional<CORE_ADDR> ssp
-    = gdbarch_get_shadow_stack_pointer (gdbarch);
-  if (!ssp.has_value ())
+    = gdbarch_get_shadow_stack_pointer (gdbarch, regcache,
+					shadow_stack_enabled);
+  if (!ssp.has_value () || !shadow_stack_enabled)
     return;
 
   const CORE_ADDR new_ssp
@@ -101,7 +103,6 @@ void shadow_stack_push (gdbarch *gdbarch, const CORE_ADDR new_addr)
   write_memory_unsigned_integer (new_ssp, element_size, byte_order,
 				 (ULONGEST) new_addr);
 
-  regcache *regcache = get_thread_regcache (inferior_thread ());
   regcache_raw_write_unsigned (regcache,
 			       gdbarch_ssp_regnum (gdbarch),
 			       new_ssp);
@@ -534,9 +535,14 @@ backtrace_shadow_command (const shadow_stack_print_options &print_options,
     error (_("Printing of the shadow stack backtrace is not supported for"
 	     " the current target."));
 
+  regcache *regcache = get_thread_regcache (inferior_thread ());
+  bool shadow_stack_enabled = false;
+
   std::optional<CORE_ADDR> start_ssp
-    = gdbarch_get_shadow_stack_pointer (gdbarch);
-  if (!start_ssp.has_value ())
+    = gdbarch_get_shadow_stack_pointer (gdbarch, regcache,
+					shadow_stack_enabled);
+
+  if (!start_ssp.has_value () || !shadow_stack_enabled)
     error (_("Shadow stack is not enabled for the current target."));
 
   /* Check if START_SSP points to a shadow stack memory range and use
