@@ -95,7 +95,7 @@ class diagonalMVClass;
 //
 template <typename dataType, typename intType>
 static void extract_diagonal(sycl::queue q,
-                             const intType n,
+                             const std::int64_t n,
                              sycl::buffer<intType, 1> &ia_buffer,
                              sycl::buffer<intType, 1> &ja_buffer,
                              sycl::buffer<dataType, 1> &a_buffer,
@@ -131,7 +131,7 @@ static void extract_diagonal(sycl::queue q,
 template <typename dataType, typename intType>
 static void modify_diagonal(sycl::queue q,
                             const dataType new_diagVal,
-                            const intType n,
+                            const std::int64_t n,
                             sycl::buffer<intType, 1> &ia_buffer,
                             sycl::buffer<intType, 1> &ja_buffer,
                             sycl::buffer<dataType, 1> &a_buffer, // to be modified
@@ -224,7 +224,7 @@ int run_sparse_blas_example(sycl::queue &q)
     try {
         // Matrix data size
         intType size  = 4;
-        intType n = size * size * size; // A is n x n
+        const std::int64_t n = size * size * size; // A is n x n
 
         // PCG settings
         const intType maxIter = 500;
@@ -242,7 +242,7 @@ int run_sparse_blas_example(sycl::queue &q)
 
         generate_sparse_matrix<dataType, intType>(size, ia, ja, a);
 
-        const intType a_nnz = ia[n]; // 0 based indexing
+        const std::int64_t a_nnz = ia[n]; // 0 based indexing
 
         // Vectors x and y
         std::vector<dataType, mkl_allocator<dataType, 64>> x;
@@ -286,7 +286,7 @@ int run_sparse_blas_example(sycl::queue &q)
 
         oneapi::mkl::sparse::init_matrix_handle(&csrA);
 
-        oneapi::mkl::sparse::set_csr_data(q, csrA, n, n, oneapi::mkl::index_base::zero,
+        oneapi::mkl::sparse::set_csr_data(q, csrA, n, n, a_nnz, oneapi::mkl::index_base::zero,
                                           ia_buffer, ja_buffer, a_buffer);
 
         // properties set on csrA which aide in internal optimizations (especially for trsv)
