@@ -414,7 +414,7 @@ int run_sparse_blas_example(sycl::queue &q)
         // setup optimizations and properties we know about A matrix
         oneapi::mkl::sparse::init_matrix_handle(&csrA);
 
-        auto ev_set = oneapi::mkl::sparse::set_csr_data(q, csrA, n, n,
+        auto ev_set = oneapi::mkl::sparse::set_csr_data(q, csrA, n, n, nnz,
                 oneapi::mkl::index_base::zero, ia_d, ja_d, a_d, {});
 
         oneapi::mkl::sparse::set_matrix_property(csrA, oneapi::mkl::sparse::property::symmetric);
