@@ -99,7 +99,7 @@ class diagonalMVClass;
 //
 template <typename dataType, typename intType>
 sycl::event extract_diagonal(sycl::queue q,
-                             const intType n,
+                             const std::int64_t n,
                              const intType *ia_d,
                              const intType *ja_d,
                              const dataType *a_d,
@@ -128,7 +128,7 @@ sycl::event extract_diagonal(sycl::queue q,
 template <typename dataType, typename intType>
 sycl::event modify_diagonal(sycl::queue q,
                             const dataType new_diagVal,
-                            const intType n,
+                            const std::int64_t n,
                             const intType *ia_d,
                             const intType *ja_d,
                                   dataType *a_d, // to be modified
@@ -227,9 +227,9 @@ int run_sparse_blas_example(sycl::queue &q)
 
         // Matrix data size
         const intType size  = 16;
-        const intType n = size * size * size; // A is n x n
+        const std::int64_t n = size * size * size; // A is n x n
 
-        const intType nnzUB = 27 * n; // upper bound of nnz from 27 point stencil
+        const std::int64_t nnzUB = 27 * n; // upper bound of nnz from 27 point stencil
 
         // PCG settings
         const intType maxIter = 500;
@@ -260,7 +260,7 @@ int run_sparse_blas_example(sycl::queue &q)
         //
         generate_sparse_matrix<dataType, intType>(size, ia_h, ja_h, a_h);
 
-        const intType nnz = ia_h[n]; // assumes zero indexing
+        const std::int64_t nnz = ia_h[n]; // assumes zero indexing
 
         // Init right hand side and vector x
         for (int i = 0; i < n; i++) {
@@ -340,7 +340,7 @@ int run_sparse_blas_example(sycl::queue &q)
         // setup optimizations and properties we know about A matrix
         oneapi::mkl::sparse::init_matrix_handle(&csrA);
 
-        auto ev_set = oneapi::mkl::sparse::set_csr_data(q, csrA, n, n,
+        auto ev_set = oneapi::mkl::sparse::set_csr_data(q, csrA, n, n, nnz,
                 oneapi::mkl::index_base::zero, ia_d, ja_d, a_d, {});
 
         oneapi::mkl::sparse::set_matrix_property(csrA, oneapi::mkl::sparse::property::symmetric);
