@@ -98,14 +98,14 @@ int run_sparse_blas_example(sycl::queue &q)
         //
         intType size = 4;
 
-        intType a_nrows = size * size * size;
-        intType a_ncols = a_nrows;
-        intType a_nnz   = 27 * a_nrows;
-        intType b_nrows = size * size * size;
-        intType b_ncols = b_nrows;
-        intType b_nnz   = 27 * b_nrows;
-        intType c_nrows = size * size * size;
-        intType c_ncols = c_nrows;
+        const std::int64_t a_nrows = size * size * size;
+        const std::int64_t a_ncols = a_nrows;
+              std::int64_t a_nnz   = 27 * a_nrows;
+        const std::int64_t b_nrows = size * size * size;
+        const std::int64_t b_ncols = b_nrows;
+              std::int64_t b_nnz   = 27 * b_nrows;
+        const std::int64_t c_nrows = size * size * size;
+        const std::int64_t c_ncols = c_nrows;
         // c_nnz is unknown at this point
 
         //
@@ -172,9 +172,9 @@ int run_sparse_blas_example(sycl::queue &q)
         oneapi::mkl::sparse::init_matrix_handle(&csrB);
         oneapi::mkl::sparse::init_matrix_handle(&csrC);
 
-        oneapi::mkl::sparse::set_csr_data(q, csrA, a_nrows, a_ncols, a_index, a_rowptr, a_colind, a_val);
+        oneapi::mkl::sparse::set_csr_data(q, csrA, a_nrows, a_ncols, a_nnz, a_index, a_rowptr, a_colind, a_val);
 
-        oneapi::mkl::sparse::set_csr_data(q, csrB, b_nrows, b_ncols, b_index, b_rowptr, b_colind, b_val);
+        oneapi::mkl::sparse::set_csr_data(q, csrB, b_nrows, b_ncols, b_nnz, b_index, b_rowptr, b_colind, b_val);
 
         //
         // only c_rowptr exists at this point in process so create some
@@ -182,7 +182,7 @@ int run_sparse_blas_example(sycl::queue &q)
         //
         sycl::buffer<intType, 1> c_colind_dummy(0);
         sycl::buffer<dataType, 1> c_vals_dummy(0);
-        oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, c_index, c_rowptr, c_colind_dummy,
+        oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, 0, c_index, c_rowptr, c_colind_dummy,
                                           c_vals_dummy);
 
         //
@@ -256,7 +256,7 @@ int run_sparse_blas_example(sycl::queue &q)
         }
         sycl::buffer<intType, 1> c_colind(c_nnz);
         sycl::buffer<dataType, 1> c_vals(c_nnz);
-        oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, c_index, c_rowptr, c_colind, c_vals);
+        oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, c_nnz, c_index, c_rowptr, c_colind, c_vals);
 
         // Step 3.3  finalize into C matrix
         req = oneapi::mkl::sparse::matmat_request::finalize;
@@ -282,7 +282,7 @@ int run_sparse_blas_example(sycl::queue &q)
             auto c        = c_vals.get_host_access(sycl::read_only);
             intType c_ind = c_index == oneapi::mkl::index_base::zero ? 0 : 1;
             std::cout << "C matrix [first two rows]:" << std::endl;
-            for (intType row = 0; row < std::min(static_cast<intType>(2), c_nrows); ++row) {
+            for (intType row = 0; row < std::min(static_cast<std::int64_t>(2), c_nrows); ++row) {
                 for (intType j = ic[row] - c_ind; j < ic[row + 1] - c_ind; ++j) {
                     intType col = jc[j];
                     dataType val  = c[j];
