@@ -106,14 +106,14 @@ int run_sparse_blas_example(sycl::queue &q)
         //
         intType size = 4;
 
-        intType a_nrows = size * size * size;
-        intType a_ncols = a_nrows;
-        intType a_nnz   = 27 * a_nrows;
-        intType b_nrows = size * size * size;
-        intType b_ncols = b_nrows;
-        intType b_nnz   = 27 * b_nrows;
-        intType c_nrows = size * size * size;
-        intType c_ncols = c_nrows;
+        const std::int64_t a_nrows = size * size * size;
+        const std::int64_t a_ncols = a_nrows;
+              std::int64_t a_nnz   = 27 * a_nrows;
+        const std::int64_t b_nrows = size * size * size;
+        const std::int64_t b_ncols = b_nrows;
+              std::int64_t b_nnz   = 27 * b_nrows;
+        const std::int64_t c_nrows = size * size * size;
+        const std::int64_t c_ncols = c_nrows;
         // c_nnz is unknown at this point
 
         //
@@ -260,15 +260,15 @@ int run_sparse_blas_example(sycl::queue &q)
         oneapi::mkl::sparse::init_matrix_handle(&csrB);
         oneapi::mkl::sparse::init_matrix_handle(&csrC);
 
-        auto ev_setA = oneapi::mkl::sparse::set_csr_data(q, csrA, a_nrows, a_ncols, a_index,
+        auto ev_setA = oneapi::mkl::sparse::set_csr_data(q, csrA, a_nrows, a_ncols, a_nnz, a_index,
                 a_rowptr, a_colind, a_values, {ev_cpy_ia, ev_cpy_ja, ev_cpy_a});
-        auto ev_setB = oneapi::mkl::sparse::set_csr_data(q, csrB, b_nrows, b_ncols, b_index,
+        auto ev_setB = oneapi::mkl::sparse::set_csr_data(q, csrB, b_nrows, b_ncols, b_nnz, b_index,
                 b_rowptr, b_colind, b_values, {ev_cpy_ib, ev_cpy_jb, ev_cpy_b});
 
         //
         // only c_rowptr exists at this point in process so pass in nullptrs
         //
-        auto ev_setC = oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, c_index, c_rowptr, (intType *)nullptr, (dataType *)nullptr, {});
+        auto ev_setC = oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, 0, c_index, c_rowptr, (intType *)nullptr, (dataType *)nullptr, {});
 
         //
         // initialize the matmat descriptor
@@ -323,7 +323,7 @@ int run_sparse_blas_example(sycl::queue &q)
         }
         int_ptr_vec.push_back(c_colind);
         data_ptr_vec.push_back(c_values);
-        ev_setC = oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, c_index, c_rowptr, c_colind, c_values, {ev3_1});
+        ev_setC = oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, c_nnz[0], c_index, c_rowptr, c_colind, c_values, {ev3_1});
 
         // Step 3.3  finalize into C matrix
         req = oneapi::mkl::sparse::matmat_request::finalize;
