@@ -106,14 +106,14 @@ int run_sparse_blas_example(sycl::queue &q)
         //
         intType size = 4;
 
-        intType a_nrows = size * size * size;
-        intType a_ncols = a_nrows;
-        intType a_nnz   = 27 * a_nrows;
-        intType b_nrows = size * size * size;
-        intType b_ncols = b_nrows;
-        intType b_nnz   = 27 * b_nrows;
-        intType c_nrows = size * size * size;
-        intType c_ncols = c_nrows;
+        const std::int64_t a_nrows = size * size * size;
+        const std::int64_t a_ncols = a_nrows;
+              std::int64_t a_nnz   = 27 * a_nrows;
+        const std::int64_t b_nrows = size * size * size;
+        const std::int64_t b_ncols = b_nrows;
+              std::int64_t b_nnz   = 27 * b_nrows;
+        const std::int64_t c_nrows = size * size * size;
+        const std::int64_t c_ncols = c_nrows;
         // c_nnz is unknown at this point
 
         //
@@ -213,13 +213,13 @@ int run_sparse_blas_example(sycl::queue &q)
         oneapi::mkl::sparse::init_matrix_handle(&csrB);
         oneapi::mkl::sparse::init_matrix_handle(&csrC);
 
-        auto ev_setA = oneapi::mkl::sparse::set_csr_data(q, csrA, a_nrows, a_ncols, a_index, a_rowptr, a_colind, a_values, {});
-        auto ev_setB = oneapi::mkl::sparse::set_csr_data(q, csrB, b_nrows, b_ncols, b_index, b_rowptr, b_colind, b_values, {});
+        auto ev_setA = oneapi::mkl::sparse::set_csr_data(q, csrA, a_nrows, a_ncols, a_nnz, a_index, a_rowptr, a_colind, a_values, {});
+        auto ev_setB = oneapi::mkl::sparse::set_csr_data(q, csrB, b_nrows, b_ncols, b_nnz, b_index, b_rowptr, b_colind, b_values, {});
 
         //
         // only c_rowptr exists at this point in process so pass in nullptrs
         //
-        auto ev_setC = oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, c_index, c_rowptr,
+        auto ev_setC = oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, 0, c_index, c_rowptr,
                                           (intType *)nullptr, (dataType *)nullptr, {});
 
         //
@@ -330,7 +330,7 @@ int run_sparse_blas_example(sycl::queue &q)
             throw std::runtime_error(errorMessage);
         }
         int_ptr_vec.push_back(c_colind);
-        ev_setC = oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, c_index, c_rowptr, c_colind,
+        ev_setC = oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, c_nnz[0], c_index, c_rowptr, c_colind,
                                           (dataType *)nullptr, {ev3_1});
 
         // Step 3.3  finalize into C matrix
@@ -347,7 +347,7 @@ int run_sparse_blas_example(sycl::queue &q)
             auto kernel = [=]() {
                 std::cout << "C matrix structure [first two rows]:" << std::endl;
                 intType c_ind = c_index == oneapi::mkl::index_base::zero ? 0 : 1;
-                for (intType row = 0; row < std::min(static_cast<intType>(2), c_nrows); ++row) {
+                for (intType row = 0; row < std::min(static_cast<std::int64_t>(2), c_nrows); ++row) {
                     for (intType j = c_rowptr[row] - c_ind; j < c_rowptr[row + 1] - c_ind; ++j) {
                         intType col = c_colind[j];
                         std::cout << "C(" << row + c_ind << ", " << col << ") is nonzero"
