@@ -95,14 +95,14 @@ int run_sparse_blas_example(sycl::queue &q)
         //
         intType size = 4;
 
-        intType a_nrows = size * size * size;
-        intType a_ncols = a_nrows;
-        intType a_nnz   = 27 * a_nrows;
-        intType b_nrows = size * size * size;
-        intType b_ncols = b_nrows;
-        intType b_nnz   = 27 * b_nrows;
-        intType c_nrows = size * size * size;
-        intType c_ncols = c_nrows;
+        const std::int64_t a_nrows = size * size * size;
+        const std::int64_t a_ncols = a_nrows;
+              std::int64_t a_nnz   = 27 * a_nrows;
+        const std::int64_t b_nrows = size * size * size;
+        const std::int64_t b_ncols = b_nrows;
+              std::int64_t b_nnz   = 27 * b_nrows;
+        const std::int64_t c_nrows = size * size * size;
+        const std::int64_t c_ncols = c_nrows;
 
         //
         // setup A data locally in CSR format
@@ -230,9 +230,9 @@ int run_sparse_blas_example(sycl::queue &q)
         oneapi::mkl::sparse::init_matrix_handle(&csrA);
         oneapi::mkl::sparse::init_matrix_handle(&csrB);
 
-        auto ev_setA = oneapi::mkl::sparse::set_csr_data(q, csrA, a_nrows, a_ncols, a_index,
+        auto ev_setA = oneapi::mkl::sparse::set_csr_data(q, csrA, a_nrows, a_ncols, a_nnz, a_index,
                 a_rowptr, a_colind, a_values, {ev_cpy_ia, ev_cpy_ja, ev_cpy_a});
-        auto ev_setB = oneapi::mkl::sparse::set_csr_data(q, csrB, b_nrows, b_ncols, b_index,
+        auto ev_setB = oneapi::mkl::sparse::set_csr_data(q, csrB, b_nrows, b_ncols, b_nnz, b_index,
                 b_rowptr, b_colind, b_values, {ev_cpy_ib, ev_cpy_jb, ev_cpy_b});
         auto ev_fillC = q.fill<dataType>(dnsC, dataType(0), c_size);
 
@@ -244,7 +244,7 @@ int run_sparse_blas_example(sycl::queue &q)
             ldc, {ev_setA, ev_setB, ev_fillC});
 
         // Copy C matrix to host for printing
-        const intType c_nrows_copy = std::min<intType>(2, c_nrows); // only copy over this many rows of C to host
+        const intType c_nrows_copy = std::min<std::int64_t>(2, c_nrows); // only copy over this many rows of C to host
 
         dataType *dnsC_host = sycl::malloc_host<dataType>(c_ncols * c_nrows_copy, q);
         if (!dnsC_host) {
