@@ -97,15 +97,15 @@ int run_sparse_blas_example(sycl::queue &q)
         //
         intType size = 4;
 
-        intType a_nrows = size * size * size;
-        intType a_ncols = a_nrows;
-        intType a_nnz   = 27 * a_nrows;
-        intType b_nrows = (opA == opB) ? a_nrows : a_ncols;
-        intType b_ncols = (opA == opB) ? a_ncols : a_nrows;
-        intType b_nnz   = 27 * a_nrows;
-        intType c_nrows = (opA == oneapi::mkl::transpose::nontrans) ? a_nrows : a_ncols;
-        intType c_ncols = (opA == oneapi::mkl::transpose::nontrans) ? a_ncols : a_nrows;
-        // c_nnz is unknown at this point
+        const std::int64_t a_nrows = size * size * size;
+        const std::int64_t a_ncols = a_nrows;
+              std::int64_t a_nnz   = 27 * a_nrows;
+        const std::int64_t b_nrows = (opA == opB) ? a_nrows : a_ncols;
+        const std::int64_t b_ncols = (opA == opB) ? a_ncols : a_nrows;
+              std::int64_t b_nnz   = 27 * a_nrows;
+        const std::int64_t c_nrows = (opA == oneapi::mkl::transpose::nontrans) ? a_nrows : a_ncols;
+        const std::int64_t c_ncols = (opA == oneapi::mkl::transpose::nontrans) ? a_ncols : a_nrows;
+              std::int64_t c_nnz   = 0; // c_nnz is unknown at this point -> initializing  to 0
 
         //
         // setup A data locally in CSR format
@@ -236,13 +236,13 @@ int run_sparse_blas_example(sycl::queue &q)
         oneapi::mkl::sparse::init_matrix_handle(&csrB);
         oneapi::mkl::sparse::init_matrix_handle(&csrC);
 
-        auto ev_setA = oneapi::mkl::sparse::set_csr_data(q, csrA, a_nrows, a_ncols, a_index,
+        auto ev_setA = oneapi::mkl::sparse::set_csr_data(q, csrA, a_nrows, a_ncols, a_nnz, a_index,
                 a_rowptr, a_colind, a_values, {ev_cpy_ia, ev_cpy_ja, ev_cpy_a});
-        auto ev_setB = oneapi::mkl::sparse::set_csr_data(q, csrB, b_nrows, b_ncols, b_index,
+        auto ev_setB = oneapi::mkl::sparse::set_csr_data(q, csrB, b_nrows, b_ncols, b_nnz, b_index,
                 b_rowptr, b_colind, b_values, {ev_cpy_ib, ev_cpy_jb, ev_cpy_b});
 
         // Step 1.1: Set C matrix handle data with nullptrs
-        auto ev_setC = oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, c_index,
+        auto ev_setC = oneapi::mkl::sparse::set_csr_data(q, csrC, c_nrows, c_ncols, c_nnz, c_index,
                                                          c_rowptr, c_colind, c_values);
 
         // Step 1.2: Initialize the omatadd descriptor and set algorithm
@@ -269,7 +269,6 @@ int run_sparse_blas_example(sycl::queue &q)
                 {ev_setA, ev_setB, ev_setC});
 
         // Step 3.2: Get non-zero count of output C matrix
-        std::int64_t c_nnz = 0;
         oneapi::mkl::sparse::omatadd_get_nnz(
                 q, opA, opB, csrA, csrB, csrC, alg, descr, c_nnz, {ev_omatadd_analyze});
 
@@ -291,7 +290,7 @@ int run_sparse_blas_example(sycl::queue &q)
         data_ptr_vec.push_back(c_values);
 
         ev_setC = oneapi::mkl::sparse::set_csr_data(
-                q, csrC, c_nrows, c_ncols, c_index, c_rowptr, c_colind, c_values);
+                q, csrC, c_nrows, c_ncols, c_nnz, c_index, c_rowptr, c_colind, c_values);
 
         // Step 4.2: Finalize by performing matrix addition into C matrix handle
         auto ev_add = oneapi::mkl::sparse::omatadd(
@@ -308,7 +307,7 @@ int run_sparse_blas_example(sycl::queue &q)
         //
 
         // Copy first set of rows of C to host for printing
-        const intType c_nrows_copy = std::min<intType>(2, c_nrows); // only copy over this many rows of C to host
+        const intType c_nrows_copy = std::min<std::int64_t>(2, c_nrows); // only copy over this many rows of C to host
 
         intType *c_rowptr_host = sycl::malloc_host<intType>(c_nrows_copy+1, q);
         if (!c_rowptr_host) {
