@@ -120,8 +120,8 @@ int run_sparse_blas_example(sycl::queue &q)
 
         // Matrix data size
         intType size  = 4;
-        intType nrows = size * size * size;
-        intType ncols = nrows;
+        const std::int64_t  nrows = size * size * size;
+        const std::int64_t  ncols = nrows;
         intType columns = 5;
         intType ldb    = (layout_val == oneapi::mkl::layout::row_major) ? columns     : nrows;
         intType ldx    = (layout_val == oneapi::mkl::layout::row_major) ? columns     : nrows;
@@ -131,9 +131,9 @@ int run_sparse_blas_example(sycl::queue &q)
         // Input matrix in CSR format
         intType *ia, *ja;
         dataType *a, *dnsB, *dnsX, *dnsX_ref;
-        intType sizea   = 27 * nrows;
-        intType sizeja  = 27 * nrows;
-        intType sizeia  = nrows + 1;
+        const std::int64_t sizea   = 27 * nrows;
+        const std::int64_t sizeja  = 27 * nrows;
+        const std::int64_t sizeia  = nrows + 1;
 
         ia        = sycl::malloc_shared<intType>(sizeia, q);
         ja        = sycl::malloc_shared<intType>(sizeja, q);
@@ -164,6 +164,8 @@ int run_sparse_blas_example(sycl::queue &q)
 
         generate_sparse_matrix<dataType, intType>(size, ia, ja, a, int_index);
 
+        const std::int64_t nnz = ia[nrows] - int_index;
+
         // Init matrices B, X, and X_ref
         for (int i = 0; i < b_size; i++) {
             dnsB[i] = set_fp_value(dataType(2.0), dataType(0.0));
@@ -186,13 +188,14 @@ int run_sparse_blas_example(sycl::queue &q)
         std::cout << "\t\t\talpha    = " << alpha << std::endl;
         std::cout << "\t\t\tnrows    = " << nrows << std::endl;
         std::cout << "\t\t\tncols    = " << ncols << std::endl;
+        std::cout << "\t\t\tnnz      = " << nnz << std::endl;
         std::cout << "\t\t\tcolumns  = " << columns << std::endl;
         std::cout << "\t\t\tldb      = " << ldb << std::endl;
         std::cout << "\t\t\tldx      = " << ldx << std::endl;
 
         oneapi::mkl::sparse::init_matrix_handle(&csrA);
 
-        auto ev_set = oneapi::mkl::sparse::set_csr_data(q, csrA, nrows, nrows,
+        auto ev_set = oneapi::mkl::sparse::set_csr_data(q, csrA, nrows, nrows, nnz,
                                                         index_base_val, ia, ja, a, {});
 
         auto ev_opt = oneapi::mkl::sparse::optimize_trsm(q, layout_val, uplo_val, opA,
