@@ -1,6 +1,5 @@
 /* Generic target-file-type support for the BFD library.
    Copyright (C) 1990-2024 Free Software Foundation, Inc.
-   Copyright (C) 2019-2024 Intel Corporation
    Written by Cygnus Support.
 
    This file is part of BFD, the Binary File Descriptor library.
@@ -836,8 +835,6 @@ extern const bfd_target nds32_elf32_le_vec;
 extern const bfd_target nds32_elf32_linux_be_vec;
 extern const bfd_target nds32_elf32_linux_le_vec;
 extern const bfd_target nfp_elf64_vec;
-extern const bfd_target nios2_elf32_be_vec;
-extern const bfd_target nios2_elf32_le_vec;
 extern const bfd_target ns32k_aout_pc532mach_vec;
 extern const bfd_target ns32k_aout_pc532nbsd_vec;
 extern const bfd_target or1k_elf32_vec;
@@ -1222,9 +1219,6 @@ static const bfd_target * const _bfd_target_vector[] =
 	&nfp_elf64_vec,
 #endif
 
-	&nios2_elf32_be_vec,
-	&nios2_elf32_le_vec,
-
 	&ns32k_aout_pc532mach_vec,
 	&ns32k_aout_pc532nbsd_vec,
 
