@@ -1,7 +1,6 @@
 /* This testcase is part of GDB, the GNU debugger.
 
    Copyright 2023-2025 Free Software Foundation, Inc.
-   Copyright (C) 2023-2025 Intel Corporation
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,13 +16,13 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 static void
-dummy() /* dummy-function */
+dummy ()
 {
 }
 
 int
 main ()
 {
-  dummy(); /* break-here */
+  dummy (); /* break-here */
   return 0; /* stop-here */
 }
