@@ -1,7 +1,6 @@
 /* TID parsing for GDB, the GNU debugger.
 
-   Copyright (C) 2015-2025 Free Software Foundation, Inc.
-   Copyright (C) 2019-2025 Intel Corporation
+   Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -25,7 +24,7 @@
 
 /* See tid-parse.h.  */
 
-void ATTRIBUTE_NORETURN
+[[noreturn]] void
 invalid_thread_id_error (const char *string)
 {
   error (_("Invalid thread ID: %s"), string);
@@ -49,51 +48,62 @@ get_non_negative_number_trailer (const char **pp, int *parsed_value,
   return retval;
 }
 
-/* See tid-parse.h.  */
+/* Parse TIDSTR as a per-inferior lane ID, in one of the following forms:
 
-struct thread_info *
-parse_thread_id (const char *tidstr, const char **end, int *simd_lane_num)
+     INF_NUM.THR_NUM:LANE_NUM, THR_NUM:LANE, THR_NUM, :LANE_NUM
+
+   Return a tuple; the first item of the tuple is INF_NUM, the second item
+   is THR_NUM, and the third is LANE_NUM.
+
+   If TIDSTR does not include an INF_NUM component, then the first item in
+   the tuple will be 0 (which is an invalid inferior number), this indicates
+   that TIDSTR references the current inferior.
+
+   If TIDSTR does not include a THR_NUM component, then the second item in
+   the tuple will be 0 (which is an invalid thread number).  This indicates
+   that TIDSTR references the current thread.
+
+   If TIDSTR does not include a LANE_NUM component, then the third item in
+   the tuple will be -1 (which is an invalid lane number).  This indicates
+   that TIDSTR references the default lane.
+
+   This function does not validate the INF_NUM, THR_NUM and LANE_NUM are
+   actually valid numbers, that is, they might reference inferiors, threads
+   or lanes that don't actually exist; this function just splits the string
+   into its component parts.
+
+   If there is an error parsing TIDSTR then this function will raise an
+   exception.  */
+
+static std::tuple<int, int, int>
+parse_thread_id_1 (const char *tidstr, const char **end)
 {
   const char *number = tidstr;
   const char *dot, *p1;
-  struct thread_info *tp = nullptr;
-  struct inferior *inf;
-  int thr_num;
-  int lane_num = -1;
-  int explicit_inf_id = 0;
+  int thr_num, inf_num, lane_num;
 
   dot = strchr (number, '.');
 
   if (dot != NULL)
     {
       /* Parse number to the left of the dot.  */
-      int inf_num;
-
       p1 = number;
       if (!get_non_negative_number_trailer (&p1, &inf_num, '.', number))
 	invalid_thread_id_error (number);
 
       if (inf_num == 0)
 	invalid_thread_id_error (number);
-
-      inf = find_inferior_id (inf_num);
-      if (inf == NULL)
-	error (_("No inferior number '%d'"), inf_num);
-
-      explicit_inf_id = 1;
       p1 = dot + 1;
     }
   else
     {
-      inf = current_inferior ();
-
+      inf_num = 0;
       p1 = number;
     }
 
   dot = strchr (p1, ':');
-
-  bool lane_specified = (dot != NULL);
-  int trailer = lane_specified ? ':' : 0;
+  bool lane_specified = (dot != nullptr);
+  char trailer = lane_specified ? ':' : 0;
 
   if (p1[0] != ':')
     {
@@ -103,7 +113,62 @@ parse_thread_id (const char *tidstr, const char **end, int *simd_lane_num)
 
       if (thr_num == 0)
 	invalid_thread_id_error (number);
+    }
+  else
+    {
+      /* Only lane number is specified.  Reference the current thread.  */
+      thr_num = 0;
+    }
 
+  lane_num = -1;
+  if (lane_specified)
+    {
+      p1 = dot + 1;
+
+      if (!get_non_negative_number_trailer (&p1, &lane_num, 0, dot))
+	error (_("Incorrect SIMD lane number: %s."), dot);
+
+      if (lane_num >= (sizeof (unsigned int)) * 8)
+	error (_("Incorrect SIMD lane number: %d."), lane_num);
+    }
+
+  if (end != nullptr)
+    *end = p1;
+
+  return { inf_num, thr_num, lane_num };
+}
+
+/* See tid-parse.h.  */
+
+struct thread_info *
+parse_thread_id (const char *tidstr, const char **end, int *simd_lane_num)
+{
+  const auto [inf_num, thr_num, lane_num]
+    = parse_thread_id_1 (tidstr, end);
+
+  inferior *inf;
+  bool explicit_inf_id = false;
+
+  if (inf_num != 0)
+    {
+      inf = find_inferior_id (inf_num);
+      if (inf == nullptr)
+	error (_("No inferior number '%d'"), inf_num);
+      explicit_inf_id = true;
+    }
+  else
+    inf = current_inferior ();
+
+  thread_info *tp = nullptr;
+  if (thr_num == 0)
+    {
+      /* Take the current thread.  */
+      if (inferior_ptid == null_ptid)
+	error (_("No thread selected."));
+      tp = inferior_thread ();
+    }
+  else
+    {
       for (thread_info *it : inf->threads ())
 	if (it->per_inf_num == thr_num)
 	  {
@@ -119,15 +184,8 @@ parse_thread_id (const char *tidstr, const char **end, int *simd_lane_num)
 	    error (_("Unknown thread %d."), thr_num);
 	}
     }
-  else
-    {
-      /* Only lane number is specified.  Take the current thread.  */
-      if (inferior_ptid == null_ptid)
-	error (_("No thread selected."));
-      tp = inferior_thread ();
-    }
 
-  if (lane_specified)
+  if (lane_num != -1)
     {
       if (tp->executing ())
 	error (_("Thread %s is executing, cannot check SIMD lane status:"
@@ -141,33 +199,34 @@ parse_thread_id (const char *tidstr, const char **end, int *simd_lane_num)
 	error (_("Thread %s does not have SIMD lanes: Cannot specify SIMD"
 		 " lane"), print_thread_id (tp));
 
-      p1 = dot + 1;
-
-      if (!get_non_negative_number_trailer (&p1, &lane_num, 0, dot))
-	error (_("Incorrect SIMD lane number: %s."), dot);
-
-      if (lane_num >= (sizeof (unsigned int)) * 8)
-	error (_("Incorrect SIMD lane number: %d."), lane_num);
-
-      if (simd_lane_num != nullptr)
-	*simd_lane_num = lane_num;
-      else
+      if (simd_lane_num == nullptr)
 	error (_("SIMD lane is not supported."));
     }
-  else
-    {
-      if (simd_lane_num != nullptr)
-	*simd_lane_num = -1;
-    }
 
-  if (end != NULL)
-    *end = p1;
+  if (simd_lane_num != nullptr)
+    *simd_lane_num = lane_num;
 
   return tp;
 }
 
 /* See tid-parse.h.  */
 
+bool
+is_thread_id (const char *tidstr, const char **end)
+{
+  try
+    {
+      (void) parse_thread_id_1 (tidstr, end);
+      return true;
+    }
+  catch (const gdb_exception_error &)
+    {
+      return false;
+    }
+}
+
+/* See tid-parse.h.  */
+
 tid_range_parser::tid_range_parser (const char *tidlist,
 				    int default_inferior,
 				    int default_thr_num)
@@ -926,7 +985,7 @@ _initialize_tid_parse ()
 #if GDB_SELF_TEST
   selftests::register_test ("test_get_tid",
 			    selftests::test_get_tid);
-selftests::register_test ("test_get_tid_range",
+  selftests::register_test ("test_get_tid_range",
 			    selftests::test_get_tid_range);
 #endif
 }
