@@ -1,7 +1,6 @@
 /* CTF format support.
 
-   Copyright (C) 2012-2025 Free Software Foundation, Inc.
-   Copyright (C) 2021-2025 Intel Corporation
+   Copyright (C) 2012-2024 Free Software Foundation, Inc.
    Contributed by Hui Zhu <hui_zhu@mentor.com>
    Contributed by Yao Qi <yao@codesourcery.com>
 
@@ -1113,7 +1112,7 @@ ctf_read_tp (struct uploaded_tp **uploaded_tps)
    second packet which contains events on trace blocks.  */
 
 static void
-ctf_target_open (const char *dirname, int from_tty)
+ctf_target_open (const char *args, int from_tty)
 {
   struct bt_ctf_event *event;
   uint32_t event_id;
@@ -1121,10 +1120,11 @@ ctf_target_open (const char *dirname, int from_tty)
   struct uploaded_tsv *uploaded_tsvs = NULL;
   struct uploaded_tp *uploaded_tps = NULL;
 
-  if (!dirname)
+  std::string dirname = extract_single_filename_arg (args);
+  if (dirname.empty ())
     error (_("No CTF directory specified."));
 
-  ctf_open_dir (dirname);
+  ctf_open_dir (dirname.c_str ());
 
   target_preopen (from_tty);
 
@@ -1164,7 +1164,7 @@ ctf_target_open (const char *dirname, int from_tty)
   start_pos = bt_iter_get_pos (bt_ctf_get_iter (ctf_iter));
   gdb_assert (start_pos->type == BT_SEEK_RESTORE);
 
-  trace_dirname = make_unique_xstrdup (dirname);
+  trace_dirname = make_unique_xstrdup (dirname.c_str ());
   current_inferior ()->push_target (&ctf_ops);
 
   inferior_appeared (current_inferior (), CTF_PID);
@@ -1724,6 +1724,7 @@ void
 _initialize_ctf ()
 {
 #if HAVE_LIBBABELTRACE
-  add_target (ctf_target_info, ctf_target_open, filename_completer);
+  add_target (ctf_target_info, ctf_target_open,
+	      filename_maybe_quoted_completer);
 #endif
 }
