@@ -1,7 +1,6 @@
 /* TUI display source/assembly window.
 
-   Copyright (C) 1998-2025 Free Software Foundation, Inc.
-   Copyright (C) 2024-2025 Intel Corporation
+   Copyright (C) 1998-2024 Free Software Foundation, Inc.
 
    Contributed by Hewlett-Packard Company.
 
@@ -20,14 +19,13 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#include <ctype.h>
+#include "observable.h"
 #include "symtab.h"
 #include "frame.h"
 #include "breakpoint.h"
 #include "value.h"
 #include "source.h"
 #include "objfiles.h"
-#include "filenames.h"
 #include "gdbsupport/gdb-safe-ctype.h"
 
 #include "tui/tui.h"
@@ -35,7 +33,6 @@
 #include "tui/tui-io.h"
 #include "tui/tui-status.h"
 #include "tui/tui-win.h"
-#include "tui/tui-wingeneral.h"
 #include "tui/tui-winsource.h"
 #include "tui/tui-source.h"
 #include "tui/tui-disasm.h"
@@ -317,6 +314,9 @@ tui_source_window_base::refresh_window ()
      the screen, potentially creating a flicker.  */
   wnoutrefresh (handle.get ());
 
+  if (m_content.empty ())
+    return;
+
   int pad_width = getmaxx (m_pad.get ());
   int left_margin = this->left_margin ();
   int view_width = this->view_width ();
@@ -346,7 +346,7 @@ tui_source_window_base::refresh_window ()
   int smincol = x + box_width () + left_margin;
   int smaxrow = sminrow + m_content.size () - 1;
   int smaxcol = smincol + view_width - 1;
-  prefresh (m_pad.get (), 0, pad_x, sminrow, smincol, smaxrow, smaxcol);
+  pnoutrefresh (m_pad.get (), 0, pad_x, sminrow, smincol, smaxrow, smaxcol);
 }
 
 void
@@ -407,15 +407,9 @@ tui_source_window_base::show_source_content ()
   for (int lineno = 0; lineno < m_content.size (); lineno++)
     show_source_line (lineno);
 
-  if (can_box ())
-    {
-      /* Calling check_and_display_highlight_if_needed will call refresh_window
-	 (so long as the current window can be boxed), which will ensure that
-	 the newly loaded window content is copied to the screen.  */
-      check_and_display_highlight_if_needed ();
-    }
-  else
-    refresh_window ();
+  /* Calling check_and_display_highlight_if_needed will call
+     refresh_window.  */
+  check_and_display_highlight_if_needed ();
 }
 
 tui_source_window_base::tui_source_window_base ()
@@ -449,8 +443,8 @@ tui_source_window_base::rerender ()
 
   if (!m_content.empty ())
     {
-      struct symtab_and_line cursal
-	= get_current_source_symtab_and_line ();
+      symtab_and_line cursal
+	= get_current_source_symtab_and_line (current_program_space);
 
       if (m_start_line_or_addr.loa == LOA_LINE)
 	cursal.line = m_start_line_or_addr.u.line_no;
@@ -460,14 +454,26 @@ tui_source_window_base::rerender ()
     }
   else if (deprecated_safe_get_selected_frame () != NULL)
     {
-      struct symtab_and_line cursal
-	= get_current_source_symtab_and_line ();
+      symtab_and_line cursal
+	= get_current_source_symtab_and_line (current_program_space);
       frame_info_ptr frame = deprecated_safe_get_selected_frame ();
       struct gdbarch *gdbarch = get_frame_arch (frame);
 
-      struct symtab *s = find_pc_line_symtab (get_frame_pc (frame));
-      if (this != TUI_SRC_WIN)
-	find_line_first_pc (s, cursal.line, &cursal.pc);
+      CORE_ADDR pc = get_frame_pc (frame);
+      struct symtab *s = find_pc_line_symtab (pc);
+      if (this != tui_src_win ())
+	{
+	  find_line_first_pc (s, cursal.line, &cursal.pc);
+	  if (cursal.pc == 0)
+	    {
+	      CORE_ADDR low;
+	      if (find_pc_partial_function_sym (pc, nullptr, &low, nullptr,
+						nullptr))
+		cursal.pc = tui_get_low_disassembly_address (gdbarch, low, pc);
+	      else
+		cursal.pc = pc;
+	    }
+	}
 
       /* This centering code is copied from tui_source_window::maybe_update.
 	 It would be nice to do centering more often, and do it in just one
@@ -499,9 +505,9 @@ tui_source_window_base::refill ()
 {
   symtab_and_line sal {};
 
-  if (this == TUI_SRC_WIN)
+  if (this == tui_src_win ())
     {
-      sal = get_current_source_symtab_and_line ();
+      sal = get_current_source_symtab_and_line (current_program_space);
       if (sal.symtab == NULL)
 	{
 	  frame_info_ptr fi = deprecated_safe_get_selected_frame ();
