@@ -1,7 +1,6 @@
 /* Target-dependent code for X86-based targets.
 
-   Copyright (C) 2018-2025 Free Software Foundation, Inc.
-   Copyright (C) 2018-2025 Intel Corporation
+   Copyright (C) 2018-2024 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -18,8 +17,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef X86_TDEP_H
-#define X86_TDEP_H
+#ifndef GDB_X86_TDEP_H
+#define GDB_X86_TDEP_H
 
 /* Fill SSP to the shadow stack pointer in GDB's REGCACHE.  */
 
@@ -37,4 +36,4 @@ extern bool x86_in_indirect_branch_thunk (CORE_ADDR pc,
 					  const char * const *register_names,
 					  int lo, int hi);
 
-#endif /* x86-tdep.h */
+#endif /* GDB_X86_TDEP_H */
